clear
set mem 2g
set more off

local admindata = "/rdcprojects/mc1/mc00535/data/ezdata/blocklevel_admdata.dta"
local cendatadir = "/rdcprojects/mc1/mc00535/data/decennial/02-Recoded_State_Files"
local outdir = "/rdcprojects/mc1/mc00535/data/decennial/03-State_Files"


**** Open admin file and keep a list of sample counties
use tract1990 assigned_tract using `admindata' if assigned_tract!=., clear
gen county90=substr(tract1990,1,5)
keep county90
gen st=substr(county90,1,2)
bysort county90 st: keep if _n==1
save `outdir'/samplelists.dta, replace


**** Open file derived from 1990 census geography files and keep a list of all states
use blockid90 using "/rdcprojects/mc1/mc00535/data/Tract1990_Centroids/Block1990_XY.dta"
gen county90=substr(blockid90,1,5)
keep county90
gen st=substr(county90,1,2)
bysort county90 st: keep if _n==1
save `outdir'/universelists.dta, replace


**** Create a file containing the 9 deciles of the lnwage2 distribution for each year among residents of sample counties
* Get list of sample counties
use `outdir'/samplelists.dta
levelsof st, local(states)
clear


set seed 1234
tempfile wagevars
**** For each year, loop over sample counties (`samplecounties') and nonsample areas by state (`states')
foreach year in 1980 1990 2000 {
local count=0
foreach state of local states {
local count=`count'+1
di ""
di ""
di ""
di "Reading in state `state', year `year'"
use pwgt2 incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf using `cendatadir'/dec`year'recoded`state'.dta, clear
if `count'>1 {
append using `wagevars', nolabel
}
save `wagevars', replace
}

**** Create lnwage2 variable to be conditioned on in creation of wage weights
gen wage=incw/(wklyrwk*wklyrhr)
gen lnwage=ln(wage)
gen lnwage2=lnwage if incwf==0&wklyrwkf==0&wklyrhrf==0
drop incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf

collapse (p10) lnwage2_10=lnwage2 (p20) lnwage2_20=lnwage2 (p30) lnwage2_30=lnwage2 (p40) lnwage2_40=lnwage2 (p50) lnwage2_50=lnwage2 (p60) lnwage2_60=lnwage2 (p70) lnwage2_70=lnwage2 (p80) lnwage2_80=lnwage2 (p90) lnwage2_90=lnwage2 [aw=pwgt2]

save `cendatadir'/wage_deciles`year'.dta, replace

}

