clear
set more off
set matsize 2000
set mem 5g

* set to version 10 so anovas run with current notation for interaction terms
version 10

adopath ++ "/public/ado"

local cendatadir = "/rdcprojects/mc1/mc00535/data/decennial/02-Recoded_State_Files"

**********************************************************************************
*** This is used to record diagnostics from the missingness models regressions ***
**********************************************************************************
tempname memhold
tempfile results
postfile `memhold' str20(county90) double(year assigned_tract) str20(model) double(N df_m df_tracts) using "`results'"

**** Get list of sample counties
use `cendatadir'/samplelists.dta
levelsof county90, local(samplecounties)
clear

**** Get list of all US states
use `cendatadir'/universelists.dta
* Drop Washington, DC since this local will be used to loop over non-sample counties
drop if st=="11"
levelsof st, local(states)
clear

**** Get wage deciles for each year in sample counties
foreach year in 1980 1990 2000 {
use `cendatadir'/wage_deciles`year'.dta, clear
mean lnwage2_*
local lnwage2_p10_`year'=_b[lnwage2_10]
local lnwage2_p20_`year'=_b[lnwage2_20]
local lnwage2_p30_`year'=_b[lnwage2_30]
local lnwage2_p40_`year'=_b[lnwage2_40]
local lnwage2_p50_`year'=_b[lnwage2_50]
local lnwage2_p60_`year'=_b[lnwage2_60]
local lnwage2_p70_`year'=_b[lnwage2_70]
local lnwage2_p80_`year'=_b[lnwage2_80]
local lnwage2_p90_`year'=_b[lnwage2_90]
}
clear

tempfile predictions

local count=0
**** For each year, loop over sample counties (`samplecounties') and nonsample areas by state (`states')
foreach year in 1980 1990 2000 {
forval type=1/2 {
if `type'==1 local list = "samplecounties"
if `type'==2 local list = "states"
foreach county of local `list' {
local count=`count'+1

local state = substr("`county'",1,2)

local varlist1980 = "pwgt2 assigned_tract tractid90 powtractid90 esr incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf sex age educcat inschool raceeth cow powcounty80f powtractid80f"
local varlist1990 = "pwgt2 assigned_tract tractid90 powtractid90 esr incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf sex age educcat inschool raceeth cow pow90f1 pow90f2 pow90f3 pow90f4 pow90f5"
local varlist2000 = "pwgt2 assigned_tract tractid90 powtractid90 esr incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf sex age educcat inschool raceeth cow powf1 powf3 powf5"

if `type'==1 {
di ""
di ""
di ""
di "Processing county `county', year `year'"
use `varlist`year'' using `cendatadir'/dec`year'recoded`state'.dta
keep if substr(tractid90,1,5)=="`county'"
}
if `type'==2 {
di ""
di ""
di ""
di "Processing nonsample portion of state `state', year `year'"
use `varlist`year'' using `cendatadir'/dec`year'recoded_5pctnonsample.dta
keep if substr(tractid90,1,2)=="`state'"
replace tractid90="`state'"+"000000000"
}

***** Restrict attention to those with a potentially valid pow
keep if inlist(esr,1,4)==1

gen byte pow_missimp = .
if `year'==1980 {
replace pow_missimp = ( inlist(powcounty80f,0,.)==0 | inlist(powtractid80f,0,.)==0 )
drop powcounty80f powtractid80f
}
if `year'==1990 {
replace pow_missimp = ( inlist(pow90f1,0,.)==0 | inlist(pow90f2,0,.)==0 | inlist(pow90f3,0,.)==0 | inlist(pow90f4,0,.)==0 | inlist(pow90f5,0,.)==0 )
drop pow90f1 pow90f2 pow90f3 pow90f4 pow90f5
}
if `year'==2000 {
replace pow_missimp = ( inlist(powf1,0,.)==0 | inlist(powf3,0,.)==0 | inlist(powf5,0,.)==0 )
drop powf1 powf3 powf5
}
replace pow_missimp = powtractid90=="" if pow_missimp==0
label variable pow_missimp "=1 if pow geocode is missing or imputed"

**** Create a year variable to use when merging weights back on to data
gen year=`year'

**** Create lnwage2 variable to be conditioned on in creation of wage weights
gen wage=incw/(wklyrwk*wklyrhr)
gen lnwage=ln(wage)
gen lnwage2=lnwage if incwf==0&wklyrwkf==0&wklyrhrf==0
drop incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf

**** Replace missing lnwage2 values with 0 so that all employed individuals can be included in unconditional regression
****    In the unconditional regression, include the missing lnwage2 dummy 
gen lnwage2_miss=lnwage2==.
replace lnwage2=0 if lnwage2==.

**** Generate lnwage2 polynomial to be used in both regressions
gen lnwage2_cat=0 if lnwage2_miss==1
replace lnwage2_cat=1 if  inrange(lnwage2,-999999             ,`lnwage2_p10_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=2 if  inrange(lnwage2,`lnwage2_p10_`year'',`lnwage2_p20_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=3 if  inrange(lnwage2,`lnwage2_p20_`year'',`lnwage2_p30_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=4 if  inrange(lnwage2,`lnwage2_p30_`year'',`lnwage2_p40_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=5 if  inrange(lnwage2,`lnwage2_p40_`year'',`lnwage2_p50_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=6 if  inrange(lnwage2,`lnwage2_p50_`year'',`lnwage2_p60_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=7 if  inrange(lnwage2,`lnwage2_p60_`year'',`lnwage2_p70_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=8 if  inrange(lnwage2,`lnwage2_p70_`year'',`lnwage2_p80_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=9 if  inrange(lnwage2,`lnwage2_p80_`year'',`lnwage2_p90_`year'')==1 & lnwage2_miss==0 
replace lnwage2_cat=10 if inrange(lnwage2,`lnwage2_p90_`year'',999999              )==1 & lnwage2_miss==0 

**** Recode Broad Age Categories
gen broadagecat = .
replace broadagecat=1 if age <=19
replace broadagecat=2 if 20 <= age & age <= 39
replace broadagecat=3 if 40 <= age & age <= 64
replace broadagecat=4 if 65 <= age

**** Recode Broad Educ Categories
gen broadeduccat = .
replace broadeduccat = 1 if educcat<= 7
replace broadeduccat = 2 if educcat == 8
replace broadeduccat = 3 if educcat >= 9
replace broadeduccat = 4 if inschool>= 2&inschool!=.

**** Race
gen racecat = 1 if raceeth == 1
replace racecat = 2 if raceeth == 2
replace racecat = 3 if raceeth > 2 & raceeth!=.

**** COW
destring cow, replace
recode cow .=-1

**** Create a numeric tract categorical variable to include in anovas
egen tractnum=group(tractid90)

gen pow_missimp_hat=.
**** Estimate the probability of having a missing or imputed POW given employed
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow          if assigned_tract==1 [aw=pwgt2]
if _rc==0 predict temppredict                 if assigned_tract==1
if _rc==0 replace pow_missimp_hat=temppredict if assigned_tract==1
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (1) ("pow_ipw") (e(N)) (e(df_m)) (e(df_1))
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow          if assigned_tract==0 [aw=pwgt2]
if _rc==0 predict temppredict                 if assigned_tract==0
if _rc==0 replace pow_missimp_hat=temppredict if assigned_tract==0
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (0) ("pow_ipw") (e(N)) (e(df_m)) (e(df_1))
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow          if assigned_tract==. [aw=pwgt2]
if _rc==0 predict temppredict                 if assigned_tract==.
if _rc==0 replace pow_missimp_hat=temppredict if assigned_tract==.
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (.) ("pow_ipw") (e(N)) (e(df_m)) (e(df_1))

gen wage_pow_missimp_hat=.
**** Estimate the probability of having a missing or imputed POW given employed and lnwage2!=.
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow               if assigned_tract==1 & lnwage2_miss==0 [aw=pwgt2]
if _rc==0 predict temppredict                      if assigned_tract==1
if _rc==0 replace wage_pow_missimp_hat=temppredict if assigned_tract==1
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (1) ("wage_pow_ipw") (e(N)) (e(df_m)) (e(df_1))
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow               if assigned_tract==0 & lnwage2_miss==0 [aw=pwgt2]
if _rc==0 predict temppredict                      if assigned_tract==0
if _rc==0 replace wage_pow_missimp_hat=temppredict if assigned_tract==0
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (0) ("wage_pow_ipw") (e(N)) (e(df_m)) (e(df_1))
cap noi anova pow_missimp tractnum lnwage2_cat racecat broadeduccat broadagecat sex racecat*broadeduccat racecat*broadagecat racecat*sex broadeduccat*broadagecat broadeduccat*sex broadagecat*sex cow               if assigned_tract==. & lnwage2_miss==0 [aw=pwgt2]
if _rc==0 predict temppredict                      if assigned_tract==.
if _rc==0 replace wage_pow_missimp_hat=temppredict if assigned_tract==.
if _rc==0 drop temppredict
if _rc==0 post `memhold' ("`county'") (`year') (.) ("wage_pow_ipw") (e(N)) (e(df_m)) (e(df_1))

***To check that predictions are being made for everyone, summarize the predictions and a never-missing variable
su sex pow_missimp_hat wage_pow_missimp_hat if lnwage2_miss==1
su sex pow_missimp_hat wage_pow_missimp_hat if lnwage2_miss==0

drop tractnum

collapse pow_missimp_hat wage_pow_missimp_hat, by(tractid90 lnwage2_cat cow year sex broadagecat broadeduccat racecat)

if `count'>1 {
append using `predictions'
}
save `predictions', replace

}
}
}

gen pow_ipw = 1/(1-  min(max(pow_missimp_hat,0),.975)  ) if pow_missimp_hat<.
label variable pow_ipw "Inverse of Pr(pow is valid|employed)"
drop pow_missimp

gen wage_pow_ipw = 1/(1-  min(max(wage_pow_missimp_hat,0),.975)  ) if wage_pow_missimp_hat<.
label variable wage_pow_ipw "Inverse of Pr(pow is valid|employed,lnwage2!=.)"
drop wage_pow_missimp

save "`cendatadir'/County-Year-Demo_POWimputation_IPWs", replace

su pow_ipw, detail
su wage_pow_ipw, detail

*********************************
*** export diagnostic results ***
*********************************
postclose `memhold'
use `results', clear
save "`cendatadir'/County-Year-Demo_POWimputation_IPWs_Ns", replace


