***********************************************************************;
**** This program defines a series of macros.  One macro is the    ****;
**** actual geocoding routine, all other macros clean address      ****;
**** data in some way.  The address cleaning macros are:           ****;
****                                                               ****;
**** 1. trim_addr - Drops all characters appearing after a USPS    ****;
****    recognized street designator (st, avenue, rd, drive, etc.) ****;
**** 2. replace_wordnum - Replaces ordinal words with the numeric  ****;
****    equiv.  For example, "third" becomes "3rd                  ****;
**** 3. group_streetnum - If in the first six characters a group   ****;
****    of numbers followed by a space and more numbers occurs,    ****;
****    the space is moved to the end of the group of numbers.     ****;
****    The macro makes sure to omit instances in which the second ****;
****    group of numbers is part of an numeric street name.        ****;
****    For example,                                               ****;
****    "123 45 elm street" becomes "12345  elm street" but        ****;
****    "123 45th street" remains unchanged                        ****;
**** 4. drop_secondaries - Removes secondary address key words and ****;
****    any words that follow.  Also, with the key word "floor",   ****;
****    any ordinal word dicectly preceeding is also removed.      ****;
****    For example:                                               ****;
****    "123 elm street STE 550" becomes "123 elm street" and      ****;
****    "123 elm street 3rd floor" becomes "123 elm street"        ****;
**** 5. remove_abbrev - Replaces each abbreviated postal words     ****;
****    with the full word                                         ****;
**** 6. abbreviate - Replaces each postal words with its           ****;
****    abbreviation                                               ****;
**** 7. group_directions - replaces " s w " with " sw ", etc.      ****;
**** 8. remove_quote - replaces quotation marks with blank spaces  ****;
***********************************************************************;





**** Set paths and librefs;
%let homedir = /rdcprojects/mc1/mc00535;
%let TIGERYEAR = 2000;
**** Location of map spatial data sets and catalog;
%let MAP_DATA=&homedir/data/geocoding/&TIGERYEAR/Geocoded Street Map;
**** Location for street lookup data sets used by geocoder;
%let LOOKUP_DATA=&homedir/data/geocoding/&TIGERYEAR/Street Lookup Data;
**** Location of address data set to be geocoded;
%let ADDRESS_DATA=&homedir/data/geocoding/Address Data;
**** Set librefs;
libname STREET "&MAP_DATA";
libname LOOKUP "&LOOKUP_DATA";
libname ADDRESS "&ADDRESS_DATA";



**** This macro calls the geocoding routine ****;
%macro geocode(addr_data,out_coded,out_notcoded,addr_type);

/*--- Create address data set. --------------------------*/
data ADDRESS.SAMPLE;
set ADDRESS.&addr_data ;
run;

%let createnew = NO;
/*--- Set up the batch geocoding input. ----------------------------*/
%gcbatch(
glib = LOOKUP, /* Street data sets libref */
newdata = &createnew , /* (Re)create lookup data? */
mname = STREET.USA&TIGERYEAR..SAMPLE, /* Base map of streets */
geod = ADDRESS.SAMPLE, /* Address data to geocode */
nv = lbdnum, /* Who's at the address */
av = &addr_type.street, /* House number/street name */
cv = &addr_type.plce, /* City name */
sv = &addr_type.st, /* State abbreviation */
zv = &addr_type.zip5, /* ZIP Code (5-digit) */
pv = county tract block); /* AREA var wanted from map */
/*--- Invoke the batch geocoding program. --------------------------*/
dm 'AF C=SASHELP.GIS.GEOCODEB.SCL';


data ADDRESS.&out_coded ;
set ADDRESS.SAMPLE;
if tract ~= .;
matchtype = "&addr_type ";
run;

%let keepvars = yr lbdnum bstreet bplce bst bzip5 tract_ssl newfips mu flagb
                     pstreet pplce pst pzip5;
%if (1992 <= &yr) & (2001 >= &yr) %then %let keepvars = yr lbdnum 
                     bstreet bplce bst bzip5 tract_ssl newfips mu flagb
                     pstreet pplce pst pzip5
                     mstreet mplce mst mzip5;
data ADDRESS.&out_notcoded
   (keep = &keepvars );
set ADDRESS.SAMPLE;
if tract = .;
run;
%mend;




%macro trim_addr(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data (drop = testfind );
set ADDRESS.&in_addr_data ;

%let prmry1 = ALLEE;
%let prmry2 = ALLEY;
%let prmry3 = ALLY;
%let prmry4 = ALY;
%let prmry5 = ANEX;
%let prmry6 = ANNEX;
%let prmry7 = ANNX;
%let prmry8 = ANX;
%let prmry9 = ARC;
%let prmry10 = ARCADE;
%let prmry11 = AV;
%let prmry12 = AVE;
%let prmry13 = AVEN;
%let prmry14 = AVENU;
%let prmry15 = AVENUE;
%let prmry16 = AVN;
%let prmry17 = AVNUE;
%let prmry18 = BAYOO;
%let prmry19 = BAYOU;
%let prmry20 = BCH;
%let prmry21 = BEACH;
%let prmry22 = BEND;
%let prmry23 = BLF;
%let prmry24 = BLUF;
%let prmry25 = BLUFF;
%let prmry26 = BLUFFS;
%let prmry27 = BLVD;
%let prmry28 = BND;
%let prmry29 = BOT;
%let prmry30 = BOTTM;
%let prmry31 = BOTTOM;
%let prmry32 = BOUL;
%let prmry33 = BOULEVARD;
%let prmry34 = BOULV;
%let prmry35 = BR;
%let prmry36 = BRANCH;
%let prmry37 = BRDGE;
%let prmry38 = BRG;
%let prmry39 = BRIDGE;
%let prmry40 = BRK;
%let prmry41 = BRNCH;
%let prmry42 = BROOK;
%let prmry43 = BROOKS;
%let prmry44 = BTM;
%let prmry45 = BURG;
%let prmry46 = BURGS;
%let prmry47 = BYP;
%let prmry48 = BYPA;
%let prmry49 = BYPAS;
%let prmry50 = BYPASS;
%let prmry51 = BYPS;
%let prmry52 = CAMP;
%let prmry53 = CANYN;
%let prmry54 = CANYON;
%let prmry55 = CAPE;
%let prmry56 = CAUSEWAY;
%let prmry57 = CAUSWAY;
%let prmry58 = CEN;
%let prmry59 = CENT;
%let prmry60 = CENTER;
%let prmry61 = CENTERS;
%let prmry62 = CENTR;
%let prmry63 = CENTRE;
%let prmry64 = CIR;
%let prmry65 = CIRC;
%let prmry66 = CIRCL;
%let prmry67 = CIRCLE;
%let prmry68 = CIRCLES;
%let prmry69 = CK;
%let prmry70 = CLB;
%let prmry71 = CLF;
%let prmry72 = CLFS;
%let prmry73 = CLIFF;
%let prmry74 = CLIFFS;
%let prmry75 = CLUB;
%let prmry76 = CMP;
%let prmry77 = CNTER;
%let prmry78 = CNTR;
%let prmry79 = CNYN;
%let prmry80 = COMMON;
%let prmry81 = COR;
%let prmry82 = CORNER;
%let prmry83 = CORNERS;
%let prmry84 = CORS;
%let prmry85 = COURSE;
%let prmry86 = COURT;
%let prmry87 = COURTS;
%let prmry88 = COVE;
%let prmry89 = COVES;
%let prmry90 = CP;
%let prmry91 = CPE;
%let prmry92 = CR;
%let prmry93 = CRCL;
%let prmry94 = CRCLE;
%let prmry95 = CRECENT;
%let prmry96 = CREEK;
%let prmry97 = CRES;
%let prmry98 = CRESCENT;
%let prmry99 = CRESENT;
%let prmry100 = CREST;
%let prmry101 = CRK;
%let prmry102 = CROSSING;
%let prmry103 = CROSSROAD;
%let prmry104 = CRSCNT;
%let prmry105 = CRSE;
%let prmry106 = CRSENT;
%let prmry107 = CRSNT;
%let prmry108 = CRSSING;
%let prmry109 = CRSSNG;
%let prmry110 = CRT;
%let prmry111 = CSWY;
%let prmry112 = CT;
%let prmry113 = CT;
%let prmry114 = CTR;
%let prmry115 = CURVE;
%let prmry116 = CV;
%let prmry117 = CYN;
%let prmry118 = DALE;
%let prmry119 = DAM;
%let prmry120 = DIV;
%let prmry121 = DIVIDE;
%let prmry122 = DL;
%let prmry123 = DM;
%let prmry124 = DR;
%let prmry125 = DRIV;
%let prmry126 = DRIVE;
%let prmry127 = DRIVES;
%let prmry128 = DRV;
%let prmry129 = DV;
%let prmry130 = DVD;
%let prmry131 = EST;
%let prmry132 = ESTATE;
%let prmry133 = ESTATES;
%let prmry134 = ESTS;
%let prmry135 = EXP;
%let prmry136 = EXPR;
%let prmry137 = EXPRESS;
%let prmry138 = EXPRESSWAY;
%let prmry139 = EXPW;
%let prmry140 = EXPY;
%let prmry141 = EXT;
%let prmry142 = EXTENSION;
%let prmry143 = EXTENSIONS;
%let prmry144 = EXTN;
%let prmry145 = EXTNSN;
%let prmry146 = EXTS;
%let prmry147 = FALL;
%let prmry148 = FALLS;
%let prmry149 = FERRY;
%let prmry150 = FIELD;
%let prmry151 = FIELDS;
%let prmry152 = FLAT;
%let prmry153 = FLATS;
%let prmry154 = FLD;
%let prmry155 = FLDS;
%let prmry156 = FLS;
%let prmry157 = FLT;
%let prmry158 = FLTS;
%let prmry159 = FORD;
%let prmry160 = FORDS;
%let prmry161 = FOREST;
%let prmry162 = FORESTS;
%let prmry163 = FORG;
%let prmry164 = FORGE;
%let prmry165 = FORGES;
%let prmry166 = FORK;
%let prmry167 = FORKS;
%let prmry168 = FORT;
%let prmry169 = FRD;
%let prmry170 = FREEWAY;
%let prmry171 = FREEWY;
%let prmry172 = FRG;
%let prmry173 = FRK;
%let prmry174 = FRKS;
%let prmry175 = FRRY;
%let prmry176 = FRST;
%let prmry177 = FRT;
%let prmry178 = FRWAY;
%let prmry179 = FRWY;
%let prmry180 = FRY;
%let prmry181 = FT;
%let prmry182 = FWY;
%let prmry183 = GARDEN;
%let prmry184 = GARDENS;
%let prmry185 = GARDN;
%let prmry186 = GATEWAY;
%let prmry187 = GATEWY;
%let prmry188 = GATWAY;
%let prmry189 = GDN;
%let prmry190 = GDNS;
%let prmry191 = GLEN;
%let prmry192 = GLENS;
%let prmry193 = GLN;
%let prmry194 = GRDEN;
%let prmry195 = GRDN;
%let prmry196 = GRDNS;
%let prmry197 = GREEN;
%let prmry198 = GREENS;
%let prmry199 = GRN;
%let prmry200 = GROV;
%let prmry201 = GROVE;
%let prmry202 = GROVES;
%let prmry203 = GRV;
%let prmry204 = GTWAY;
%let prmry205 = GTWY;
%let prmry206 = HARB;
%let prmry207 = HARBOR;
%let prmry208 = HARBORS;
%let prmry209 = HARBR;
%let prmry210 = HAVEN;
%let prmry211 = HAVN;
%let prmry212 = HBR;
%let prmry213 = HEIGHT;
%let prmry214 = HEIGHTS;
%let prmry215 = HGTS;
%let prmry216 = HIGHWAY;
%let prmry217 = HIGHWY;
%let prmry218 = HILL;
%let prmry219 = HILLS;
%let prmry220 = HIWAY;
%let prmry221 = HIWY;
%let prmry222 = HL;
%let prmry223 = HLLW;
%let prmry224 = HLS;
%let prmry225 = HOLLOW;
%let prmry226 = HOLLOWS;
%let prmry227 = HOLW;
%let prmry228 = HOLWS;
%let prmry229 = HRBOR;
%let prmry230 = HT;
%let prmry231 = HTS;
%let prmry232 = HVN;
%let prmry233 = HWAY;
%let prmry234 = HWY;
%let prmry235 = INLET;
%let prmry236 = INLT;
%let prmry237 = IS;
%let prmry238 = ISLAND;
%let prmry239 = ISLANDS;
%let prmry240 = ISLE;
%let prmry241 = ISLES;
%let prmry242 = ISLND;
%let prmry243 = ISLNDS;
%let prmry244 = ISS;
%let prmry245 = JCT;
%let prmry246 = JCTION;
%let prmry247 = JCTN;
%let prmry248 = JCTNS;
%let prmry249 = JCTS;
%let prmry250 = JUNCTION;
%let prmry251 = JUNCTIONS;
%let prmry252 = JUNCTN;
%let prmry253 = JUNCTON;
%let prmry254 = KEY;
%let prmry255 = KEYS;
%let prmry256 = KNL;
%let prmry257 = KNLS;
%let prmry258 = KNOL;
%let prmry259 = KNOLL;
%let prmry260 = KNOLLS;
%let prmry261 = KY;
%let prmry262 = KYS;
%let prmry263 = LA;
%let prmry264 = LAKE;
%let prmry265 = LAKES;
%let prmry266 = LAND;
%let prmry267 = LANDING;
%let prmry268 = LANE;
%let prmry269 = LANES;
%let prmry270 = LCK;
%let prmry271 = LCKS;
%let prmry272 = LDG;
%let prmry273 = LDGE;
%let prmry274 = LF;
%let prmry275 = LGT;
%let prmry276 = LIGHT;
%let prmry277 = LIGHTS;
%let prmry278 = LK;
%let prmry279 = LKS;
%let prmry280 = LN;
%let prmry281 = LNDG;
%let prmry282 = LNDNG;
%let prmry283 = LOAF;
%let prmry284 = LOCK;
%let prmry285 = LOCKS;
%let prmry286 = LODG;
%let prmry287 = LODGE;
%let prmry288 = LOOP;
%let prmry289 = LOOPS;
%let prmry290 = MALL;
%let prmry291 = MANOR;
%let prmry292 = MANORS;
%let prmry293 = MDW;
%let prmry294 = MDWS;
%let prmry295 = MEADOW;
%let prmry296 = MEADOWS;
%let prmry297 = MEDOWS;
%let prmry298 = MEWS;
%let prmry299 = MILL;
%let prmry300 = MILLS;
%let prmry301 = MISSION;
%let prmry302 = MISSN;
%let prmry303 = ML;
%let prmry304 = MLS;
%let prmry305 = MNR;
%let prmry306 = MNRS;
%let prmry307 = MNT;
%let prmry308 = MNTAIN;
%let prmry309 = MNTN;
%let prmry310 = MNTNS;
%let prmry311 = MOTORWAY;
%let prmry312 = MOUNT;
%let prmry313 = MOUNTAIN;
%let prmry314 = MOUNTAINS;
%let prmry315 = MOUNTIN;
%let prmry316 = MSN;
%let prmry317 = MSSN;
%let prmry318 = MT;
%let prmry319 = MTIN;
%let prmry320 = MTN;
%let prmry321 = NCK;
%let prmry322 = NECK;
%let prmry323 = ORCH;
%let prmry324 = ORCHARD;
%let prmry325 = ORCHRD;
%let prmry326 = OVAL;
%let prmry327 = OVERPASS;
%let prmry328 = OVL;
%let prmry329 = PARK;
%let prmry330 = PARKS;
%let prmry331 = PARKWAY;
%let prmry332 = PARKWAYS;
%let prmry333 = PARKWY;
%let prmry334 = PASS;
%let prmry335 = PASSAGE;
%let prmry336 = PATH;
%let prmry337 = PATHS;
%let prmry338 = PIKE;
%let prmry339 = PIKES;
%let prmry340 = PINE;
%let prmry341 = PINES;
%let prmry342 = PK;
%let prmry343 = PKWAY;
%let prmry344 = PKWY;
%let prmry345 = PKWYS;
%let prmry346 = PKY;
%let prmry347 = PL;
%let prmry348 = PLACE;
%let prmry349 = PLAIN;
%let prmry350 = PLAINES;
%let prmry351 = PLAINS;
%let prmry352 = PLAZA;
%let prmry353 = PLN;
%let prmry354 = PLNS;
%let prmry355 = PLZ;
%let prmry356 = PLZA;
%let prmry357 = PNES;
%let prmry358 = POINT;
%let prmry359 = POINTS;
%let prmry360 = PORT;
%let prmry361 = PORTS;
%let prmry362 = PR;
%let prmry363 = PRAIRIE;
%let prmry364 = PRARIE;
%let prmry365 = PRK;
%let prmry366 = PRR;
%let prmry367 = PRT;
%let prmry368 = PRTS;
%let prmry369 = PT;
%let prmry370 = PTS;
%let prmry371 = RAD;
%let prmry372 = RADIAL;
%let prmry373 = RADIEL;
%let prmry374 = RADL;
%let prmry375 = RAMP;
%let prmry376 = RANCH;
%let prmry377 = RANCHES;
%let prmry378 = RAPID;
%let prmry379 = RAPIDS;
%let prmry380 = RD;
%let prmry381 = RDG;
%let prmry382 = RDGE;
%let prmry383 = RDGS;
%let prmry384 = RDS;
%let prmry385 = REST;
%let prmry386 = RIDGE;
%let prmry387 = RIDGES;
%let prmry388 = RIV;
%let prmry389 = RIVER;
%let prmry390 = RIVR;
%let prmry391 = RNCH;
%let prmry392 = RNCHS;
%let prmry393 = ROAD;
%let prmry394 = ROADS;
%let prmry395 = ROUTE;
%let prmry396 = ROW;
%let prmry397 = RPD;
%let prmry398 = RPDS;
%let prmry399 = RST;
%let prmry400 = RUE;
%let prmry401 = RUN;
%let prmry402 = RVR;
%let prmry403 = SHL;
%let prmry404 = SHLS;
%let prmry405 = SHOAL;
%let prmry406 = SHOALS;
%let prmry407 = SHOAR;
%let prmry408 = SHOARS;
%let prmry409 = SHORE;
%let prmry410 = SHORES;
%let prmry411 = SHR;
%let prmry412 = SHRS;
%let prmry413 = SKYWAY;
%let prmry414 = SMT;
%let prmry415 = SPG;
%let prmry416 = SPGS;
%let prmry417 = SPNG;
%let prmry418 = SPNGS;
%let prmry419 = SPRING;
%let prmry420 = SPRINGS;
%let prmry421 = SPRNG;
%let prmry422 = SPRNGS;
%let prmry423 = SPUR;
%let prmry424 = SPURS;
%let prmry425 = SQ;
%let prmry426 = SQR;
%let prmry427 = SQRE;
%let prmry428 = SQRS;
%let prmry429 = SQU;
%let prmry430 = SQUARE;
%let prmry431 = SQUARES;
%let prmry432 = ST;
%let prmry433 = STA;
%let prmry434 = STATION;
%let prmry435 = STATN;
%let prmry436 = STN;
%let prmry437 = STR;
%let prmry438 = STRA;
%let prmry439 = STRAV;
%let prmry440 = STRAVE;
%let prmry441 = STRAVEN;
%let prmry442 = STRAVENUE;
%let prmry443 = STRAVN;
%let prmry444 = STREAM;
%let prmry445 = STREET;
%let prmry446 = STREETS;
%let prmry447 = STREME;
%let prmry448 = STRM;
%let prmry449 = STRT;
%let prmry450 = STRVN;
%let prmry451 = STRVNUE;
%let prmry452 = SUMIT;
%let prmry453 = SUMITT;
%let prmry454 = SUMMIT;
%let prmry455 = TER;
%let prmry456 = TERR;
%let prmry457 = TERRACE;
%let prmry458 = THROUGHWAY;
%let prmry459 = TPK;
%let prmry460 = TPKE;
%let prmry461 = TR;
%let prmry462 = TRACE;
%let prmry463 = TRACES;
%let prmry464 = TRACK;
%let prmry465 = TRACKS;
%let prmry466 = TRAFFICWAY;
%let prmry467 = TRAIL;
%let prmry468 = TRAILS;
%let prmry469 = TRAK;
%let prmry470 = TRCE;
%let prmry471 = TRFY;
%let prmry472 = TRK;
%let prmry473 = TRKS;
%let prmry474 = TRL;
%let prmry475 = TRLS;
%let prmry476 = TRNPK;
%let prmry477 = TRPK;
%let prmry478 = TUNEL;
%let prmry479 = TUNL;
%let prmry480 = TUNLS;
%let prmry481 = TUNNEL;
%let prmry482 = TUNNELS;
%let prmry483 = TUNNL;
%let prmry484 = TURNPIKE;
%let prmry485 = TURNPK;
%let prmry486 = UN;
%let prmry487 = UNDERPASS;
%let prmry488 = UNION;
%let prmry489 = UNIONS;
%let prmry490 = VALLEY;
%let prmry491 = VALLEYS;
%let prmry492 = VALLY;
%let prmry493 = VDCT;
%let prmry494 = VIA;
%let prmry495 = VIADCT;
%let prmry496 = VIADUCT;
%let prmry497 = VIEW;
%let prmry498 = VIEWS;
%let prmry499 = VILL;
%let prmry500 = VILLAG;
%let prmry501 = VILLAGE;
%let prmry502 = VILLAGES;
%let prmry503 = VILLE;
%let prmry504 = VILLG;
%let prmry505 = VILLIAGE;
%let prmry506 = VIS;
%let prmry507 = VIST;
%let prmry508 = VISTA;
%let prmry509 = VL;
%let prmry510 = VLG;
%let prmry511 = VLGS;
%let prmry512 = VLLY;
%let prmry513 = VLY;
%let prmry514 = VLYS;
%let prmry515 = VST;
%let prmry516 = VSTA;
%let prmry517 = VW;
%let prmry518 = VWS;
%let prmry519 = WALK;
%let prmry520 = WALKS;
%let prmry521 = WALL;
%let prmry522 = WAY;
%let prmry523 = WAYS;
%let prmry524 = WELL;
%let prmry525 = WELLS;
%let prmry526 = WLS;
%let prmry527 = WY;
%let prmry528 = XING;
%let prmry529 = ALY;
%let prmry530 = ALY;
%let prmry531 = ALY;
%let prmry532 = ALY;
%let prmry533 = ANX;
%let prmry534 = ANX;
%let prmry535 = ANX;
%let prmry536 = ANX;
%let prmry537 = ARC;
%let prmry538 = ARC;
%let prmry539 = AVE;
%let prmry540 = AVE;
%let prmry541 = AVE;
%let prmry542 = AVE;
%let prmry543 = AVE;
%let prmry544 = AVE;
%let prmry545 = AVE;
%let prmry546 = BYU;
%let prmry547 = BYU;
%let prmry548 = BCH;
%let prmry549 = BCH;
%let prmry550 = BND;
%let prmry551 = BLF;
%let prmry552 = BLF;
%let prmry553 = BLF;
%let prmry554 = BLFS;
%let prmry555 = BLVD;
%let prmry556 = BND;
%let prmry557 = BTM;
%let prmry558 = BTM;
%let prmry559 = BTM;
%let prmry560 = BLVD;
%let prmry561 = BLVD;
%let prmry562 = BLVD;
%let prmry563 = BR;
%let prmry564 = BR;
%let prmry565 = BRG;
%let prmry566 = BRG;
%let prmry567 = BRG;
%let prmry568 = BRK;
%let prmry569 = BR;
%let prmry570 = BRK;
%let prmry571 = BRKS;
%let prmry572 = BTM;
%let prmry573 = BG;
%let prmry574 = BGS;
%let prmry575 = BYP;
%let prmry576 = BYP;
%let prmry577 = BYP;
%let prmry578 = BYP;
%let prmry579 = BYP;
%let prmry580 = CP;
%let prmry581 = CYN;
%let prmry582 = CYN;
%let prmry583 = CPE;
%let prmry584 = CSWY;
%let prmry585 = CSWY;
%let prmry586 = CTR;
%let prmry587 = CTR;
%let prmry588 = CTR;
%let prmry589 = CTRS;
%let prmry590 = CTR;
%let prmry591 = CTR;
%let prmry592 = CIR;
%let prmry593 = CIR;
%let prmry594 = CIR;
%let prmry595 = CIR;
%let prmry596 = CIRS;
%let prmry597 = CRK;
%let prmry598 = CLB;
%let prmry599 = CLF;
%let prmry600 = CLFS;
%let prmry601 = CLF;
%let prmry602 = CLFS;
%let prmry603 = CLB;
%let prmry604 = CP;
%let prmry605 = CTR;
%let prmry606 = CTR;
%let prmry607 = CYN;
%let prmry608 = CMN;
%let prmry609 = COR;
%let prmry610 = COR;
%let prmry611 = CORS;
%let prmry612 = CORS;
%let prmry613 = CRSE;
%let prmry614 = CT;
%let prmry615 = CTS;
%let prmry616 = CV;
%let prmry617 = CVS;
%let prmry618 = CP;
%let prmry619 = CPE;
%let prmry620 = CRK;
%let prmry621 = CIR;
%let prmry622 = CIR;
%let prmry623 = CRES;
%let prmry624 = CRK;
%let prmry625 = CRES;
%let prmry626 = CRES;
%let prmry627 = CRES;
%let prmry628 = CRST;
%let prmry629 = CRK;
%let prmry630 = XING;
%let prmry631 = XRD;
%let prmry632 = CRES;
%let prmry633 = CRSE;
%let prmry634 = CRES;
%let prmry635 = CRES;
%let prmry636 = XING;
%let prmry637 = XING;
%let prmry638 = CT;
%let prmry639 = CSWY;
%let prmry640 = CT;
%let prmry641 = CTS;
%let prmry642 = CTR;
%let prmry643 = CURV;
%let prmry644 = CV;
%let prmry645 = CYN;
%let prmry646 = DL;
%let prmry647 = DM;
%let prmry648 = DV;
%let prmry649 = DV;
%let prmry650 = DL;
%let prmry651 = DM;
%let prmry652 = DR;
%let prmry653 = DR;
%let prmry654 = DR;
%let prmry655 = DRS;
%let prmry656 = DR;
%let prmry657 = DV;
%let prmry658 = DV;
%let prmry659 = EST;
%let prmry660 = EST;
%let prmry661 = ESTS;
%let prmry662 = ESTS;
%let prmry663 = EXPY;
%let prmry664 = EXPY;
%let prmry665 = EXPY;
%let prmry666 = EXPY;
%let prmry667 = EXPY;
%let prmry668 = EXPY;
%let prmry669 = EXT;
%let prmry670 = EXT;
%let prmry671 = EXTS;
%let prmry672 = EXT;
%let prmry673 = EXT;
%let prmry674 = EXTS;
%let prmry675 = FALL;
%let prmry676 = FLS;
%let prmry677 = FRY;
%let prmry678 = FLD;
%let prmry679 = FLDS;
%let prmry680 = FLT;
%let prmry681 = FLTS;
%let prmry682 = FLD;
%let prmry683 = FLDS;
%let prmry684 = FLS;
%let prmry685 = FLT;
%let prmry686 = FLTS;
%let prmry687 = FRD;
%let prmry688 = FRDS;
%let prmry689 = FRST;
%let prmry690 = FRST;
%let prmry691 = FRG;
%let prmry692 = FRG;
%let prmry693 = FRGS;
%let prmry694 = FRK;
%let prmry695 = FRKS;
%let prmry696 = FT;
%let prmry697 = FRD;
%let prmry698 = FWY;
%let prmry699 = FWY;
%let prmry700 = FRG;
%let prmry701 = FRK;
%let prmry702 = FRKS;
%let prmry703 = FRY;
%let prmry704 = FRST;
%let prmry705 = FT;
%let prmry706 = FWY;
%let prmry707 = FWY;
%let prmry708 = FRY;
%let prmry709 = FT;
%let prmry710 = FWY;
%let prmry711 = GDN;
%let prmry712 = GDNS;
%let prmry713 = GDN;
%let prmry714 = GTWY;
%let prmry715 = GTWY;
%let prmry716 = GTWY;
%let prmry717 = GDN;
%let prmry718 = GDNS;
%let prmry719 = GLN;
%let prmry720 = GLNS;
%let prmry721 = GLN;
%let prmry722 = GDN;
%let prmry723 = GDN;
%let prmry724 = GDNS;
%let prmry725 = GRN;
%let prmry726 = GRNS;
%let prmry727 = GRN;
%let prmry728 = GRV;
%let prmry729 = GRV;
%let prmry730 = GRVS;
%let prmry731 = GRV;
%let prmry732 = GTWY;
%let prmry733 = GTWY;
%let prmry734 = HBR;
%let prmry735 = HBR;
%let prmry736 = HBRS;
%let prmry737 = HBR;
%let prmry738 = HVN;
%let prmry739 = HVN;
%let prmry740 = HBR;
%let prmry741 = HTS;
%let prmry742 = HTS;
%let prmry743 = HTS;
%let prmry744 = HWY;
%let prmry745 = HWY;
%let prmry746 = HL;
%let prmry747 = HLS;
%let prmry748 = HWY;
%let prmry749 = HWY;
%let prmry750 = HL;
%let prmry751 = HOLW;
%let prmry752 = HLS;
%let prmry753 = HOLW;
%let prmry754 = HOLW;
%let prmry755 = HOLW;
%let prmry756 = HOLW;
%let prmry757 = HBR;
%let prmry758 = HTS;
%let prmry759 = HTS;
%let prmry760 = HVN;
%let prmry761 = HWY;
%let prmry762 = HWY;
%let prmry763 = INLT;
%let prmry764 = INLT;
%let prmry765 = IS;
%let prmry766 = IS;
%let prmry767 = ISS;
%let prmry768 = ISLE;
%let prmry769 = ISLE;
%let prmry770 = IS;
%let prmry771 = ISS;
%let prmry772 = ISS;
%let prmry773 = JCT;
%let prmry774 = JCT;
%let prmry775 = JCT;
%let prmry776 = JCTS;
%let prmry777 = JCTS;
%let prmry778 = JCT;
%let prmry779 = JCTS;
%let prmry780 = JCT;
%let prmry781 = JCT;
%let prmry782 = KY;
%let prmry783 = KYS;
%let prmry784 = KNL;
%let prmry785 = KNLS;
%let prmry786 = KNL;
%let prmry787 = KNL;
%let prmry788 = KNLS;
%let prmry789 = KY;
%let prmry790 = KYS;
%let prmry791 = LN;
%let prmry792 = LK;
%let prmry793 = LKS;
%let prmry794 = LAND;
%let prmry795 = LNDG;
%let prmry796 = LN;
%let prmry797 = LN;
%let prmry798 = LCK;
%let prmry799 = LCKS;
%let prmry800 = LDG;
%let prmry801 = LDG;
%let prmry802 = LF;
%let prmry803 = LGT;
%let prmry804 = LGT;
%let prmry805 = LGTS;
%let prmry806 = LK;
%let prmry807 = LKS;
%let prmry808 = LN;
%let prmry809 = LNDG;
%let prmry810 = LNDG;
%let prmry811 = LF;
%let prmry812 = LCK;
%let prmry813 = LCKS;
%let prmry814 = LDG;
%let prmry815 = LDG;
%let prmry816 = LOOP;
%let prmry817 = LOOP;
%let prmry818 = MALL;
%let prmry819 = MNR;
%let prmry820 = MNRS;
%let prmry821 = MDW;
%let prmry822 = MDWS;
%let prmry823 = MDW;
%let prmry824 = MDWS;
%let prmry825 = MDWS;
%let prmry826 = MEWS;
%let prmry827 = ML;
%let prmry828 = MLS;
%let prmry829 = MSN;
%let prmry830 = MSN;
%let prmry831 = ML;
%let prmry832 = MLS;
%let prmry833 = MNR;
%let prmry834 = MNRS;
%let prmry835 = MT;
%let prmry836 = MTN;
%let prmry837 = MTN;
%let prmry838 = MTNS;
%let prmry839 = MTWY;
%let prmry840 = MT;
%let prmry841 = MTN;
%let prmry842 = MTNS;
%let prmry843 = MTN;
%let prmry844 = MSN;
%let prmry845 = MSN;
%let prmry846 = MT;
%let prmry847 = MTN;
%let prmry848 = MTN;
%let prmry849 = NCK;
%let prmry850 = NCK;
%let prmry851 = ORCH;
%let prmry852 = ORCH;
%let prmry853 = ORCH;
%let prmry854 = OVAL;
%let prmry855 = OPAS;
%let prmry856 = OVAL;
%let prmry857 = PARK;
%let prmry858 = PARK;
%let prmry859 = PKWY;
%let prmry860 = PKWY;
%let prmry861 = PKWY;
%let prmry862 = PASS;
%let prmry863 = PSGE;
%let prmry864 = PATH;
%let prmry865 = PATH;
%let prmry866 = PIKE;
%let prmry867 = PIKE;
%let prmry868 = PNE;
%let prmry869 = PNES;
%let prmry870 = PARK;
%let prmry871 = PKWY;
%let prmry872 = PKWY;
%let prmry873 = PKWY;
%let prmry874 = PKWY;
%let prmry875 = PL;
%let prmry876 = PL;
%let prmry877 = PLN;
%let prmry878 = PLNS;
%let prmry879 = PLNS;
%let prmry880 = PLZ;
%let prmry881 = PLN;
%let prmry882 = PLNS;
%let prmry883 = PLZ;
%let prmry884 = PLZ;
%let prmry885 = PNES;
%let prmry886 = PT;
%let prmry887 = PTS;
%let prmry888 = PRT;
%let prmry889 = PRTS;
%let prmry890 = PR;
%let prmry891 = PR;
%let prmry892 = PR;
%let prmry893 = PARK;
%let prmry894 = PR;
%let prmry895 = PRT;
%let prmry896 = PRTS;
%let prmry897 = PT;
%let prmry898 = PTS;
%let prmry899 = RADL;
%let prmry900 = RADL;
%let prmry901 = RADL;
%let prmry902 = RADL;
%let prmry903 = RAMP;
%let prmry904 = RNCH;
%let prmry905 = RNCH;
%let prmry906 = RPD;
%let prmry907 = RPDS;
%let prmry908 = RD;
%let prmry909 = RDG;
%let prmry910 = RDG;
%let prmry911 = RDGS;
%let prmry912 = RDS;
%let prmry913 = RST;
%let prmry914 = RDG;
%let prmry915 = RDGS;
%let prmry916 = RIV;
%let prmry917 = RIV;
%let prmry918 = RIV;
%let prmry919 = RNCH;
%let prmry920 = RNCH;
%let prmry921 = RD;
%let prmry922 = RDS;
%let prmry923 = RTE;
%let prmry924 = ROW;
%let prmry925 = RPD;
%let prmry926 = RPDS;
%let prmry927 = RST;
%let prmry928 = RUE;
%let prmry929 = RUN;
%let prmry930 = RIV;
%let prmry931 = SHL;
%let prmry932 = SHLS;
%let prmry933 = SHL;
%let prmry934 = SHLS;
%let prmry935 = SHR;
%let prmry936 = SHRS;
%let prmry937 = SHR;
%let prmry938 = SHRS;
%let prmry939 = SHR;
%let prmry940 = SHRS;
%let prmry941 = SKWY;
%let prmry942 = SMT;
%let prmry943 = SPG;
%let prmry944 = SPGS;
%let prmry945 = SPG;
%let prmry946 = SPGS;
%let prmry947 = SPG;
%let prmry948 = SPGS;
%let prmry949 = SPG;
%let prmry950 = SPGS;
%let prmry951 = SPUR;
%let prmry952 = SPUR;
%let prmry953 = SQ;
%let prmry954 = SQ;
%let prmry955 = SQ;
%let prmry956 = SQS;
%let prmry957 = SQ;
%let prmry958 = SQ;
%let prmry959 = SQS;
%let prmry960 = ST;
%let prmry961 = STA;
%let prmry962 = STA;
%let prmry963 = STA;
%let prmry964 = STA;
%let prmry965 = ST;
%let prmry966 = STRA;
%let prmry967 = STRA;
%let prmry968 = STRA;
%let prmry969 = STRA;
%let prmry970 = STRA;
%let prmry971 = STRA;
%let prmry972 = STRM;
%let prmry973 = ST;
%let prmry974 = STS;
%let prmry975 = STRM;
%let prmry976 = STRM;
%let prmry977 = ST;
%let prmry978 = STRA;
%let prmry979 = STRA;
%let prmry980 = SMT;
%let prmry981 = SMT;
%let prmry982 = SMT;
%let prmry983 = TER;
%let prmry984 = TER;
%let prmry985 = TER;
%let prmry986 = TRWY;
%let prmry987 = TPKE;
%let prmry988 = TPKE;
%let prmry989 = TRL;
%let prmry990 = TRCE;
%let prmry991 = TRCE;
%let prmry992 = TRAK;
%let prmry993 = TRAK;
%let prmry994 = TRFY;
%let prmry995 = TRL;
%let prmry996 = TRL;
%let prmry997 = TRAK;
%let prmry998 = TRCE;
%let prmry999 = TRFY;
%let prmry1000 = TRAK;
%let prmry1001 = TRAK;
%let prmry1002 = TRL;
%let prmry1003 = TRL;
%let prmry1004 = TPKE;
%let prmry1005 = TPKE;
%let prmry1006 = TUNL;
%let prmry1007 = TUNL;
%let prmry1008 = TUNL;
%let prmry1009 = TUNL;
%let prmry1010 = TUNL;
%let prmry1011 = TUNL;
%let prmry1012 = TPKE;
%let prmry1013 = TPKE;
%let prmry1014 = UN;
%let prmry1015 = UPAS;
%let prmry1016 = UN;
%let prmry1017 = UNS;
%let prmry1018 = VLY;
%let prmry1019 = VLYS;
%let prmry1020 = VLY;
%let prmry1021 = VIA;
%let prmry1022 = VIA;
%let prmry1023 = VIA;
%let prmry1024 = VIA;
%let prmry1025 = VW;
%let prmry1026 = VWS;
%let prmry1027 = VLG;
%let prmry1028 = VLG;
%let prmry1029 = VLG;
%let prmry1030 = VLGS;
%let prmry1031 = VL;
%let prmry1032 = VLG;
%let prmry1033 = VLG;
%let prmry1034 = VIS;
%let prmry1035 = VIS;
%let prmry1036 = VIS;
%let prmry1037 = VL;
%let prmry1038 = VLG;
%let prmry1039 = VLGS;
%let prmry1040 = VLY;
%let prmry1041 = VLY;
%let prmry1042 = VLYS;
%let prmry1043 = VIS;
%let prmry1044 = VIS;
%let prmry1045 = VW;
%let prmry1046 = VWS;
%let prmry1047 = WALK;
%let prmry1048 = WALK;
%let prmry1049 = WALL;
%let prmry1050 = WAY;
%let prmry1051 = WAYS;
%let prmry1052 = WL;
%let prmry1053 = WLS;
%let prmry1054 = WLS;
%let prmry1055 = WAY;
%let prmry1056 = XING;

%do ii = 1 %to 1056;
testfind = find(&addr_type.street," &&prmry&ii ","i",-99);
if testfind > 0 then &addr_type.street = substr(&addr_type.street,1,find(&addr_type.street," &&prmry&ii ","i",-99)+length(" &&prmry&ii ")-1);
%end;

recodes = "PR";

run;
%mend;


%macro replace_wordnum(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%let wordnum1 = first;
%let wordnum2 = second;
%let wordnum3 = third;
%let wordnum4 = fourth;
%let wordnum5 = fifth;
%let wordnum6 = sixth;
%let wordnum7 = seventh;
%let wordnum8 = eighth;
%let wordnum9 = ninth;
%let wordnum10 = tenth;
%let wordnum11 = eleventh;
%let wordnum12 = twelfth;
%let wordnum13 = thirteenth;
%let wordnum14 = fourteenth;
%let wordnum15 = fifteenth;
%let wordnum16 = sixteenth;
%let wordnum17 = seventeenth;
%let wordnum18 = eighteenth;
%let wordnum19 = nineteenth;
%let wordnum20 = twentieth;

%let numnum1 = 1ST;
%let numnum2 = 2ND;
%let numnum3 = 3RD;
%let numnum4 = 4TH;
%let numnum5 = 5TH;
%let numnum6 = 6TH;
%let numnum7 = 7TH;
%let numnum8 = 8TH;
%let numnum9 = 9TH;
%let numnum10 = 10TH;
%let numnum11 = 11TH;
%let numnum12 = 12TH;
%let numnum13 = 13TH;
%let numnum14 = 14TH;
%let numnum15 = 15TH;
%let numnum16 = 16TH;
%let numnum17 = 17TH;
%let numnum18 = 18TH;
%let numnum19 = 19TH;
%let numnum20 = 20TH;

%let num1 = one;
%let num2 = two;
%let num3 = three;
%let num4 = four;
%let num5 = five;
%let num6 = six;
%let num7 = seven;
%let num8 = eight;
%let num9 = nine;
%let num10 = ten;
%let num11 = eleven;
%let num12 = twelve;
%let num13 = thirteen;
%let num14 = fourteen;
%let num15 = fifteen;
%let num16 = sixteen;
%let num17 = seventeen;
%let num18 = eighteen;
%let num19 = nineteen;
%let num20 = twenty;
%let num21 = twenty one;
%let num22 = twenty two;
%let num23 = twenty three;
%let num24 = twenty four;
%let num25 = twenty five;
%let num26 = twenty six;
%let num27 = twenty seven;
%let num28 = twenty eight;
%let num29 = twenty nine;
%let num30 = thirty ;
%let num31 = thirty one;
%let num32 = thirty two;
%let num33 = thirty three;
%let num34 = thirty four;
%let num35 = thirty five;
%let num36 = thirty six;
%let num37 = thirty seven;
%let num38 = thirty eight;
%let num39 = thirty nine;
%let num40 = forty ;
%let num41 = forty one;
%let num42 = forty two;
%let num43 = forty three;
%let num44 = forty four;
%let num45 = forty five;
%let num46 = forty six;
%let num47 = forty seven;
%let num48 = forty eight;
%let num49 = forty nine;
%let num50 = fifty ;
%let num51 = fifty one;
%let num52 = fifty two;
%let num53 = fifty three;
%let num54 = fifty four;
%let num55 = fifty five;
%let num56 = fifty six;
%let num57 = fifty seven;
%let num58 = fifty eight;
%let num59 = fifty nine;
%let num60 = sixty ;
%let num61 = sixty one;
%let num62 = sixty two;
%let num63 = sixty three;
%let num64 = sixty four;
%let num65 = sixty five;
%let num66 = sixty six;
%let num67 = sixty seven;
%let num68 = sixty eight;
%let num69 = sixty nine;
%let num70 = seventy ;
%let num71 = seventy one;
%let num72 = seventy two;
%let num73 = seventy three;
%let num74 = seventy four;
%let num75 = seventy five;
%let num76 = seventy six;
%let num77 = seventy seven;
%let num78 = seventy eight;
%let num79 = seventy nine;
%let num80 = eighty ;
%let num81 = eighty one;
%let num82 = eighty two;
%let num83 = eighty three;
%let num84 = eighty four;
%let num85 = eighty five;
%let num86 = eighty six;
%let num87 = eighty seven;
%let num88 = eighty eight;
%let num89 = eighty nine;
%let num90 = ninety ;
%let num91 = ninety one;
%let num92 = ninety two;
%let num93 = ninety three;
%let num94 = ninety four;
%let num95 = ninety five;
%let num96 = ninety six;
%let num97 = ninety seven;
%let num98 = ninety eight;
%let num99 = ninety nine;
%let num100 = one hundred ;


%do ii = 1 %to 20;
if find(&addr_type.street," &&wordnum&ii ","i",-99) = 1 then 
  &addr_type.street = "&&numnum&ii " ||
           substr(&addr_type.street,find(&addr_type.street," &&wordnum&ii ","i",-99)+length(" &&wordnum&ii "),99);

if find(&addr_type.street," &&wordnum&ii ","i",-99) > 1 then 
  &addr_type.street = substr(&addr_type.street,1,find(&addr_type.street," &&wordnum&ii ","i",-99)-1) ||
           " &&numnum&ii " ||
           substr(&addr_type.street,find(&addr_type.street," &&wordnum&ii ","i",-99)+length(" &&wordnum&ii "),99);
%end;


%do ii = 1 %to 100;
if upcase(substr(&addr_type.street,1,length("&&num&ii "))) = upcase("&&num&ii ") then substr(&addr_type.street,1,length("&&num&ii ")) = upcase("&ii ");
%end;

recodes = "WN";


run;
%mend;



%macro group_streetnum(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data (drop = match maxchar);
set ADDRESS.&in_addr_data ;

%let ord0 = 0th;
%let ord1 = 1st;
%let ord2 = 2nd;
%let ord3 = 3rd;
%let ord4 = 4th;
%let ord5 = 5th;
%let ord6 = 6th;
%let ord7 = 7th;
%let ord8 = 8th;
%let ord9 = 9th;
%let ord10 = 10th;
%let ord11 = 11th;
%let ord12 = 12th;
%let ord13 = 13th;
%let ord14 = 14th;
%let ord15 = 15th;
%let ord16 = 16th;
%let ord17 = 17th;
%let ord18 = 18th;
%let ord19 = 19th;
%let ord20 = 20th;

maxchar = 6;
match = 0;
%do ones = 10 %to 19;
if find(&addr_type.street,"&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"&&ord&ones",'i',1)-1);
if find(&addr_type.street,"1&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"1&&ord&ones",'i',1)-1);
if find(&addr_type.street,"2&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"&&1ord&ones",'i',1)-1);
if find(&addr_type.street,"3&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"&&3ord&ones",'i',1)-1);
if find(&addr_type.street,"4&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"4&&ord&ones",'i',1)-1);
%end;

%do ones = 0 %to 9;
if find(&addr_type.street,"&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"&&ord&ones",'i',1)-1);
%do tens = 1 %to 49;
if find(&addr_type.street,"&tens&&ord&ones",'i')>0 then maxchar = min(maxchar,find(&addr_type.street,"&tens&&ord&ones",'i',1)-1);
if find(&addr_type.street,"&tens&&ord&ones",'i')>0 then match = 1;
%end;
%end;

%do times = 1 %to 6;
%do i = 0 %to 9;
%do j = 0 %to 9;
substr(&addr_type.street,1,maxchar)=tranwrd(substr(&addr_type.street,1,maxchar),"&i &j","&i&j");
%end;
%end;
%end;

recodes = "GS";

run;
%mend;



%macro drop_secondaries(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%let secnd1 = STE;
%let secnd2 = SUITE;
%let secnd3 = APARTMENT;
%let secnd4 = BASEMENT;
%let secnd5 = BUILDING;
%let secnd6 = DEPARTMENT;
%let secnd7 = FLOOR;
%let secnd8 = FRONT;
%let secnd9 = HANGAR;
%let secnd10 = LOBBY;
%let secnd11 = LOT;
%let secnd12 = LOWER;
%let secnd13 = OFFICE;
%let secnd14 = PENTHOUSE;
%let secnd15 = PIER;
%let secnd16 = REAR;
%let secnd17 = ROOM;
%let secnd18 = SIDE;
%let secnd19 = SLIP;
%let secnd20 = SPACE;
%let secnd21 = STOP;
%let secnd22 = TRAILER;
%let secnd23 = UNIT;
%let secnd24 = UPPER;
%let secnd25 = APT;
%let secnd26 = BSMT;
%let secnd27 = BLDG;
%let secnd28 = DEPT;
%let secnd29 = FL;
%let secnd30 = FRNT;
%let secnd31 = HNGR;
%let secnd32 = LBBY;
%let secnd33 = LOT;
%let secnd34 = LOWR;
%let secnd35 = OFC;
%let secnd36 = PH;
%let secnd37 = PIER;
%let secnd38 = REAR;
%let secnd39 = RM;
%let secnd40 = SIDE;
%let secnd41 = SLIP;
%let secnd42 = SPC;
%let secnd43 = STOP;
%let secnd44 = TRLR;
%let secnd45 = UNIT;
%let secnd46 = UPPR;

%let ord0 = 0th;
%let ord1 = 1st;
%let ord2 = 2nd;
%let ord3 = 3rd;
%let ord4 = 4th;
%let ord5 = 5th;
%let ord6 = 6th;
%let ord7 = 7th;
%let ord8 = 8th;
%let ord9 = 9th;
%let ord10 = 10th;
%let ord11 = 11th;
%let ord12 = 12th;
%let ord13 = 13th;
%let ord14 = 14th;
%let ord15 = 15th;
%let ord16 = 16th;
%let ord17 = 17th;
%let ord18 = 18th;
%let ord19 = 19th;

%do ii = 1 %to 46;

%do ones = 0 %to 9;
if find(&addr_type.street," &&ord&ones floor ",'i')>0 then &addr_type.street = substr(&addr_type.street,1,find(&addr_type.street," &&ord&ones floor ","i",-99)-1);
%do tens = 1 %to 29;
if find(&addr_type.street," &tens&&ord&ones floor ",'i')>0 then &addr_type.street = substr(&addr_type.street,1,find(&addr_type.street," &tens&&ord&ones floor ","i",-99)-1);
%end;
%end;

testfind = find(&addr_type.street," &&secnd&ii ","i",-99);
if testfind > 0 then &addr_type.street = substr(&addr_type.street,1,find(&addr_type.street," &&secnd&ii ","i",-99)-1);

%end;

recodes = "DS";

run;
%mend;



%macro abbreviate(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%let word1 = ALLEE;
%let word2 = ALLEY;
%let word3 = ALLY;
%let word4 = ALY;
%let word5 = ANEX;
%let word6 = ANNEX;
%let word7 = ANNX;
%let word8 = ANX;
%let word9 = ARC;
%let word10 = ARCADE;
%let word11 = AV;
%let word12 = AVE;
%let word13 = AVEN;
%let word14 = AVENU;
%let word15 = AVENUE;
%let word16 = AVN;
%let word17 = AVNUE;
%let word18 = BAYOO;
%let word19 = BAYOU;
%let word20 = BCH;
%let word21 = BEACH;
%let word22 = BEND;
%let word23 = BLF;
%let word24 = BLUF;
%let word25 = BLUFF;
%let word26 = BLUFFS;
%let word27 = BLVD;
%let word28 = BND;
%let word29 = BOT;
%let word30 = BOTTM;
%let word31 = BOTTOM;
%let word32 = BOUL;
%let word33 = BOULEVARD;
%let word34 = BOULV;
%let word35 = BR;
%let word36 = BRANCH;
%let word37 = BRDGE;
%let word38 = BRG;
%let word39 = BRIDGE;
%let word40 = BRK;
%let word41 = BRNCH;
%let word42 = BROOK;
%let word43 = BROOKS;
%let word44 = BTM;
%let word45 = BURG;
%let word46 = BURGS;
%let word47 = BYP;
%let word48 = BYPA;
%let word49 = BYPAS;
%let word50 = BYPASS;
%let word51 = BYPS;
%let word52 = CAMP;
%let word53 = CANYN;
%let word54 = CANYON;
%let word55 = CAPE;
%let word56 = CAUSEWAY;
%let word57 = CAUSWAY;
%let word58 = CEN;
%let word59 = CENT;
%let word60 = CENTER;
%let word61 = CENTERS;
%let word62 = CENTR;
%let word63 = CENTRE;
%let word64 = CIR;
%let word65 = CIRC;
%let word66 = CIRCL;
%let word67 = CIRCLE;
%let word68 = CIRCLES;
%let word69 = CK;
%let word70 = CLB;
%let word71 = CLF;
%let word72 = CLFS;
%let word73 = CLIFF;
%let word74 = CLIFFS;
%let word75 = CLUB;
%let word76 = CMP;
%let word77 = CNTER;
%let word78 = CNTR;
%let word79 = CNYN;
%let word80 = COMMON;
%let word81 = COR;
%let word82 = CORNER;
%let word83 = CORNERS;
%let word84 = CORS;
%let word85 = COURSE;
%let word86 = COURT;
%let word87 = COURTS;
%let word88 = COVE;
%let word89 = COVES;
%let word90 = CP;
%let word91 = CPE;
%let word92 = CR;
%let word93 = CRCL;
%let word94 = CRCLE;
%let word95 = CRECENT;
%let word96 = CREEK;
%let word97 = CRES;
%let word98 = CRESCENT;
%let word99 = CRESENT;
%let word100 = CREST;
%let word101 = CRK;
%let word102 = CROSSING;
%let word103 = CROSSROAD;
%let word104 = CRSCNT;
%let word105 = CRSE;
%let word106 = CRSENT;
%let word107 = CRSNT;
%let word108 = CRSSING;
%let word109 = CRSSNG;
%let word110 = CRT;
%let word111 = CSWY;
%let word112 = CT;
%let word113 = CT;
%let word114 = CTR;
%let word115 = CURVE;
%let word116 = CV;
%let word117 = CYN;
%let word118 = DALE;
%let word119 = DAM;
%let word120 = DIV;
%let word121 = DIVIDE;
%let word122 = DL;
%let word123 = DM;
%let word124 = DR;
%let word125 = DRIV;
%let word126 = DRIVE;
%let word127 = DRIVES;
%let word128 = DRV;
%let word129 = DV;
%let word130 = DVD;
%let word131 = EST;
%let word132 = ESTATE;
%let word133 = ESTATES;
%let word134 = ESTS;
%let word135 = EXP;
%let word136 = EXPR;
%let word137 = EXPRESS;
%let word138 = EXPRESSWAY;
%let word139 = EXPW;
%let word140 = EXPY;
%let word141 = EXT;
%let word142 = EXTENSION;
%let word143 = EXTENSIONS;
%let word144 = EXTN;
%let word145 = EXTNSN;
%let word146 = EXTS;
%let word147 = FALL;
%let word148 = FALLS;
%let word149 = FERRY;
%let word150 = FIELD;
%let word151 = FIELDS;
%let word152 = FLAT;
%let word153 = FLATS;
%let word154 = FLD;
%let word155 = FLDS;
%let word156 = FLS;
%let word157 = FLT;
%let word158 = FLTS;
%let word159 = FORD;
%let word160 = FORDS;
%let word161 = FOREST;
%let word162 = FORESTS;
%let word163 = FORG;
%let word164 = FORGE;
%let word165 = FORGES;
%let word166 = FORK;
%let word167 = FORKS;
%let word168 = FORT;
%let word169 = FRD;
%let word170 = FREEWAY;
%let word171 = FREEWY;
%let word172 = FRG;
%let word173 = FRK;
%let word174 = FRKS;
%let word175 = FRRY;
%let word176 = FRST;
%let word177 = FRT;
%let word178 = FRWAY;
%let word179 = FRWY;
%let word180 = FRY;
%let word181 = FT;
%let word182 = FWY;
%let word183 = GARDEN;
%let word184 = GARDENS;
%let word185 = GARDN;
%let word186 = GATEWAY;
%let word187 = GATEWY;
%let word188 = GATWAY;
%let word189 = GDN;
%let word190 = GDNS;
%let word191 = GLEN;
%let word192 = GLENS;
%let word193 = GLN;
%let word194 = GRDEN;
%let word195 = GRDN;
%let word196 = GRDNS;
%let word197 = GREEN;
%let word198 = GREENS;
%let word199 = GRN;
%let word200 = GROV;
%let word201 = GROVE;
%let word202 = GROVES;
%let word203 = GRV;
%let word204 = GTWAY;
%let word205 = GTWY;
%let word206 = HARB;
%let word207 = HARBOR;
%let word208 = HARBORS;
%let word209 = HARBR;
%let word210 = HAVEN;
%let word211 = HAVN;
%let word212 = HBR;
%let word213 = HEIGHT;
%let word214 = HEIGHTS;
%let word215 = HGTS;
%let word216 = HIGHWAY;
%let word217 = HIGHWY;
%let word218 = HILL;
%let word219 = HILLS;
%let word220 = HIWAY;
%let word221 = HIWY;
%let word222 = HL;
%let word223 = HLLW;
%let word224 = HLS;
%let word225 = HOLLOW;
%let word226 = HOLLOWS;
%let word227 = HOLW;
%let word228 = HOLWS;
%let word229 = HRBOR;
%let word230 = HT;
%let word231 = HTS;
%let word232 = HVN;
%let word233 = HWAY;
%let word234 = HWY;
%let word235 = INLET;
%let word236 = INLT;
%let word237 = IS;
%let word238 = ISLAND;
%let word239 = ISLANDS;
%let word240 = ISLE;
%let word241 = ISLES;
%let word242 = ISLND;
%let word243 = ISLNDS;
%let word244 = ISS;
%let word245 = JCT;
%let word246 = JCTION;
%let word247 = JCTN;
%let word248 = JCTNS;
%let word249 = JCTS;
%let word250 = JUNCTION;
%let word251 = JUNCTIONS;
%let word252 = JUNCTN;
%let word253 = JUNCTON;
%let word254 = KEY;
%let word255 = KEYS;
%let word256 = KNL;
%let word257 = KNLS;
%let word258 = KNOL;
%let word259 = KNOLL;
%let word260 = KNOLLS;
%let word261 = KY;
%let word262 = KYS;
%let word263 = LA;
%let word264 = LAKE;
%let word265 = LAKES;
%let word266 = LAND;
%let word267 = LANDING;
%let word268 = LANE;
%let word269 = LANES;
%let word270 = LCK;
%let word271 = LCKS;
%let word272 = LDG;
%let word273 = LDGE;
%let word274 = LF;
%let word275 = LGT;
%let word276 = LIGHT;
%let word277 = LIGHTS;
%let word278 = LK;
%let word279 = LKS;
%let word280 = LN;
%let word281 = LNDG;
%let word282 = LNDNG;
%let word283 = LOAF;
%let word284 = LOCK;
%let word285 = LOCKS;
%let word286 = LODG;
%let word287 = LODGE;
%let word288 = LOOP;
%let word289 = LOOPS;
%let word290 = MALL;
%let word291 = MANOR;
%let word292 = MANORS;
%let word293 = MDW;
%let word294 = MDWS;
%let word295 = MEADOW;
%let word296 = MEADOWS;
%let word297 = MEDOWS;
%let word298 = MEWS;
%let word299 = MILL;
%let word300 = MILLS;
%let word301 = MISSION;
%let word302 = MISSN;
%let word303 = ML;
%let word304 = MLS;
%let word305 = MNR;
%let word306 = MNRS;
%let word307 = MNT;
%let word308 = MNTAIN;
%let word309 = MNTN;
%let word310 = MNTNS;
%let word311 = MOTORWAY;
%let word312 = MOUNT;
%let word313 = MOUNTAIN;
%let word314 = MOUNTAINS;
%let word315 = MOUNTIN;
%let word316 = MSN;
%let word317 = MSSN;
%let word318 = MT;
%let word319 = MTIN;
%let word320 = MTN;
%let word321 = NCK;
%let word322 = NECK;
%let word323 = ORCH;
%let word324 = ORCHARD;
%let word325 = ORCHRD;
%let word326 = OVAL;
%let word327 = OVERPASS;
%let word328 = OVL;
%let word329 = PARK;
%let word330 = PARKS;
%let word331 = PARKWAY;
%let word332 = PARKWAYS;
%let word333 = PARKWY;
%let word334 = PASS;
%let word335 = PASSAGE;
%let word336 = PATH;
%let word337 = PATHS;
%let word338 = PIKE;
%let word339 = PIKES;
%let word340 = PINE;
%let word341 = PINES;
%let word342 = PK;
%let word343 = PKWAY;
%let word344 = PKWY;
%let word345 = PKWYS;
%let word346 = PKY;
%let word347 = PL;
%let word348 = PLACE;
%let word349 = PLAIN;
%let word350 = PLAINES;
%let word351 = PLAINS;
%let word352 = PLAZA;
%let word353 = PLN;
%let word354 = PLNS;
%let word355 = PLZ;
%let word356 = PLZA;
%let word357 = PNES;
%let word358 = POINT;
%let word359 = POINTS;
%let word360 = PORT;
%let word361 = PORTS;
%let word362 = PR;
%let word363 = PRAIRIE;
%let word364 = PRARIE;
%let word365 = PRK;
%let word366 = PRR;
%let word367 = PRT;
%let word368 = PRTS;
%let word369 = PT;
%let word370 = PTS;
%let word371 = RAD;
%let word372 = RADIAL;
%let word373 = RADIEL;
%let word374 = RADL;
%let word375 = RAMP;
%let word376 = RANCH;
%let word377 = RANCHES;
%let word378 = RAPID;
%let word379 = RAPIDS;
%let word380 = RD;
%let word381 = RDG;
%let word382 = RDGE;
%let word383 = RDGS;
%let word384 = RDS;
%let word385 = REST;
%let word386 = RIDGE;
%let word387 = RIDGES;
%let word388 = RIV;
%let word389 = RIVER;
%let word390 = RIVR;
%let word391 = RNCH;
%let word392 = RNCHS;
%let word393 = ROAD;
%let word394 = ROADS;
%let word395 = ROUTE;
%let word396 = ROW;
%let word397 = RPD;
%let word398 = RPDS;
%let word399 = RST;
%let word400 = RUE;
%let word401 = RUN;
%let word402 = RVR;
%let word403 = SHL;
%let word404 = SHLS;
%let word405 = SHOAL;
%let word406 = SHOALS;
%let word407 = SHOAR;
%let word408 = SHOARS;
%let word409 = SHORE;
%let word410 = SHORES;
%let word411 = SHR;
%let word412 = SHRS;
%let word413 = SKYWAY;
%let word414 = SMT;
%let word415 = SPG;
%let word416 = SPGS;
%let word417 = SPNG;
%let word418 = SPNGS;
%let word419 = SPRING;
%let word420 = SPRINGS;
%let word421 = SPRNG;
%let word422 = SPRNGS;
%let word423 = SPUR;
%let word424 = SPURS;
%let word425 = SQ;
%let word426 = SQR;
%let word427 = SQRE;
%let word428 = SQRS;
%let word429 = SQU;
%let word430 = SQUARE;
%let word431 = SQUARES;
%let word432 = ST;
%let word433 = STA;
%let word434 = STATION;
%let word435 = STATN;
%let word436 = STN;
%let word437 = STR;
%let word438 = STRA;
%let word439 = STRAV;
%let word440 = STRAVE;
%let word441 = STRAVEN;
%let word442 = STRAVENUE;
%let word443 = STRAVN;
%let word444 = STREAM;
%let word445 = STREET;
%let word446 = STREETS;
%let word447 = STREME;
%let word448 = STRM;
%let word449 = STRT;
%let word450 = STRVN;
%let word451 = STRVNUE;
%let word452 = SUMIT;
%let word453 = SUMITT;
%let word454 = SUMMIT;
%let word455 = TER;
%let word456 = TERR;
%let word457 = TERRACE;
%let word458 = THROUGHWAY;
%let word459 = TPK;
%let word460 = TPKE;
%let word461 = TR;
%let word462 = TRACE;
%let word463 = TRACES;
%let word464 = TRACK;
%let word465 = TRACKS;
%let word466 = TRAFFICWAY;
%let word467 = TRAIL;
%let word468 = TRAILS;
%let word469 = TRAK;
%let word470 = TRCE;
%let word471 = TRFY;
%let word472 = TRK;
%let word473 = TRKS;
%let word474 = TRL;
%let word475 = TRLS;
%let word476 = TRNPK;
%let word477 = TRPK;
%let word478 = TUNEL;
%let word479 = TUNL;
%let word480 = TUNLS;
%let word481 = TUNNEL;
%let word482 = TUNNELS;
%let word483 = TUNNL;
%let word484 = TURNPIKE;
%let word485 = TURNPK;
%let word486 = UN;
%let word487 = UNDERPASS;
%let word488 = UNION;
%let word489 = UNIONS;
%let word490 = VALLEY;
%let word491 = VALLEYS;
%let word492 = VALLY;
%let word493 = VDCT;
%let word494 = VIA;
%let word495 = VIADCT;
%let word496 = VIADUCT;
%let word497 = VIEW;
%let word498 = VIEWS;
%let word499 = VILL;
%let word500 = VILLAG;
%let word501 = VILLAGE;
%let word502 = VILLAGES;
%let word503 = VILLE;
%let word504 = VILLG;
%let word505 = VILLIAGE;
%let word506 = VIS;
%let word507 = VIST;
%let word508 = VISTA;
%let word509 = VL;
%let word510 = VLG;
%let word511 = VLGS;
%let word512 = VLLY;
%let word513 = VLY;
%let word514 = VLYS;
%let word515 = VST;
%let word516 = VSTA;
%let word517 = VW;
%let word518 = VWS;
%let word519 = WALK;
%let word520 = WALKS;
%let word521 = WALL;
%let word522 = WAY;
%let word523 = WAYS;
%let word524 = WELL;
%let word525 = WELLS;
%let word526 = WLS;
%let word527 = WY;
%let word528 = XING;

%let abbrev1 = ALY;
%let abbrev2 = ALY;
%let abbrev3 = ALY;
%let abbrev4 = ALY;
%let abbrev5 = ANX;
%let abbrev6 = ANX;
%let abbrev7 = ANX;
%let abbrev8 = ANX;
%let abbrev9 = ARC;
%let abbrev10 = ARC;
%let abbrev11 = AVE;
%let abbrev12 = AVE;
%let abbrev13 = AVE;
%let abbrev14 = AVE;
%let abbrev15 = AVE;
%let abbrev16 = AVE;
%let abbrev17 = AVE;
%let abbrev18 = BYU;
%let abbrev19 = BYU;
%let abbrev20 = BCH;
%let abbrev21 = BCH;
%let abbrev22 = BND;
%let abbrev23 = BLF;
%let abbrev24 = BLF;
%let abbrev25 = BLF;
%let abbrev26 = BLFS;
%let abbrev27 = BLVD;
%let abbrev28 = BND;
%let abbrev29 = BTM;
%let abbrev30 = BTM;
%let abbrev31 = BTM;
%let abbrev32 = BLVD;
%let abbrev33 = BLVD;
%let abbrev34 = BLVD;
%let abbrev35 = BR;
%let abbrev36 = BR;
%let abbrev37 = BRG;
%let abbrev38 = BRG;
%let abbrev39 = BRG;
%let abbrev40 = BRK;
%let abbrev41 = BR;
%let abbrev42 = BRK;
%let abbrev43 = BRKS;
%let abbrev44 = BTM;
%let abbrev45 = BG;
%let abbrev46 = BGS;
%let abbrev47 = BYP;
%let abbrev48 = BYP;
%let abbrev49 = BYP;
%let abbrev50 = BYP;
%let abbrev51 = BYP;
%let abbrev52 = CP;
%let abbrev53 = CYN;
%let abbrev54 = CYN;
%let abbrev55 = CPE;
%let abbrev56 = CSWY;
%let abbrev57 = CSWY;
%let abbrev58 = CTR;
%let abbrev59 = CTR;
%let abbrev60 = CTR;
%let abbrev61 = CTRS;
%let abbrev62 = CTR;
%let abbrev63 = CTR;
%let abbrev64 = CIR;
%let abbrev65 = CIR;
%let abbrev66 = CIR;
%let abbrev67 = CIR;
%let abbrev68 = CIRS;
%let abbrev69 = CRK;
%let abbrev70 = CLB;
%let abbrev71 = CLF;
%let abbrev72 = CLFS;
%let abbrev73 = CLF;
%let abbrev74 = CLFS;
%let abbrev75 = CLB;
%let abbrev76 = CP;
%let abbrev77 = CTR;
%let abbrev78 = CTR;
%let abbrev79 = CYN;
%let abbrev80 = CMN;
%let abbrev81 = COR;
%let abbrev82 = COR;
%let abbrev83 = CORS;
%let abbrev84 = CORS;
%let abbrev85 = CRSE;
%let abbrev86 = CT;
%let abbrev87 = CTS;
%let abbrev88 = CV;
%let abbrev89 = CVS;
%let abbrev90 = CP;
%let abbrev91 = CPE;
%let abbrev92 = CRK;
%let abbrev93 = CIR;
%let abbrev94 = CIR;
%let abbrev95 = CRES;
%let abbrev96 = CRK;
%let abbrev97 = CRES;
%let abbrev98 = CRES;
%let abbrev99 = CRES;
%let abbrev100 = CRST;
%let abbrev101 = CRK;
%let abbrev102 = XING;
%let abbrev103 = XRD;
%let abbrev104 = CRES;
%let abbrev105 = CRSE;
%let abbrev106 = CRES;
%let abbrev107 = CRES;
%let abbrev108 = XING;
%let abbrev109 = XING;
%let abbrev110 = CT;
%let abbrev111 = CSWY;
%let abbrev112 = CT;
%let abbrev113 = CTS;
%let abbrev114 = CTR;
%let abbrev115 = CURV;
%let abbrev116 = CV;
%let abbrev117 = CYN;
%let abbrev118 = DL;
%let abbrev119 = DM;
%let abbrev120 = DV;
%let abbrev121 = DV;
%let abbrev122 = DL;
%let abbrev123 = DM;
%let abbrev124 = DR;
%let abbrev125 = DR;
%let abbrev126 = DR;
%let abbrev127 = DRS;
%let abbrev128 = DR;
%let abbrev129 = DV;
%let abbrev130 = DV;
%let abbrev131 = EST;
%let abbrev132 = EST;
%let abbrev133 = ESTS;
%let abbrev134 = ESTS;
%let abbrev135 = EXPY;
%let abbrev136 = EXPY;
%let abbrev137 = EXPY;
%let abbrev138 = EXPY;
%let abbrev139 = EXPY;
%let abbrev140 = EXPY;
%let abbrev141 = EXT;
%let abbrev142 = EXT;
%let abbrev143 = EXTS;
%let abbrev144 = EXT;
%let abbrev145 = EXT;
%let abbrev146 = EXTS;
%let abbrev147 = FALL;
%let abbrev148 = FLS;
%let abbrev149 = FRY;
%let abbrev150 = FLD;
%let abbrev151 = FLDS;
%let abbrev152 = FLT;
%let abbrev153 = FLTS;
%let abbrev154 = FLD;
%let abbrev155 = FLDS;
%let abbrev156 = FLS;
%let abbrev157 = FLT;
%let abbrev158 = FLTS;
%let abbrev159 = FRD;
%let abbrev160 = FRDS;
%let abbrev161 = FRST;
%let abbrev162 = FRST;
%let abbrev163 = FRG;
%let abbrev164 = FRG;
%let abbrev165 = FRGS;
%let abbrev166 = FRK;
%let abbrev167 = FRKS;
%let abbrev168 = FT;
%let abbrev169 = FRD;
%let abbrev170 = FWY;
%let abbrev171 = FWY;
%let abbrev172 = FRG;
%let abbrev173 = FRK;
%let abbrev174 = FRKS;
%let abbrev175 = FRY;
%let abbrev176 = FRST;
%let abbrev177 = FT;
%let abbrev178 = FWY;
%let abbrev179 = FWY;
%let abbrev180 = FRY;
%let abbrev181 = FT;
%let abbrev182 = FWY;
%let abbrev183 = GDN;
%let abbrev184 = GDNS;
%let abbrev185 = GDN;
%let abbrev186 = GTWY;
%let abbrev187 = GTWY;
%let abbrev188 = GTWY;
%let abbrev189 = GDN;
%let abbrev190 = GDNS;
%let abbrev191 = GLN;
%let abbrev192 = GLNS;
%let abbrev193 = GLN;
%let abbrev194 = GDN;
%let abbrev195 = GDN;
%let abbrev196 = GDNS;
%let abbrev197 = GRN;
%let abbrev198 = GRNS;
%let abbrev199 = GRN;
%let abbrev200 = GRV;
%let abbrev201 = GRV;
%let abbrev202 = GRVS;
%let abbrev203 = GRV;
%let abbrev204 = GTWY;
%let abbrev205 = GTWY;
%let abbrev206 = HBR;
%let abbrev207 = HBR;
%let abbrev208 = HBRS;
%let abbrev209 = HBR;
%let abbrev210 = HVN;
%let abbrev211 = HVN;
%let abbrev212 = HBR;
%let abbrev213 = HTS;
%let abbrev214 = HTS;
%let abbrev215 = HTS;
%let abbrev216 = HWY;
%let abbrev217 = HWY;
%let abbrev218 = HL;
%let abbrev219 = HLS;
%let abbrev220 = HWY;
%let abbrev221 = HWY;
%let abbrev222 = HL;
%let abbrev223 = HOLW;
%let abbrev224 = HLS;
%let abbrev225 = HOLW;
%let abbrev226 = HOLW;
%let abbrev227 = HOLW;
%let abbrev228 = HOLW;
%let abbrev229 = HBR;
%let abbrev230 = HTS;
%let abbrev231 = HTS;
%let abbrev232 = HVN;
%let abbrev233 = HWY;
%let abbrev234 = HWY;
%let abbrev235 = INLT;
%let abbrev236 = INLT;
%let abbrev237 = IS;
%let abbrev238 = IS;
%let abbrev239 = ISS;
%let abbrev240 = ISLE;
%let abbrev241 = ISLE;
%let abbrev242 = IS;
%let abbrev243 = ISS;
%let abbrev244 = ISS;
%let abbrev245 = JCT;
%let abbrev246 = JCT;
%let abbrev247 = JCT;
%let abbrev248 = JCTS;
%let abbrev249 = JCTS;
%let abbrev250 = JCT;
%let abbrev251 = JCTS;
%let abbrev252 = JCT;
%let abbrev253 = JCT;
%let abbrev254 = KY;
%let abbrev255 = KYS;
%let abbrev256 = KNL;
%let abbrev257 = KNLS;
%let abbrev258 = KNL;
%let abbrev259 = KNL;
%let abbrev260 = KNLS;
%let abbrev261 = KY;
%let abbrev262 = KYS;
%let abbrev263 = LN;
%let abbrev264 = LK;
%let abbrev265 = LKS;
%let abbrev266 = LAND;
%let abbrev267 = LNDG;
%let abbrev268 = LN;
%let abbrev269 = LN;
%let abbrev270 = LCK;
%let abbrev271 = LCKS;
%let abbrev272 = LDG;
%let abbrev273 = LDG;
%let abbrev274 = LF;
%let abbrev275 = LGT;
%let abbrev276 = LGT;
%let abbrev277 = LGTS;
%let abbrev278 = LK;
%let abbrev279 = LKS;
%let abbrev280 = LN;
%let abbrev281 = LNDG;
%let abbrev282 = LNDG;
%let abbrev283 = LF;
%let abbrev284 = LCK;
%let abbrev285 = LCKS;
%let abbrev286 = LDG;
%let abbrev287 = LDG;
%let abbrev288 = LOOP;
%let abbrev289 = LOOP;
%let abbrev290 = MALL;
%let abbrev291 = MNR;
%let abbrev292 = MNRS;
%let abbrev293 = MDW;
%let abbrev294 = MDWS;
%let abbrev295 = MDW;
%let abbrev296 = MDWS;
%let abbrev297 = MDWS;
%let abbrev298 = MEWS;
%let abbrev299 = ML;
%let abbrev300 = MLS;
%let abbrev301 = MSN;
%let abbrev302 = MSN;
%let abbrev303 = ML;
%let abbrev304 = MLS;
%let abbrev305 = MNR;
%let abbrev306 = MNRS;
%let abbrev307 = MT;
%let abbrev308 = MTN;
%let abbrev309 = MTN;
%let abbrev310 = MTNS;
%let abbrev311 = MTWY;
%let abbrev312 = MT;
%let abbrev313 = MTN;
%let abbrev314 = MTNS;
%let abbrev315 = MTN;
%let abbrev316 = MSN;
%let abbrev317 = MSN;
%let abbrev318 = MT;
%let abbrev319 = MTN;
%let abbrev320 = MTN;
%let abbrev321 = NCK;
%let abbrev322 = NCK;
%let abbrev323 = ORCH;
%let abbrev324 = ORCH;
%let abbrev325 = ORCH;
%let abbrev326 = OVAL;
%let abbrev327 = OPAS;
%let abbrev328 = OVAL;
%let abbrev329 = PARK;
%let abbrev330 = PARK;
%let abbrev331 = PKWY;
%let abbrev332 = PKWY;
%let abbrev333 = PKWY;
%let abbrev334 = PASS;
%let abbrev335 = PSGE;
%let abbrev336 = PATH;
%let abbrev337 = PATH;
%let abbrev338 = PIKE;
%let abbrev339 = PIKE;
%let abbrev340 = PNE;
%let abbrev341 = PNES;
%let abbrev342 = PARK;
%let abbrev343 = PKWY;
%let abbrev344 = PKWY;
%let abbrev345 = PKWY;
%let abbrev346 = PKWY;
%let abbrev347 = PL;
%let abbrev348 = PL;
%let abbrev349 = PLN;
%let abbrev350 = PLNS;
%let abbrev351 = PLNS;
%let abbrev352 = PLZ;
%let abbrev353 = PLN;
%let abbrev354 = PLNS;
%let abbrev355 = PLZ;
%let abbrev356 = PLZ;
%let abbrev357 = PNES;
%let abbrev358 = PT;
%let abbrev359 = PTS;
%let abbrev360 = PRT;
%let abbrev361 = PRTS;
%let abbrev362 = PR;
%let abbrev363 = PR;
%let abbrev364 = PR;
%let abbrev365 = PARK;
%let abbrev366 = PR;
%let abbrev367 = PRT;
%let abbrev368 = PRTS;
%let abbrev369 = PT;
%let abbrev370 = PTS;
%let abbrev371 = RADL;
%let abbrev372 = RADL;
%let abbrev373 = RADL;
%let abbrev374 = RADL;
%let abbrev375 = RAMP;
%let abbrev376 = RNCH;
%let abbrev377 = RNCH;
%let abbrev378 = RPD;
%let abbrev379 = RPDS;
%let abbrev380 = RD;
%let abbrev381 = RDG;
%let abbrev382 = RDG;
%let abbrev383 = RDGS;
%let abbrev384 = RDS;
%let abbrev385 = RST;
%let abbrev386 = RDG;
%let abbrev387 = RDGS;
%let abbrev388 = RIV;
%let abbrev389 = RIV;
%let abbrev390 = RIV;
%let abbrev391 = RNCH;
%let abbrev392 = RNCH;
%let abbrev393 = RD;
%let abbrev394 = RDS;
%let abbrev395 = RTE;
%let abbrev396 = ROW;
%let abbrev397 = RPD;
%let abbrev398 = RPDS;
%let abbrev399 = RST;
%let abbrev400 = RUE;
%let abbrev401 = RUN;
%let abbrev402 = RIV;
%let abbrev403 = SHL;
%let abbrev404 = SHLS;
%let abbrev405 = SHL;
%let abbrev406 = SHLS;
%let abbrev407 = SHR;
%let abbrev408 = SHRS;
%let abbrev409 = SHR;
%let abbrev410 = SHRS;
%let abbrev411 = SHR;
%let abbrev412 = SHRS;
%let abbrev413 = SKWY;
%let abbrev414 = SMT;
%let abbrev415 = SPG;
%let abbrev416 = SPGS;
%let abbrev417 = SPG;
%let abbrev418 = SPGS;
%let abbrev419 = SPG;
%let abbrev420 = SPGS;
%let abbrev421 = SPG;
%let abbrev422 = SPGS;
%let abbrev423 = SPUR;
%let abbrev424 = SPUR;
%let abbrev425 = SQ;
%let abbrev426 = SQ;
%let abbrev427 = SQ;
%let abbrev428 = SQS;
%let abbrev429 = SQ;
%let abbrev430 = SQ;
%let abbrev431 = SQS;
%let abbrev432 = ST;
%let abbrev433 = STA;
%let abbrev434 = STA;
%let abbrev435 = STA;
%let abbrev436 = STA;
%let abbrev437 = ST;
%let abbrev438 = STRA;
%let abbrev439 = STRA;
%let abbrev440 = STRA;
%let abbrev441 = STRA;
%let abbrev442 = STRA;
%let abbrev443 = STRA;
%let abbrev444 = STRM;
%let abbrev445 = ST;
%let abbrev446 = STS;
%let abbrev447 = STRM;
%let abbrev448 = STRM;
%let abbrev449 = ST;
%let abbrev450 = STRA;
%let abbrev451 = STRA;
%let abbrev452 = SMT;
%let abbrev453 = SMT;
%let abbrev454 = SMT;
%let abbrev455 = TER;
%let abbrev456 = TER;
%let abbrev457 = TER;
%let abbrev458 = TRWY;
%let abbrev459 = TPKE;
%let abbrev460 = TPKE;
%let abbrev461 = TRL;
%let abbrev462 = TRCE;
%let abbrev463 = TRCE;
%let abbrev464 = TRAK;
%let abbrev465 = TRAK;
%let abbrev466 = TRFY;
%let abbrev467 = TRL;
%let abbrev468 = TRL;
%let abbrev469 = TRAK;
%let abbrev470 = TRCE;
%let abbrev471 = TRFY;
%let abbrev472 = TRAK;
%let abbrev473 = TRAK;
%let abbrev474 = TRL;
%let abbrev475 = TRL;
%let abbrev476 = TPKE;
%let abbrev477 = TPKE;
%let abbrev478 = TUNL;
%let abbrev479 = TUNL;
%let abbrev480 = TUNL;
%let abbrev481 = TUNL;
%let abbrev482 = TUNL;
%let abbrev483 = TUNL;
%let abbrev484 = TPKE;
%let abbrev485 = TPKE;
%let abbrev486 = UN;
%let abbrev487 = UPAS;
%let abbrev488 = UN;
%let abbrev489 = UNS;
%let abbrev490 = VLY;
%let abbrev491 = VLYS;
%let abbrev492 = VLY;
%let abbrev493 = VIA;
%let abbrev494 = VIA;
%let abbrev495 = VIA;
%let abbrev496 = VIA;
%let abbrev497 = VW;
%let abbrev498 = VWS;
%let abbrev499 = VLG;
%let abbrev500 = VLG;
%let abbrev501 = VLG;
%let abbrev502 = VLGS;
%let abbrev503 = VL;
%let abbrev504 = VLG;
%let abbrev505 = VLG;
%let abbrev506 = VIS;
%let abbrev507 = VIS;
%let abbrev508 = VIS;
%let abbrev509 = VL;
%let abbrev510 = VLG;
%let abbrev511 = VLGS;
%let abbrev512 = VLY;
%let abbrev513 = VLY;
%let abbrev514 = VLYS;
%let abbrev515 = VIS;
%let abbrev516 = VIS;
%let abbrev517 = VW;
%let abbrev518 = VWS;
%let abbrev519 = WALK;
%let abbrev520 = WALK;
%let abbrev521 = WALL;
%let abbrev522 = WAY;
%let abbrev523 = WAYS;
%let abbrev524 = WL;
%let abbrev525 = WLS;
%let abbrev526 = WLS;
%let abbrev527 = WAY;
%let abbrev528 = XING;

%do i = 1 %to 528;
&addr_type.street = tranwrd(&addr_type.street," &&word&i "," &&abbrev&i ");
%end;

recodes = "AB";
run;
%mend;



%macro remove_abbrev(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%let word1 = ALLEE;
%let word2 = ALLEY;
%let word3 = ALLY;
%let word4 = ALY;
%let word5 = ANEX;
%let word6 = ANNEX;
%let word7 = ANNX;
%let word8 = ANX;
%let word9 = ARC;
%let word10 = ARCADE;
%let word11 = AV;
%let word12 = AVE;
%let word13 = AVEN;
%let word14 = AVENU;
%let word15 = AVENUE;
%let word16 = AVN;
%let word17 = AVNUE;
%let word18 = BAYOO;
%let word19 = BAYOU;
%let word20 = BCH;
%let word21 = BEACH;
%let word22 = BEND;
%let word23 = BLF;
%let word24 = BLUF;
%let word25 = BLUFF;
%let word26 = BLUFFS;
%let word27 = BLVD;
%let word28 = BND;
%let word29 = BOT;
%let word30 = BOTTM;
%let word31 = BOTTOM;
%let word32 = BOUL;
%let word33 = BOULEVARD;
%let word34 = BOULV;
%let word35 = BR;
%let word36 = BRANCH;
%let word37 = BRDGE;
%let word38 = BRG;
%let word39 = BRIDGE;
%let word40 = BRK;
%let word41 = BRNCH;
%let word42 = BROOK;
%let word43 = BROOKS;
%let word44 = BTM;
%let word45 = BURG;
%let word46 = BURGS;
%let word47 = BYP;
%let word48 = BYPA;
%let word49 = BYPAS;
%let word50 = BYPASS;
%let word51 = BYPS;
%let word52 = CAMP;
%let word53 = CANYN;
%let word54 = CANYON;
%let word55 = CAPE;
%let word56 = CAUSEWAY;
%let word57 = CAUSWAY;
%let word58 = CEN;
%let word59 = CENT;
%let word60 = CENTER;
%let word61 = CENTERS;
%let word62 = CENTR;
%let word63 = CENTRE;
%let word64 = CIR;
%let word65 = CIRC;
%let word66 = CIRCL;
%let word67 = CIRCLE;
%let word68 = CIRCLES;
%let word69 = CK;
%let word70 = CLB;
%let word71 = CLF;
%let word72 = CLFS;
%let word73 = CLIFF;
%let word74 = CLIFFS;
%let word75 = CLUB;
%let word76 = CMP;
%let word77 = CNTER;
%let word78 = CNTR;
%let word79 = CNYN;
%let word80 = COMMON;
%let word81 = COR;
%let word82 = CORNER;
%let word83 = CORNERS;
%let word84 = CORS;
%let word85 = COURSE;
%let word86 = COURT;
%let word87 = COURTS;
%let word88 = COVE;
%let word89 = COVES;
%let word90 = CP;
%let word91 = CPE;
%let word92 = CR;
%let word93 = CRCL;
%let word94 = CRCLE;
%let word95 = CRECENT;
%let word96 = CREEK;
%let word97 = CRES;
%let word98 = CRESCENT;
%let word99 = CRESENT;
%let word100 = CREST;
%let word101 = CRK;
%let word102 = CROSSING;
%let word103 = CROSSROAD;
%let word104 = CRSCNT;
%let word105 = CRSE;
%let word106 = CRSENT;
%let word107 = CRSNT;
%let word108 = CRSSING;
%let word109 = CRSSNG;
%let word110 = CRT;
%let word111 = CSWY;
%let word112 = CT;
%let word113 = CT;
%let word114 = CTR;
%let word115 = CURVE;
%let word116 = CV;
%let word117 = CYN;
%let word118 = DALE;
%let word119 = DAM;
%let word120 = DIV;
%let word121 = DIVIDE;
%let word122 = DL;
%let word123 = DM;
%let word124 = DR;
%let word125 = DRIV;
%let word126 = DRIVE;
%let word127 = DRIVES;
%let word128 = DRV;
%let word129 = DV;
%let word130 = DVD;
%let word131 = EST;
%let word132 = ESTATE;
%let word133 = ESTATES;
%let word134 = ESTS;
%let word135 = EXP;
%let word136 = EXPR;
%let word137 = EXPRESS;
%let word138 = EXPRESSWAY;
%let word139 = EXPW;
%let word140 = EXPY;
%let word141 = EXT;
%let word142 = EXTENSION;
%let word143 = EXTENSIONS;
%let word144 = EXTN;
%let word145 = EXTNSN;
%let word146 = EXTS;
%let word147 = FALL;
%let word148 = FALLS;
%let word149 = FERRY;
%let word150 = FIELD;
%let word151 = FIELDS;
%let word152 = FLAT;
%let word153 = FLATS;
%let word154 = FLD;
%let word155 = FLDS;
%let word156 = FLS;
%let word157 = FLT;
%let word158 = FLTS;
%let word159 = FORD;
%let word160 = FORDS;
%let word161 = FOREST;
%let word162 = FORESTS;
%let word163 = FORG;
%let word164 = FORGE;
%let word165 = FORGES;
%let word166 = FORK;
%let word167 = FORKS;
%let word168 = FORT;
%let word169 = FRD;
%let word170 = FREEWAY;
%let word171 = FREEWY;
%let word172 = FRG;
%let word173 = FRK;
%let word174 = FRKS;
%let word175 = FRRY;
%let word176 = FRST;
%let word177 = FRT;
%let word178 = FRWAY;
%let word179 = FRWY;
%let word180 = FRY;
%let word181 = FT;
%let word182 = FWY;
%let word183 = GARDEN;
%let word184 = GARDENS;
%let word185 = GARDN;
%let word186 = GATEWAY;
%let word187 = GATEWY;
%let word188 = GATWAY;
%let word189 = GDN;
%let word190 = GDNS;
%let word191 = GLEN;
%let word192 = GLENS;
%let word193 = GLN;
%let word194 = GRDEN;
%let word195 = GRDN;
%let word196 = GRDNS;
%let word197 = GREEN;
%let word198 = GREENS;
%let word199 = GRN;
%let word200 = GROV;
%let word201 = GROVE;
%let word202 = GROVES;
%let word203 = GRV;
%let word204 = GTWAY;
%let word205 = GTWY;
%let word206 = HARB;
%let word207 = HARBOR;
%let word208 = HARBORS;
%let word209 = HARBR;
%let word210 = HAVEN;
%let word211 = HAVN;
%let word212 = HBR;
%let word213 = HEIGHT;
%let word214 = HEIGHTS;
%let word215 = HGTS;
%let word216 = HIGHWAY;
%let word217 = HIGHWY;
%let word218 = HILL;
%let word219 = HILLS;
%let word220 = HIWAY;
%let word221 = HIWY;
%let word222 = HL;
%let word223 = HLLW;
%let word224 = HLS;
%let word225 = HOLLOW;
%let word226 = HOLLOWS;
%let word227 = HOLW;
%let word228 = HOLWS;
%let word229 = HRBOR;
%let word230 = HT;
%let word231 = HTS;
%let word232 = HVN;
%let word233 = HWAY;
%let word234 = HWY;
%let word235 = INLET;
%let word236 = INLT;
%let word237 = IS;
%let word238 = ISLAND;
%let word239 = ISLANDS;
%let word240 = ISLE;
%let word241 = ISLES;
%let word242 = ISLND;
%let word243 = ISLNDS;
%let word244 = ISS;
%let word245 = JCT;
%let word246 = JCTION;
%let word247 = JCTN;
%let word248 = JCTNS;
%let word249 = JCTS;
%let word250 = JUNCTION;
%let word251 = JUNCTIONS;
%let word252 = JUNCTN;
%let word253 = JUNCTON;
%let word254 = KEY;
%let word255 = KEYS;
%let word256 = KNL;
%let word257 = KNLS;
%let word258 = KNOL;
%let word259 = KNOLL;
%let word260 = KNOLLS;
%let word261 = KY;
%let word262 = KYS;
%let word263 = LA;
%let word264 = LAKE;
%let word265 = LAKES;
%let word266 = LAND;
%let word267 = LANDING;
%let word268 = LANE;
%let word269 = LANES;
%let word270 = LCK;
%let word271 = LCKS;
%let word272 = LDG;
%let word273 = LDGE;
%let word274 = LF;
%let word275 = LGT;
%let word276 = LIGHT;
%let word277 = LIGHTS;
%let word278 = LK;
%let word279 = LKS;
%let word280 = LN;
%let word281 = LNDG;
%let word282 = LNDNG;
%let word283 = LOAF;
%let word284 = LOCK;
%let word285 = LOCKS;
%let word286 = LODG;
%let word287 = LODGE;
%let word288 = LOOP;
%let word289 = LOOPS;
%let word290 = MALL;
%let word291 = MANOR;
%let word292 = MANORS;
%let word293 = MDW;
%let word294 = MDWS;
%let word295 = MEADOW;
%let word296 = MEADOWS;
%let word297 = MEDOWS;
%let word298 = MEWS;
%let word299 = MILL;
%let word300 = MILLS;
%let word301 = MISSION;
%let word302 = MISSN;
%let word303 = ML;
%let word304 = MLS;
%let word305 = MNR;
%let word306 = MNRS;
%let word307 = MNT;
%let word308 = MNTAIN;
%let word309 = MNTN;
%let word310 = MNTNS;
%let word311 = MOTORWAY;
%let word312 = MOUNT;
%let word313 = MOUNTAIN;
%let word314 = MOUNTAINS;
%let word315 = MOUNTIN;
%let word316 = MSN;
%let word317 = MSSN;
%let word318 = MT;
%let word319 = MTIN;
%let word320 = MTN;
%let word321 = NCK;
%let word322 = NECK;
%let word323 = ORCH;
%let word324 = ORCHARD;
%let word325 = ORCHRD;
%let word326 = OVAL;
%let word327 = OVERPASS;
%let word328 = OVL;
%let word329 = PARK;
%let word330 = PARKS;
%let word331 = PARKWAY;
%let word332 = PARKWAYS;
%let word333 = PARKWY;
%let word334 = PASS;
%let word335 = PASSAGE;
%let word336 = PATH;
%let word337 = PATHS;
%let word338 = PIKE;
%let word339 = PIKES;
%let word340 = PINE;
%let word341 = PINES;
%let word342 = PK;
%let word343 = PKWAY;
%let word344 = PKWY;
%let word345 = PKWYS;
%let word346 = PKY;
%let word347 = PL;
%let word348 = PLACE;
%let word349 = PLAIN;
%let word350 = PLAINES;
%let word351 = PLAINS;
%let word352 = PLAZA;
%let word353 = PLN;
%let word354 = PLNS;
%let word355 = PLZ;
%let word356 = PLZA;
%let word357 = PNES;
%let word358 = POINT;
%let word359 = POINTS;
%let word360 = PORT;
%let word361 = PORTS;
%let word362 = PR;
%let word363 = PRAIRIE;
%let word364 = PRARIE;
%let word365 = PRK;
%let word366 = PRR;
%let word367 = PRT;
%let word368 = PRTS;
%let word369 = PT;
%let word370 = PTS;
%let word371 = RAD;
%let word372 = RADIAL;
%let word373 = RADIEL;
%let word374 = RADL;
%let word375 = RAMP;
%let word376 = RANCH;
%let word377 = RANCHES;
%let word378 = RAPID;
%let word379 = RAPIDS;
%let word380 = RD;
%let word381 = RDG;
%let word382 = RDGE;
%let word383 = RDGS;
%let word384 = RDS;
%let word385 = REST;
%let word386 = RIDGE;
%let word387 = RIDGES;
%let word388 = RIV;
%let word389 = RIVER;
%let word390 = RIVR;
%let word391 = RNCH;
%let word392 = RNCHS;
%let word393 = ROAD;
%let word394 = ROADS;
%let word395 = ROUTE;
%let word396 = ROW;
%let word397 = RPD;
%let word398 = RPDS;
%let word399 = RST;
%let word400 = RUE;
%let word401 = RUN;
%let word402 = RVR;
%let word403 = SHL;
%let word404 = SHLS;
%let word405 = SHOAL;
%let word406 = SHOALS;
%let word407 = SHOAR;
%let word408 = SHOARS;
%let word409 = SHORE;
%let word410 = SHORES;
%let word411 = SHR;
%let word412 = SHRS;
%let word413 = SKYWAY;
%let word414 = SMT;
%let word415 = SPG;
%let word416 = SPGS;
%let word417 = SPNG;
%let word418 = SPNGS;
%let word419 = SPRING;
%let word420 = SPRINGS;
%let word421 = SPRNG;
%let word422 = SPRNGS;
%let word423 = SPUR;
%let word424 = SPURS;
%let word425 = SQ;
%let word426 = SQR;
%let word427 = SQRE;
%let word428 = SQRS;
%let word429 = SQU;
%let word430 = SQUARE;
%let word431 = SQUARES;
%let word432 = ST;
%let word433 = STA;
%let word434 = STATION;
%let word435 = STATN;
%let word436 = STN;
%let word437 = STR;
%let word438 = STRA;
%let word439 = STRAV;
%let word440 = STRAVE;
%let word441 = STRAVEN;
%let word442 = STRAVENUE;
%let word443 = STRAVN;
%let word444 = STREAM;
%let word445 = STREET;
%let word446 = STREETS;
%let word447 = STREME;
%let word448 = STRM;
%let word449 = STRT;
%let word450 = STRVN;
%let word451 = STRVNUE;
%let word452 = SUMIT;
%let word453 = SUMITT;
%let word454 = SUMMIT;
%let word455 = TER;
%let word456 = TERR;
%let word457 = TERRACE;
%let word458 = THROUGHWAY;
%let word459 = TPK;
%let word460 = TPKE;
%let word461 = TR;
%let word462 = TRACE;
%let word463 = TRACES;
%let word464 = TRACK;
%let word465 = TRACKS;
%let word466 = TRAFFICWAY;
%let word467 = TRAIL;
%let word468 = TRAILS;
%let word469 = TRAK;
%let word470 = TRCE;
%let word471 = TRFY;
%let word472 = TRK;
%let word473 = TRKS;
%let word474 = TRL;
%let word475 = TRLS;
%let word476 = TRNPK;
%let word477 = TRPK;
%let word478 = TUNEL;
%let word479 = TUNL;
%let word480 = TUNLS;
%let word481 = TUNNEL;
%let word482 = TUNNELS;
%let word483 = TUNNL;
%let word484 = TURNPIKE;
%let word485 = TURNPK;
%let word486 = UN;
%let word487 = UNDERPASS;
%let word488 = UNION;
%let word489 = UNIONS;
%let word490 = VALLEY;
%let word491 = VALLEYS;
%let word492 = VALLY;
%let word493 = VDCT;
%let word494 = VIA;
%let word495 = VIADCT;
%let word496 = VIADUCT;
%let word497 = VIEW;
%let word498 = VIEWS;
%let word499 = VILL;
%let word500 = VILLAG;
%let word501 = VILLAGE;
%let word502 = VILLAGES;
%let word503 = VILLE;
%let word504 = VILLG;
%let word505 = VILLIAGE;
%let word506 = VIS;
%let word507 = VIST;
%let word508 = VISTA;
%let word509 = VL;
%let word510 = VLG;
%let word511 = VLGS;
%let word512 = VLLY;
%let word513 = VLY;
%let word514 = VLYS;
%let word515 = VST;
%let word516 = VSTA;
%let word517 = VW;
%let word518 = VWS;
%let word519 = WALK;
%let word520 = WALKS;
%let word521 = WALL;
%let word522 = WAY;
%let word523 = WAYS;
%let word524 = WELL;
%let word525 = WELLS;
%let word526 = WLS;
%let word527 = WY;
%let word528 = XING;

%let abbrev1 = ALY;
%let abbrev2 = ALY;
%let abbrev3 = ALY;
%let abbrev4 = ALY;
%let abbrev5 = ANX;
%let abbrev6 = ANX;
%let abbrev7 = ANX;
%let abbrev8 = ANX;
%let abbrev9 = ARC;
%let abbrev10 = ARC;
%let abbrev11 = AVE;
%let abbrev12 = AVE;
%let abbrev13 = AVE;
%let abbrev14 = AVE;
%let abbrev15 = AVE;
%let abbrev16 = AVE;
%let abbrev17 = AVE;
%let abbrev18 = BYU;
%let abbrev19 = BYU;
%let abbrev20 = BCH;
%let abbrev21 = BCH;
%let abbrev22 = BND;
%let abbrev23 = BLF;
%let abbrev24 = BLF;
%let abbrev25 = BLF;
%let abbrev26 = BLFS;
%let abbrev27 = BLVD;
%let abbrev28 = BND;
%let abbrev29 = BTM;
%let abbrev30 = BTM;
%let abbrev31 = BTM;
%let abbrev32 = BLVD;
%let abbrev33 = BLVD;
%let abbrev34 = BLVD;
%let abbrev35 = BR;
%let abbrev36 = BR;
%let abbrev37 = BRG;
%let abbrev38 = BRG;
%let abbrev39 = BRG;
%let abbrev40 = BRK;
%let abbrev41 = BR;
%let abbrev42 = BRK;
%let abbrev43 = BRKS;
%let abbrev44 = BTM;
%let abbrev45 = BG;
%let abbrev46 = BGS;
%let abbrev47 = BYP;
%let abbrev48 = BYP;
%let abbrev49 = BYP;
%let abbrev50 = BYP;
%let abbrev51 = BYP;
%let abbrev52 = CP;
%let abbrev53 = CYN;
%let abbrev54 = CYN;
%let abbrev55 = CPE;
%let abbrev56 = CSWY;
%let abbrev57 = CSWY;
%let abbrev58 = CTR;
%let abbrev59 = CTR;
%let abbrev60 = CTR;
%let abbrev61 = CTRS;
%let abbrev62 = CTR;
%let abbrev63 = CTR;
%let abbrev64 = CIR;
%let abbrev65 = CIR;
%let abbrev66 = CIR;
%let abbrev67 = CIR;
%let abbrev68 = CIRS;
%let abbrev69 = CRK;
%let abbrev70 = CLB;
%let abbrev71 = CLF;
%let abbrev72 = CLFS;
%let abbrev73 = CLF;
%let abbrev74 = CLFS;
%let abbrev75 = CLB;
%let abbrev76 = CP;
%let abbrev77 = CTR;
%let abbrev78 = CTR;
%let abbrev79 = CYN;
%let abbrev80 = CMN;
%let abbrev81 = COR;
%let abbrev82 = COR;
%let abbrev83 = CORS;
%let abbrev84 = CORS;
%let abbrev85 = CRSE;
%let abbrev86 = CT;
%let abbrev87 = CTS;
%let abbrev88 = CV;
%let abbrev89 = CVS;
%let abbrev90 = CP;
%let abbrev91 = CPE;
%let abbrev92 = CRK;
%let abbrev93 = CIR;
%let abbrev94 = CIR;
%let abbrev95 = CRES;
%let abbrev96 = CRK;
%let abbrev97 = CRES;
%let abbrev98 = CRES;
%let abbrev99 = CRES;
%let abbrev100 = CRST;
%let abbrev101 = CRK;
%let abbrev102 = XING;
%let abbrev103 = XRD;
%let abbrev104 = CRES;
%let abbrev105 = CRSE;
%let abbrev106 = CRES;
%let abbrev107 = CRES;
%let abbrev108 = XING;
%let abbrev109 = XING;
%let abbrev110 = CT;
%let abbrev111 = CSWY;
%let abbrev112 = CT;
%let abbrev113 = CTS;
%let abbrev114 = CTR;
%let abbrev115 = CURV;
%let abbrev116 = CV;
%let abbrev117 = CYN;
%let abbrev118 = DL;
%let abbrev119 = DM;
%let abbrev120 = DV;
%let abbrev121 = DV;
%let abbrev122 = DL;
%let abbrev123 = DM;
%let abbrev124 = DR;
%let abbrev125 = DR;
%let abbrev126 = DR;
%let abbrev127 = DRS;
%let abbrev128 = DR;
%let abbrev129 = DV;
%let abbrev130 = DV;
%let abbrev131 = EST;
%let abbrev132 = EST;
%let abbrev133 = ESTS;
%let abbrev134 = ESTS;
%let abbrev135 = EXPY;
%let abbrev136 = EXPY;
%let abbrev137 = EXPY;
%let abbrev138 = EXPY;
%let abbrev139 = EXPY;
%let abbrev140 = EXPY;
%let abbrev141 = EXT;
%let abbrev142 = EXT;
%let abbrev143 = EXTS;
%let abbrev144 = EXT;
%let abbrev145 = EXT;
%let abbrev146 = EXTS;
%let abbrev147 = FALL;
%let abbrev148 = FLS;
%let abbrev149 = FRY;
%let abbrev150 = FLD;
%let abbrev151 = FLDS;
%let abbrev152 = FLT;
%let abbrev153 = FLTS;
%let abbrev154 = FLD;
%let abbrev155 = FLDS;
%let abbrev156 = FLS;
%let abbrev157 = FLT;
%let abbrev158 = FLTS;
%let abbrev159 = FRD;
%let abbrev160 = FRDS;
%let abbrev161 = FRST;
%let abbrev162 = FRST;
%let abbrev163 = FRG;
%let abbrev164 = FRG;
%let abbrev165 = FRGS;
%let abbrev166 = FRK;
%let abbrev167 = FRKS;
%let abbrev168 = FT;
%let abbrev169 = FRD;
%let abbrev170 = FWY;
%let abbrev171 = FWY;
%let abbrev172 = FRG;
%let abbrev173 = FRK;
%let abbrev174 = FRKS;
%let abbrev175 = FRY;
%let abbrev176 = FRST;
%let abbrev177 = FT;
%let abbrev178 = FWY;
%let abbrev179 = FWY;
%let abbrev180 = FRY;
%let abbrev181 = FT;
%let abbrev182 = FWY;
%let abbrev183 = GDN;
%let abbrev184 = GDNS;
%let abbrev185 = GDN;
%let abbrev186 = GTWY;
%let abbrev187 = GTWY;
%let abbrev188 = GTWY;
%let abbrev189 = GDN;
%let abbrev190 = GDNS;
%let abbrev191 = GLN;
%let abbrev192 = GLNS;
%let abbrev193 = GLN;
%let abbrev194 = GDN;
%let abbrev195 = GDN;
%let abbrev196 = GDNS;
%let abbrev197 = GRN;
%let abbrev198 = GRNS;
%let abbrev199 = GRN;
%let abbrev200 = GRV;
%let abbrev201 = GRV;
%let abbrev202 = GRVS;
%let abbrev203 = GRV;
%let abbrev204 = GTWY;
%let abbrev205 = GTWY;
%let abbrev206 = HBR;
%let abbrev207 = HBR;
%let abbrev208 = HBRS;
%let abbrev209 = HBR;
%let abbrev210 = HVN;
%let abbrev211 = HVN;
%let abbrev212 = HBR;
%let abbrev213 = HTS;
%let abbrev214 = HTS;
%let abbrev215 = HTS;
%let abbrev216 = HWY;
%let abbrev217 = HWY;
%let abbrev218 = HL;
%let abbrev219 = HLS;
%let abbrev220 = HWY;
%let abbrev221 = HWY;
%let abbrev222 = HL;
%let abbrev223 = HOLW;
%let abbrev224 = HLS;
%let abbrev225 = HOLW;
%let abbrev226 = HOLW;
%let abbrev227 = HOLW;
%let abbrev228 = HOLW;
%let abbrev229 = HBR;
%let abbrev230 = HTS;
%let abbrev231 = HTS;
%let abbrev232 = HVN;
%let abbrev233 = HWY;
%let abbrev234 = HWY;
%let abbrev235 = INLT;
%let abbrev236 = INLT;
%let abbrev237 = IS;
%let abbrev238 = IS;
%let abbrev239 = ISS;
%let abbrev240 = ISLE;
%let abbrev241 = ISLE;
%let abbrev242 = IS;
%let abbrev243 = ISS;
%let abbrev244 = ISS;
%let abbrev245 = JCT;
%let abbrev246 = JCT;
%let abbrev247 = JCT;
%let abbrev248 = JCTS;
%let abbrev249 = JCTS;
%let abbrev250 = JCT;
%let abbrev251 = JCTS;
%let abbrev252 = JCT;
%let abbrev253 = JCT;
%let abbrev254 = KY;
%let abbrev255 = KYS;
%let abbrev256 = KNL;
%let abbrev257 = KNLS;
%let abbrev258 = KNL;
%let abbrev259 = KNL;
%let abbrev260 = KNLS;
%let abbrev261 = KY;
%let abbrev262 = KYS;
%let abbrev263 = LN;
%let abbrev264 = LK;
%let abbrev265 = LKS;
%let abbrev266 = LAND;
%let abbrev267 = LNDG;
%let abbrev268 = LN;
%let abbrev269 = LN;
%let abbrev270 = LCK;
%let abbrev271 = LCKS;
%let abbrev272 = LDG;
%let abbrev273 = LDG;
%let abbrev274 = LF;
%let abbrev275 = LGT;
%let abbrev276 = LGT;
%let abbrev277 = LGTS;
%let abbrev278 = LK;
%let abbrev279 = LKS;
%let abbrev280 = LN;
%let abbrev281 = LNDG;
%let abbrev282 = LNDG;
%let abbrev283 = LF;
%let abbrev284 = LCK;
%let abbrev285 = LCKS;
%let abbrev286 = LDG;
%let abbrev287 = LDG;
%let abbrev288 = LOOP;
%let abbrev289 = LOOP;
%let abbrev290 = MALL;
%let abbrev291 = MNR;
%let abbrev292 = MNRS;
%let abbrev293 = MDW;
%let abbrev294 = MDWS;
%let abbrev295 = MDW;
%let abbrev296 = MDWS;
%let abbrev297 = MDWS;
%let abbrev298 = MEWS;
%let abbrev299 = ML;
%let abbrev300 = MLS;
%let abbrev301 = MSN;
%let abbrev302 = MSN;
%let abbrev303 = ML;
%let abbrev304 = MLS;
%let abbrev305 = MNR;
%let abbrev306 = MNRS;
%let abbrev307 = MT;
%let abbrev308 = MTN;
%let abbrev309 = MTN;
%let abbrev310 = MTNS;
%let abbrev311 = MTWY;
%let abbrev312 = MT;
%let abbrev313 = MTN;
%let abbrev314 = MTNS;
%let abbrev315 = MTN;
%let abbrev316 = MSN;
%let abbrev317 = MSN;
%let abbrev318 = MT;
%let abbrev319 = MTN;
%let abbrev320 = MTN;
%let abbrev321 = NCK;
%let abbrev322 = NCK;
%let abbrev323 = ORCH;
%let abbrev324 = ORCH;
%let abbrev325 = ORCH;
%let abbrev326 = OVAL;
%let abbrev327 = OPAS;
%let abbrev328 = OVAL;
%let abbrev329 = PARK;
%let abbrev330 = PARK;
%let abbrev331 = PKWY;
%let abbrev332 = PKWY;
%let abbrev333 = PKWY;
%let abbrev334 = PASS;
%let abbrev335 = PSGE;
%let abbrev336 = PATH;
%let abbrev337 = PATH;
%let abbrev338 = PIKE;
%let abbrev339 = PIKE;
%let abbrev340 = PNE;
%let abbrev341 = PNES;
%let abbrev342 = PARK;
%let abbrev343 = PKWY;
%let abbrev344 = PKWY;
%let abbrev345 = PKWY;
%let abbrev346 = PKWY;
%let abbrev347 = PL;
%let abbrev348 = PL;
%let abbrev349 = PLN;
%let abbrev350 = PLNS;
%let abbrev351 = PLNS;
%let abbrev352 = PLZ;
%let abbrev353 = PLN;
%let abbrev354 = PLNS;
%let abbrev355 = PLZ;
%let abbrev356 = PLZ;
%let abbrev357 = PNES;
%let abbrev358 = PT;
%let abbrev359 = PTS;
%let abbrev360 = PRT;
%let abbrev361 = PRTS;
%let abbrev362 = PR;
%let abbrev363 = PR;
%let abbrev364 = PR;
%let abbrev365 = PARK;
%let abbrev366 = PR;
%let abbrev367 = PRT;
%let abbrev368 = PRTS;
%let abbrev369 = PT;
%let abbrev370 = PTS;
%let abbrev371 = RADL;
%let abbrev372 = RADL;
%let abbrev373 = RADL;
%let abbrev374 = RADL;
%let abbrev375 = RAMP;
%let abbrev376 = RNCH;
%let abbrev377 = RNCH;
%let abbrev378 = RPD;
%let abbrev379 = RPDS;
%let abbrev380 = RD;
%let abbrev381 = RDG;
%let abbrev382 = RDG;
%let abbrev383 = RDGS;
%let abbrev384 = RDS;
%let abbrev385 = RST;
%let abbrev386 = RDG;
%let abbrev387 = RDGS;
%let abbrev388 = RIV;
%let abbrev389 = RIV;
%let abbrev390 = RIV;
%let abbrev391 = RNCH;
%let abbrev392 = RNCH;
%let abbrev393 = RD;
%let abbrev394 = RDS;
%let abbrev395 = RTE;
%let abbrev396 = ROW;
%let abbrev397 = RPD;
%let abbrev398 = RPDS;
%let abbrev399 = RST;
%let abbrev400 = RUE;
%let abbrev401 = RUN;
%let abbrev402 = RIV;
%let abbrev403 = SHL;
%let abbrev404 = SHLS;
%let abbrev405 = SHL;
%let abbrev406 = SHLS;
%let abbrev407 = SHR;
%let abbrev408 = SHRS;
%let abbrev409 = SHR;
%let abbrev410 = SHRS;
%let abbrev411 = SHR;
%let abbrev412 = SHRS;
%let abbrev413 = SKWY;
%let abbrev414 = SMT;
%let abbrev415 = SPG;
%let abbrev416 = SPGS;
%let abbrev417 = SPG;
%let abbrev418 = SPGS;
%let abbrev419 = SPG;
%let abbrev420 = SPGS;
%let abbrev421 = SPG;
%let abbrev422 = SPGS;
%let abbrev423 = SPUR;
%let abbrev424 = SPUR;
%let abbrev425 = SQ;
%let abbrev426 = SQ;
%let abbrev427 = SQ;
%let abbrev428 = SQS;
%let abbrev429 = SQ;
%let abbrev430 = SQ;
%let abbrev431 = SQS;
%let abbrev432 = ST;
%let abbrev433 = STA;
%let abbrev434 = STA;
%let abbrev435 = STA;
%let abbrev436 = STA;
%let abbrev437 = ST;
%let abbrev438 = STRA;
%let abbrev439 = STRA;
%let abbrev440 = STRA;
%let abbrev441 = STRA;
%let abbrev442 = STRA;
%let abbrev443 = STRA;
%let abbrev444 = STRM;
%let abbrev445 = ST;
%let abbrev446 = STS;
%let abbrev447 = STRM;
%let abbrev448 = STRM;
%let abbrev449 = ST;
%let abbrev450 = STRA;
%let abbrev451 = STRA;
%let abbrev452 = SMT;
%let abbrev453 = SMT;
%let abbrev454 = SMT;
%let abbrev455 = TER;
%let abbrev456 = TER;
%let abbrev457 = TER;
%let abbrev458 = TRWY;
%let abbrev459 = TPKE;
%let abbrev460 = TPKE;
%let abbrev461 = TRL;
%let abbrev462 = TRCE;
%let abbrev463 = TRCE;
%let abbrev464 = TRAK;
%let abbrev465 = TRAK;
%let abbrev466 = TRFY;
%let abbrev467 = TRL;
%let abbrev468 = TRL;
%let abbrev469 = TRAK;
%let abbrev470 = TRCE;
%let abbrev471 = TRFY;
%let abbrev472 = TRAK;
%let abbrev473 = TRAK;
%let abbrev474 = TRL;
%let abbrev475 = TRL;
%let abbrev476 = TPKE;
%let abbrev477 = TPKE;
%let abbrev478 = TUNL;
%let abbrev479 = TUNL;
%let abbrev480 = TUNL;
%let abbrev481 = TUNL;
%let abbrev482 = TUNL;
%let abbrev483 = TUNL;
%let abbrev484 = TPKE;
%let abbrev485 = TPKE;
%let abbrev486 = UN;
%let abbrev487 = UPAS;
%let abbrev488 = UN;
%let abbrev489 = UNS;
%let abbrev490 = VLY;
%let abbrev491 = VLYS;
%let abbrev492 = VLY;
%let abbrev493 = VIA;
%let abbrev494 = VIA;
%let abbrev495 = VIA;
%let abbrev496 = VIA;
%let abbrev497 = VW;
%let abbrev498 = VWS;
%let abbrev499 = VLG;
%let abbrev500 = VLG;
%let abbrev501 = VLG;
%let abbrev502 = VLGS;
%let abbrev503 = VL;
%let abbrev504 = VLG;
%let abbrev505 = VLG;
%let abbrev506 = VIS;
%let abbrev507 = VIS;
%let abbrev508 = VIS;
%let abbrev509 = VL;
%let abbrev510 = VLG;
%let abbrev511 = VLGS;
%let abbrev512 = VLY;
%let abbrev513 = VLY;
%let abbrev514 = VLYS;
%let abbrev515 = VIS;
%let abbrev516 = VIS;
%let abbrev517 = VW;
%let abbrev518 = VWS;
%let abbrev519 = WALK;
%let abbrev520 = WALK;
%let abbrev521 = WALL;
%let abbrev522 = WAY;
%let abbrev523 = WAYS;
%let abbrev524 = WL;
%let abbrev525 = WLS;
%let abbrev526 = WLS;
%let abbrev527 = WAY;
%let abbrev528 = XING;

%do i = 1 %to 528;
&addr_type.street = tranwrd(&addr_type.street," &&abbrev&i "," &&word&i ");
%end;

recodes = "RA";
run;
%mend;



%macro group_directions(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%do ii = 0 %to 8;
if substr(&addr_type.street,&ii,5) = " N E " then substr(&addr_type.street,&ii,5) = "  NE ";
if substr(&addr_type.street,&ii,5) = " N W " then substr(&addr_type.street,&ii,5) = "  NW ";
if substr(&addr_type.street,&ii,5) = " S W " then substr(&addr_type.street,&ii,5) = "  SW ";
if substr(&addr_type.street,&ii,5) = " S E " then substr(&addr_type.street,&ii,5) = "  SE ";
%end;

recodes = "GD";
run;
%mend;



%macro remove_punct(in_addr_data,out_addr_data,addr_type);
data ADDRESS.&out_addr_data ;
set ADDRESS.&in_addr_data ;

%do i = 1 %to 7;
if anypunct(&addr_type.street)>0 then substr(&addr_type.street,anypunct(&addr_type.street),1) = " ";
%end;

recodes = "RQ";
run;
%mend;






%macro submit;

%do yr = 1987 %to 2004;

proc sort data = address.addresses&yr ;
by lbdnum;

data ADDRESS.sample_notcoded&yr. ;
set ADDRESS.addresses&yr ;

recodes = "  ";
run;

%let upperlim = 2;
%if (1992 <= &yr) & (2001 >= &yr) %then %let upperlim = 3;

%do loop = 1 %to &upperlim ;
%if &loop = 1 %then %let addr_type = p;
%if &loop = 2 %then %let addr_type = b;
%if &loop = 3 %then %let addr_type = m;

%remove_punct(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%replace_wordnum(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded1&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%group_streetnum(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded2&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%drop_secondaries(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded3&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%trim_addr(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded4&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%abbreviate(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded5&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%group_directions(sample_notcoded&yr. ,sample_notcoded&yr. ,&addr_type );
%geocode(sample_notcoded&yr. ,sample_coded6&addr_type&yr ,sample_notcoded&yr. ,&addr_type );

%end;


data address.sample_coded&yr. ;
set 
address.sample_coded1p&yr address.sample_coded2p&yr address.sample_coded3p&yr address.sample_coded4p&yr address.sample_coded5p&yr address.sample_coded6p&yr 
address.sample_coded1b&yr address.sample_coded2b&yr address.sample_coded3b&yr address.sample_coded4b&yr address.sample_coded5b&yr address.sample_coded6b&yr 
%if (1992 <= &yr) & (2001 >= &yr) %then %do;
address.sample_coded1m&yr address.sample_coded2m&yr address.sample_coded3m&yr address.sample_coded4m&yr address.sample_coded5m&yr address.sample_coded6m&yr 
%end;
;

tigeryear = &TIGERYEAR ;
run;

data address.sample_notcoded&yr ;
set address.sample_notcoded&yr ;
tigeryear = &TIGERYEAR ;
run;

proc datasets lib=address;
delete sample
addresses&yr
sample_coded1p&yr sample_coded2p&yr sample_coded3p&yr
sample_coded4p&yr sample_coded5p&yr sample_coded6p&yr 
sample_coded1b&yr sample_coded2b&yr sample_coded3b&yr 
sample_coded4b&yr sample_coded5b&yr sample_coded6b&yr 

%if (1992 <= &yr) & (2001 >= &yr) %then %do;
sample_coded1m&yr sample_coded2m&yr sample_coded3m&yr 
sample_coded4m&yr sample_coded5m&yr sample_coded6m&yr 
%end;
;

run;

%end;

%mend;




%submit;


