**** This dofile cleans and explains the current LBD extracts.
**** Written by: Matias.

** setup
clear
set mem 4G
set more off
global lbddir = "/rdcprojects/mc1/mc00535/data/ssllbd/stata_datasets/"
global outdir = "/rdcprojects/mc1/mc00535/data/ssllbd/"

** Program that check whether the variable is there
** and what type of variable it is.
qui{
cap program drop checkvar
program define checkvar, rclass

syntax, variable(string)
local var = "`variable'"

* is the variable present?
cap sum `var'
if _rc==0 local present = 1
if _rc!=0 local present = 0
 
* is it real or string?
if `present'==1 {
   cap count if `var'==.
   if _rc==0 local realvar = 1
   if _rc!=0 local realvar = 0
 }
if "`realvar'"=="" local realvar = "."

* is it all missing?
qui count
local N = r(N)
if `present'==1 & `realvar'==1{
   qui count if `var'==.
   if r(N)==`N' local allmiss = 1
   if r(N)< `N' local allmiss = 0
   }
if `present'==1 & `realvar'==0{
   qui count if `var'==""
   if r(N)==`N' local allmiss = 1
   if r(N)< `N' local allmiss = 0
   }
if "`allmiss'"=="" local allmiss = "."
 
return scalar present = `present'
return scalar realvar = `realvar'
return scalar allmiss = `allmiss'    
   
end

** Program that creates a (string) variable if not present,
** or it string it if real.
cap program drop string
program define string
syntax, variable(string)
local var = "`variable'"

checkvar, variable(`var')
if r(present)==0 gen `var' = ""
if r(realvar)==1 {
    cap gen aux = string(`var')
    replace aux = "" if aux =="."
    drop `var'
    ren aux `var'
    compress `var'
 }

end
}

*** Start loop
forvalues year = 1987(1)2004{
*local year = 1987
qui{
use "$lbddir/ssllbd`year'.dta", clear

** drop 
foreach var in rsr rsrf acfmu acfsu newtractmu newtractsu{
  cap drop `var'
}

global notindataset = ""
global allmissing   = ""

** SSL Recodes
foreach var in ctygeo stgeo zip street plce plgeo /*
            */ cfn ein pdiv ppn toc /*
            */ lfo lfo1 sic  indsub act npi /*
            */ sic56 ind payroll employment salereceipt{
        cap drop `var'
        di in ye "Processing variable = `var'"
        checkvar, variable(`var'mu)
        if r(present)==0 global notindataset = "$notindataset `var'mu"
        if r(allmiss)==1 global allmissing   = "$allmissing `var'mu"
        string, variable(`var'mu)
        checkvar, variable(`var'su)
        if r(present)==0 global notindataset = "$notindataset `var'su"
        if r(allmiss)==1 global allmissing   = "$allmissing `var'su"
        string, variable(`var'su)
	cap drop `var'_ssl
	gen     `var'_ssl = `var'su
	replace `var'_ssl = `var'mu if `var'mu!=""
	drop `var'mu `var'su
}

foreach var in pstreet pplce pst pzip gat{
        di in ye "Processing variable = `var'"
        checkvar, variable(`var')
        if r(present)==0 global notindataset = "$notindataset `var'"
        if r(allmiss)==1 global allmissing   = "$allmissing `var'"
        string, variable(`var')
        ren `var' `var'_ssl
}

** LBD Recodes
foreach var in lfo sic act payroll employment{
        di in ye "Processing variable = `var'"
        checkvar, variable(`var'lbd)
        if r(present)==0 global notindataset = "$notindataset `var'lbd"
        if r(allmiss)==1 global allmissing   = "$allmissing `var'lbd"
        string, variable(`var'lbd)
        ren `var'lbd `var'_lbd
}

foreach var in bestsic bestnaics{
        di in ye "Processing variable = `var'"
        checkvar, variable(`var')
        if r(present)==0 global notindataset = "$notindataset `var'"
        if r(allmiss)==1 global allmissing   = "$allmissing `var'"
        string, variable(`var')
        ren `var' `var'_lbd
}

** Variables from the SSL-SU file
foreach var in ssaemp acemp annpr empcd ssabr ssacl cyte /*
            */ acap  ac943e ac943p acsr1 acsr2 acsr3 /*
            */ acsr4 acempf acsr1f acsr2f {
             di in ye "Processing variable = `var'"
             checkvar, variable(`var')
             if r(present)==0 global notindataset = "$notindataset `var'"
             if r(allmiss)==1 global allmissing   = "$allmissing `var'"
             string, variable(`var')
             ren `var' `var'_sslsu 
}

ren acsr1f_sslsu flag_acsr1_sslsu
ren acsr2f_sslsu flag_acsr2_sslsu
ren acempf_sslsu flag_acemp_sslsu

** Variables from the SSL-MU file
foreach var in remp rap rempf rapf {
            di in ye "Processing variable = `var'"
            checkvar, variable(`var')
            if r(present)==0 global notindataset = "$notindataset `var'"
            if r(allmiss)==1 global allmissing   = "$allmissing `var'"
            string, variable(`var')
            ren `var' `var'_sslmu 
}  

ren rapf_sslmu flag_rap_sslmu
ren rempf_sslmu flag_remp_sslmu

*** Variable Generation and fixes
gen fips_ssl = stgeo_ssl+ctygeo_ssl
gen fips_lbd = state+county
gen notinlbd = 1 if yr!=year
ren firmid sslfirmid
ren cfnlbd cfn_lbd

replace ziplbd = trim(ziplbd)
gen     length = length(ziplbd)
replace ziplbd = ziplbd+"0000" if length==5
replace length = length(ziplbd)
replace ziplbd = ""  if length<9 & length>0
drop length
ren ziplbd zip_lbd

drop pay emp stgeo_ssl ctygeo_ssl year state county

foreach var in yr firstyear lastyear mu payroll_ssl payroll_lbd /*
               */ employment_ssl employment_lbd  salereceipt_ssl ssaemp_sslsu /*
               */ acemp_sslsu annpr_sslsu acap_sslsu ac943e_sslsu ac943p_sslsu /*
               */ acsr1_sslsu acsr2_sslsu acsr3_sslsu acsr4_sslsu remp_sslmu /*
               */ rap_sslmu rsr_sslmu{
                  cap gen aux = real(`var')
                  if _rc==0{ 
                     drop `var'
                     ren aux `var'
                  }
}

*** labels
label define mu 0 "su" 1 "mu"
label values mu mu

label var sslfirmid 	"Firm ID from SSL (Source: SSL)"
label var notinlbd 	"Observation in the SSEL files but not in the LBD"
label var flaga  	"Type of Link Flag (Source: LBD)"
label var flagb  	"Birth-Death-Continuer Link Flag (Source: LBD)" 
label var fips_lbd 	   "State + County FIPS codes (Source: LBD)"
label var cfn_lbd 	   "Census File Number (CFN) if yr<2002, SURVUID if yr>=2002 (Source: LBD)"
label var lfo_lbd          "Legal Form of Organization (Source: LBD)"
label var sic_lbd          "Standard Industrial Classification Code (Source: LBD)"
label var act_lbd          "Activity Code (Source: LBD)"
label var bestsic_lbd      "Best SIC (Source: LBD)"
label var bestnaics_lbd    "Best NAICS (Source: LBD)"
label var payroll_lbd 	   "Reported Annual Payroll (in $1,000) (Source: LBD)"
label var employment_lbd   "March 12 Employment (Source: LBD)"
label var fips_ssl 	"State + County FIPS codes (Source: SSL)"
label var cfn_ssl 	"Census File Number (CFN) if yr<2002, SURVUID if yr>=2002 (Source: SSL)"
label var lfo_ssl       "Legal Form of Organization (Source: SSL)"
label var toc_ssl  	"Type-of-Operation Code (Source: SSL)"
label var sic_ssl       "Standard Industrial Classification Code (Source: SSL)"
label var act_ssl       "Activity Code (Source: SSL)"
label var payroll_ssl   "Payroll (Source: SSL)"
label var employment_ssl   "Employment (Source: SSL)" 
label var salereceipt_ssl  "Sales (Source: SSL)"

label var street_ssl 	"Business Mailing Address (Source: SSL)"
label var plce_ssl 	"City Name of Business (Source: SSL)" 
label var plgeo_ssl 	"Place Geographic Code (Source: SSL)" 
label var zip_ssl 	"ZIP Code (Source: SSL)"
label var pstreet_ssl 	"Physical Location Street (Source: SSL)" 
label var pplce_ssl   	"Physical Location Place (Source: SSL)" 
label var pst_ssl     	"Physical Location State Abbrevation (Source: SSL)" 
label var pzip_ssl    	"Physical Location Zip Code (Source: SSL)" 
label var gat_ssl    	"Geographic Standardize Address Type Flag (Source: SSL)" 
label var ein_ssl  	"Employer Identification Number (Source: SSL)"
label var pdiv_ssl 	"Processing Division Code (Source: SSL)" 
label var ppn_ssl  	"Permanent Plant Number (Source: SSL)" 
label var lfo1_ssl      "Type of Business (Source: SSL)"
label var sic56_ssl     "Product Class Code (Source: SSL)"
label var ind_ssl       "Industry Code  (Source: SSL)"
label var indsub_ssl    "Sub-Industry Code  (Source: SSL)"
label var npi_ssl       "Profit/Nonprofit Indicator (Source: SSL)"

label var zip_lbd 	   "ZIP Code (Source: LBD)"

label var ssabr_sslsu      "SSA Birth Reason Code (Source: SSL su)" 
label var ssacl_sslsu      "SSA Class Code (Source: SSL su)"
label var ssaemp_sslsu     "SSA Estimated Employment (Source: SSL su)"
label var acemp_sslsu      "Administrative Current Year Employment (Source: SSL su)"
label var flag_acemp_sslsu "Administrative Current Year Employment Flag (Source: SSL su)" 
label var empcd_sslsu      "Employment Code (Source: SSL su)" 
label var cyte_sslsu       "Current Year Total Employment Size Code (Source: SSL su)" 
label var annpr_sslsu      "Annualized Payroll (Source: SSL su)" 
label var acap_sslsu       "Adm Current Yr Annual Payroll (Source: SSL su)"
label var ac943e_sslsu     "Adm Current Yr Agricultural Employment (Source: SSL su)"
label var ac943p_sslsu     "Adm Current Yr Agricultural Annual Payroll (Source: SSL su)"
label var acsr1_sslsu      "Adm Current Yr Receipts for Sales from IRS (Source: SSL su)"
label var flag_acsr1_sslsu "Adm Current Yr Receipts for Sales from IRS Flag (Source: SSL su)"
label var acsr2_sslsu      "Adm Current Yr Receipts for Royalties from IRS (Source: SSL su)"
label var flag_acsr2_sslsu "Adm Current Yr Receipts for Royalties from IRS Flag (Source: SSL su)"
label var acsr3_sslsu      "Adm Current Yr Receipts for Other income 1 from IRS (Source: SSL su)"
label var acsr4_sslsu      "Adm Current Yr Receipts for Other income 2 from IRS (Source: SSL su)"

label var rap_sslmu        "Reported Annual Payroll (Source: SSL mu)" 
label var flag_rap_sslmu   "Reported Annual Payroll Flag (Source: SSL mu)" 
label var remp_sslmu       "Reported Employment (Source: SSL mu)" 
label var flag_remp_sslmu  "Reported Employment FLAG (Source: SSL mu)" 

order lbdnum yr recnum firstyear lastyear flaga flagb mu notinlbd sslfirmid/*
  */  cfn_ssl cfn_lbd ein_ssl ppn_ssl pdiv_ssl/*
  */  fips_ssl fips_lbd zip_ssl zip_lbd street_ssl plce_ssl plgeo_ssl /*
  */  pstreet_ssl pplce_ssl pst_ssl pzip_ssl gat_ssl /*
  */  lfo_ssl lfo_lbd lfo1_ssl sic_ssl sic_lbd sic56_ssl ind_ssl indsub_ssl act_ssl npi_ssl toc_ssl/*
  */  act_lbd bestsic_lbd bestnaics_lbd /*
  */  payroll_ssl payroll_lbd  employment_ssl employment_lbd salereceipt_ssl /*
  */  ssabr_sslsu ssacl_sslsu ssaemp_sslsu acemp_sslsu flag_acemp_sslsu empcd_sslsu  /* 
  */  cyte_sslsu annpr_sslsu  acap_sslsu ac943e_sslsu ac943p_sslsu acsr1_sslsu flag_acsr1_sslsu /*
  */  acsr2_sslsu flag_acsr2_sslsu acsr3_sslsu acsr4_sslsu /*
  */  remp_sslmu flag_remp_sslmu rap_sslmu flag_rap_sslmu
}

keep lbdnum yr recnum firstyear lastyear flaga flagb mu notinlbd sslfirmid /*
   */act_lbd act_ssl bestnaics_lbd bestsic_lbd cfn_lbd cfn_ssl employment_lbd /*
   */employment_ssl fips_lbd fips_ssl lfo_lbd lfo_ssl /*
   */payroll_lbd payroll_ssl salereceipt_ssl sic_lbd sic_ssl toc_ssl newfips

compress

di in red "THESE VARIABLES ARE NOT IN YEAR `year' = $notindataset"
di ""
di in red "THESE VARIABLES ARE ALL MISSING IN YEAR `year' = $allmissing"

save "$outdir/ssllbd`year'_proc.dta", replace

}
