args year geo weight debug

clear
set mem 2g
global codes  = "/rdcprojects/mc1/mc00535/programs_organize/2.data/4.BuildWork/"

cap log close
log using "$codes/logs/2.build_POR_`geo'_`year'.log", replace
run "$codes/library.ado"
timer clear
timer on 1

use "$placebo/placebo_tracts_raw.dta", clear
keep tractid90 assigned_placebo assigned_placeboclose assigned_placebofar
tempfile placebos
save `placebos', replace

use "$placebo/placebo_tracts_raw.dta", clear
keep tractid90 assigned_placebo assigned_placeboclose assigned_placebofar
ren tractid90 powtractid90
ren assigned_placebo powassigned_placebo
ren assigned_placeboclose powassigned_placeboclose
ren assigned_placebofar powassigned_placebofar
tempfile powplacebos
save `powplacebos', replace

*** obtain all values of state for serializing
use "$data/samplelists.dta", clear
levelsof st, local(allstates)

** if "`debug'"=="debug" local allstates="$DEBUG"
if "`debug'"=="debug" local allstates="13"
if "`geo'"=="block" local allstates="06 13 17 24 26 34 36 39 42"
if "`debug'"=="debug"&"`geo'"=="block" local allstates="13"

local c = 1
foreach st of local allstates{
  use "$data/samplelists.dta" if st=="`st'", clear
  levelsof county90, local(allcounties)
  foreach s of local allcounties{
        di in ye "currently processing county `s' of state `st' in `year'"
        clear
	use  "$data/dec`year'_`st'.dta" if county90=="`s'"

        cap drop _merge
        joinby tractid90 using `placebos', unmatched(master)
        replace assigned_placebo=2 if assigned_tract==1
        replace assigned_placeboclose=2 if assigned_tract==1
        replace assigned_placebofar=2 if assigned_tract==1
        label define assigned_placebo_lab 1 "selected placebo tract" 2 "EZ tract"
        label values assigned_placebo assigned_placebo_lab
        label values assigned_placeboclose assigned_placebo_lab
        label values assigned_placebofar assigned_placebo_lab
        drop _merge

        joinby powtractid90 using `powplacebos', unmatched(master)
        replace powassigned_placebo=2 if powassigned_tract==1
        replace powassigned_placeboclose=2 if powassigned_tract==1
        replace powassigned_placebofar=2 if powassigned_tract==1
        label values powassigned_placebo assigned_placebo_lab
        label values powassigned_placeboclose assigned_placebo_lab
        label values powassigned_placebofar assigned_placebo_lab
        drop _merge

	**** when unweighted collapse is requested, set all weights to 1
	if "`weight'"=="noweight" {
	   foreach wgt in pwgt2 pwgt3 pwgt4 {
	      cap replace `wgt' = pwgt
	      }
           replace hwgt2=hwgt
	   }
	
	**** gender
        gen byte male=sex==1

	**** Recode Broad Age Categories
	gen broadagecat = .
	replace broadagecat=1 if age <=19
	replace broadagecat=2 if 20 <= age & age <= 39
	replace broadagecat=3 if 40 <= age & age <= 64
	replace broadagecat=4 if 65 <= age

	**** Recode Broad Educ Categories
	gen broadeduccat = .
	replace broadeduccat = 1 if educcat<= 7
	replace broadeduccat = 2 if educcat == 8
	replace broadeduccat = 3 if educcat >= 9
	replace broadeduccat = 4 if inschool>= 2&inschool<.

	**** Race
	gen racecat = 1 if raceeth == 1
	replace racecat = 2 if raceeth == 2
	replace racecat = 3 if raceeth > 2 & raceeth<.
	
	gen black=raceeth==2
	replace black=. if raceeth==.
	gen gt65=age>=65
	replace gt65=. if age==.
	gen lt18=age<18
	replace lt18=. if age==.
	
	gen college=educcat>=10
	replace college=. if educcat==.|educcat==0|age<25
	gen dropout=(educcat>=4&educcat<=7)
	replace dropout=. if educcat==.|educcat==0|age<25
	
	gen double wage=incw/(wklyrwk*wklyrhr)
	gen double lnwage=ln(wage)
	gen double lnwage2=lnwage if incwf==0&wklyrwkf==0&wklyrhrf==0

	gen double wkwage=incw/(wklyrwk)
	gen double lnwkwage=ln(wkwage)
	gen double lnwkwage2=lnwkwage if incwf==0&wklyrwkf==0

	*Winsorize at 80% and 40x min wage
	if `year'==1980{
	replace lnwage2=log(.8*2.90) if lnwage2<log(.8*2.90)
	replace lnwage2=log(40*2.90) if lnwage2>log(40*2.90)&lnwage2!=.
	}
	if `year'==1990{
	replace lnwage2=log(.8*3.35) if lnwage2<log(.8*3.35)
	replace lnwage2=log(40*3.35) if lnwage2>log(40*3.35)&lnwage2!=.
	}
	if `year'==2000{
	replace lnwage2=log(.8*5.15) if lnwage2<log(.8*5.15)
	replace lnwage2=log(40*5.15) if lnwage2>log(40*5.15)&lnwage2!=.
	}


	gen lnwage2_low=lnwage2 if age<=19 & educcat<=8
	gen lnwage2_hi =lnwage2 if age>=40 & educcat>=9
	gen lnwkwage2_low=lnwkwage2 if age<=19 & educcat<=8
	gen lnwkwage2_hi =lnwkwage2 if age>=40 & educcat>=9
        gen lnincw2=ln(incw) if incwf==0        

        cap drop replacemiss
        if `year'==1980 gen replacemiss = 1 if (powcounty80f==1|powtractid80f==1)
        if `year'==1990 gen replacemiss = 1 if (pow90f1==1|pow90f2==1|pow90f3==1|pow90f4==1|pow90f5==1)
        if `year'==2000 gen replacemiss = 1 if (inrange(powf1,1,5)==1|inrange(powf3,1,5)==1|inrange(powf5,1,5)==1)

	gen double lnwage2_outside=lnwage2 if powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace lnwage2_outside = . if replacemiss==1

	gen double lnwage2_outside_placebo=lnwage2 if powassigned_placebo!=assigned_placebo&assigned_placebo!=.
	replace lnwage2_outside_placebo = . if replacemiss==1

	gen double lnwage2_outside_placeboclose=lnwage2 if powassigned_placeboclose!=assigned_placeboclose&assigned_placeboclose!=.
	replace lnwage2_outside_placeboclose = . if replacemiss==1

	gen double lnwage2_outside_placebofar=lnwage2 if powassigned_placebofar!=assigned_placebofar&assigned_placebofar!=.
	replace lnwage2_outside_placebofar = . if replacemiss==1

	gen double lnwkwage2_outside=lnwkwage2 if powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace lnwkwage2_outside = . if replacemiss==1

	gen double lnwkwage2_outside_placebo=lnwkwage2 if powassigned_placebo!=assigned_placebo&assigned_placebo!=.
	replace lnwkwage2_outside_placebo = . if replacemiss==1

	gen double lnwkwage2_outside_placeboclose=lnwkwage2 if powassigned_placeboclose!=assigned_placeboclose&assigned_placeboclose!=.
	replace lnwkwage2_outside_placeboclose = . if replacemiss==1

	gen double lnwkwage2_outside_placebofar=lnwkwage2 if powassigned_placebofar!=assigned_placebofar&assigned_placebofar!=.
	replace lnwkwage2_outside_placebofar = . if replacemiss==1

	gen double lnincw2_outside=lnincw2 if powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace lnincw2_outside = . if replacemiss==1

	gen double lnincw2_outside_placebo=lnincw2 if powassigned_placebo!=assigned_placebo&assigned_placebo!=.
	replace lnincw2_outside_placebo = . if replacemiss==1

	gen double lnincw2_outside_placeboclose=lnincw2 if powassigned_placeboclose!=assigned_placeboclose&assigned_placeboclose!=.
	replace lnincw2_outside_placeboclose = . if replacemiss==1

	gen double lnincw2_outside_placebofar=lnincw2 if powassigned_placebofar!=assigned_placebofar&assigned_placebofar!=.
	replace lnincw2_outside_placebofar = . if replacemiss==1

	gen double earn_outside=incw*pwgt3 if powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace earn_outside = . if replacemiss==1

	gen double earn_outside_placebo=incw*pwgt3 if powassigned_placebo!=assigned_placebo&powassigned_placebo!=.
	replace earn_outside_placebo = . if replacemiss==1
	
        gen jobs_outside=pwgt3 if powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace jobs_outside = . if replacemiss==1

        gen jobs_outside_wage=pwgt3 if powassigned_tract!=assigned_tract&powtractid90!=""&lnwage2_outside!=.&assigned_tract!=.
	replace jobs_outside = . if replacemiss==1


	gen jobs_outside_placebo=pwgt3 if powassigned_placebo!=assigned_placebo&powtractid90!=""
	replace jobs_outside_placebo = . if replacemiss==1

	gen jobs_outside_placeboclose=pwgt3 if powassigned_placeboclose!=assigned_placeboclose&powtractid90!=""
	replace jobs_outside_placeboclose = . if replacemiss==1

	gen jobs_outside_placebofar=pwgt3 if powassigned_placebofar!=assigned_placebofar&powtractid90!=""
	replace jobs_outside_placebofar = . if replacemiss==1


        gen male_jobs_outside=pwgt3 if male==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace male_jobs_outside = . if replacemiss==1

	gen double male_lnwage2_outside=lnwage2 if male==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace male_lnwage2_outside = . if male==1 & replacemiss==1

	gen double male_lnwkwage2_outside=lnwkwage2 if male==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace male_lnwkwage2_outside = . if male==1 & replacemiss==1


        gen female_jobs_outside=pwgt3 if male==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace female_jobs_outside = . if replacemiss==1

	gen double female_lnwage2_outside=lnwage2 if male==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace female_lnwage2_outside = . if replacemiss==1

	gen double female_lnwkwage2_outside=lnwkwage2 if male==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace female_lnwkwage2_outside = . if replacemiss==1


        gen dropout_jobs_outside=pwgt3 if dropout==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace dropout_jobs_outside = . if replacemiss==1

	gen double dropout_lnwage2_outside=lnwage2 if dropout==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace dropout_lnwage2_outside = . if dropout==1 & replacemiss==1

	gen double dropout_lnwkwage2_outside=lnwkwage2 if dropout==1 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace dropout_lnwkwage2_outside = . if dropout==1 & replacemiss==1


        gen graduate_jobs_outside=pwgt3 if dropout==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace graduate_jobs_outside = . if replacemiss==1

	gen double graduate_lnwage2_outside=lnwage2 if dropout==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace graduate_lnwage2_outside = . if replacemiss==1

	gen double graduate_lnwkwage2_outside=lnwkwage2 if dropout==0 & powassigned_tract!=assigned_tract&powtractid90!=""&assigned_tract!=.
	replace graduate_lnwkwage2_outside = . if replacemiss==1





        egen bygroup = group(`geo'id90 county90)
        reweightvar, var(lnwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_outside_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_outside_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_outside_placebofar) weight(pwgt4) by(bygroup)

        reweightvar, var(female_lnwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(female_lnwkwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwkwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwkwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwkwage2_outside) weight(pwgt4) by(bygroup)

        reweightvar, var(lnwkwage2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_outside_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_outside_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_outside_placebofar) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_outside) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_outside_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_outside_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_outside_placebofar) weight(pwgt4) by(bygroup)

	if `year'==1980{
          run $codes/code_rent80_intervals
    	  gen lnrent=(logrent80_lb+logrent80_ub)/2
	  replace lnrent=log(25) if rent80cat==1
	  replace lnrent=log(750) if rent80cat==24
	  run $codes/code_value80_intervals
	  gen lnrent2=lnrent if rent80f==0
	  gen lnvalue=(logvalue_lb+logvalue_ub)/2
	  replace lnvalue=log(.5) + logvalue_ub if value80==1
	  replace lnvalue=log(1.5) + logvalue_lb if value80==24
	  gen lnvalue2=lnvalue if value80f==0
        }

        if `year'>1980{
	  run $codes/code_rent_intervals
	  gen lnrent=(logrent_lb+logrent_ub)/2
	  replace lnrent=log(40) if rentcat==1
	  replace lnrent=log(1250) if rentcat==26
	  gen lnrent2=lnrent if rentf==0
	  run $codes/code_value_intervals
	  gen lnvalue=(logvalue_lb+logvalue_ub)/2
	  replace lnvalue=log(.5) + logvalue_ub if value==1
	  replace lnvalue=log(1.5) + logvalue_lb if value==22
	  gen lnvalue2=lnvalue if valuef==0
	}

	replace incw=. if incw==0

	gen employed=1 if esr!=0
	replace employed=0 if esr==3|esr==6
	gen employed_low=employed if age<=19 & educcat<=8 & inrange(inschool,2,3)==0
	gen employed_hi =employed if age>=40 & educcat>=9 & inrange(inschool,2,3)==0
	gen unemployed=esr==3 if esr!=0&esr!=6
	gen lfp=esr!=6 if esr!=0

	gen selfemp=cow==6|cow==7 if cow!=0&cow!=.

	replace commutetime=. if employed!=1
	gen commutelt25=commutetime<25
	gen workhome=commutetime==0

	gen poverty=pov<=100 if pov!=. & pov!=0
	gen pop=1
	egen hid2=group(hid)
	gen vacant=vacancy>0 if vacancy!=.

        *** samehouse 
	if `year'==1980 gen samehouse=mig80==1 if mig80>0
	if `year'> 1980 gen samehouse=mig  ==1 if mig  >0
	
	gen employed_sh=employed if samehouse==1
	gen unemployed_sh=unemployed if samehouse==1
	gen poverty_sh=poverty if samehouse==1
	gen lnwage_sh=lnwage if samehouse==1
	gen lnwage2_sh=lnwage2 if samehouse==1
	gen lnwkwage2_sh=lnwkwage2 if samehouse==1
	gen lnincw2_sh=lnincw2 if samehouse==1

	gen employed_nsh=employed if samehouse==0
	gen unemployed_nsh=unemployed if samehouse==0
	gen poverty_nsh=poverty if samehouse==0
	gen lnwage_nsh=lnwage if samehouse==0
	gen lnwage2_nsh=lnwage2 if samehouse==0
	gen lnwkwage2_nsh=lnwkwage2 if samehouse==0
	gen lnincw2_nsh=lnincw2 if samehouse==0

	gen employed_male=employed if male==1
	gen unemployed_male=unemployed if male==1
	gen poverty_male=poverty if male==1

	gen male_lnwage=lnwage if male==1
	gen male_lnwage2=lnwage2 if male==1
	gen male_lnwkwage2=lnwkwage2 if male==1
	gen male_lnincw2=lnincw2 if male==1

	gen dropout_lnwage=lnwage if dropout==1
	gen dropout_lnwage2=lnwage2 if dropout==1
	gen dropout_lnwkwage2=lnwkwage2 if dropout==1
	gen dropout_lnincw2=lnincw2 if dropout==1


	gen employed_fem=employed if male==0
	gen unemployed_fem=unemployed if male==0
	gen poverty_fem=poverty if male==0

	gen female_lnwage=lnwage if male==0
	gen female_lnwage2=lnwage2 if male==0
	gen female_lnwkwage2=lnwkwage2 if male==0
	gen female_lnincw2=lnincw2 if male==0

	gen graduate_lnwage=lnwage if dropout==0
	gen graduate_lnwage2=lnwage2 if dropout==0
	gen graduate_lnwkwage2=lnwkwage2 if dropout==0
	gen graduate_lnincw2=lnincw2 if dropout==0

        ***Covariates***
        gen agesq=age^2
	gen age3=age^3
	gen age4=age^4

        **** Race
        gen byte other=racecat==3
        
        gen byte hsdrop  =broadeduccat==1 if broadeduccat!=.
        gen byte hs      =broadeduccat==2 if broadeduccat!=.
        gen byte coll    =broadeduccat==3 if broadeduccat!=.
        gen byte student=broadeduccat==4 if broadeduccat!=.

        if `year'==1980 gen buildingage = buildingage80

	***** Set missing category to .
	replace bedrooms=. if bedrooms==0
	replace rooms=. if rooms==0
	replace buildingage=. if buildingage==0

        replace buildingage = 1 if buildingage<4
        replace buildingage = 2 if (buildingage>=4) & (buildingage <=5)
        replace buildingage = 3 if buildingage==6
        replace buildingage = 4 if buildingage>=7

	replace rooms = 1 if rooms <3
	replace rooms = 2 if (rooms >=3) & (rooms <= 4)
	replace rooms = 3 if (rooms >=5) & (rooms <= 6)
	replace rooms = 4 if (rooms >6) & (rooms != .)
	
	replace bedrooms = 1 if bedrooms <3
	replace bedrooms = 2 if bedrooms == 3
	replace bedrooms = 3 if bedrooms == 4
	replace bedrooms = 4 if (bedrooms > 4) & (bedrooms != .)

	gen byte buildingage2 = buildingage==2 if buildingage!=.
	gen byte buildingage3 = buildingage==3 if buildingage!=.
	gen byte buildingage4 = buildingage==4 if buildingage!=.
	
        gen byte rooms2=rooms==2 if rooms!=.
        gen byte rooms3=rooms==3 if rooms!=.
        gen byte rooms4=rooms==4 if rooms!=.

        gen byte bedrooms2 = bedrooms==2 if bedrooms!=.
        gen byte bedrooms3 = bedrooms==3 if bedrooms!=.
        gen byte bedrooms4 = bedrooms==4 if bedrooms!=.

	**Ns**
	/* I want actual number of micro-obs -- Pat 10/19/11
	gen N_pop=pwgt2^2
	gen N_emp=pwgt2^2 if esr!=0
	gen N_jobs_outside=pwgt3^2 if jobs_outside!=.
	*/

	gen N_pop=1
	gen N_emp=1 if esr!=0
	gen N_jobs_outside=1 if jobs_outside!=.

	global collapsevars "male black hisp age gt65 lt18 college dropout incw lnrent lnwage lnwage2 lnwage2_low lnwage2_hi lnwkwage lnwkwage2 lnwkwage2_low lnwkwage2_hi    lnincw2 employed employed_low employed_hi unemployed lfp samehouse commutelt25 poverty employed_sh unemployed_sh poverty_sh lnwage_sh lnwage2_sh lnwkwage2_sh lnincw2_sh employed_nsh unemployed_nsh poverty_nsh lnwage_nsh  lnwage2_nsh lnwkwage2_nsh lnincw2_nsh employed_male unemployed_male poverty_male male_lnwage male_lnwage2 male_lnwkwage2 male_lnincw2 employed_fem  unemployed_fem  poverty_fem  female_lnwage female_lnwage2 female_lnwkwage2 female_lnincw2 vacant female_head workhome selfemp pop totearn incw totemp employed commutetime jobs_outside jobs_outside_wage lnwage2_outside lnwage2_outside_placebo lnwage2_outside_placeboclose lnwage2_outside_placebofar male_jobs_outside male_lnwage2_outside male_lnwkwage2_outside female_jobs_outside female_lnwage2_outside female_lnwkwage2_outside lnwkwage2_outside lnwkwage2_outside_placebo lnwkwage2_outside_placeboclose lnwkwage2_outside_placebofar lnincw2_outside lnincw2_outside_placebo lnincw2_outside_placeboclose lnincw2_outside_placebofar jobs_outside_placebo jobs_outside_placeboclose jobs_outside_placebofar earn_outside earn_outside_placebo"

        global pricevars = ""
	foreach var in $collapsevars{
	  if strpos("`var'","ln")!=0 global pricevars "$pricevars `var'"
	}
       global pricevars : list uniq global pricevars 

        foreach var in $pricevars{
          local varname = substr("N_`var'",1,32)
          gen `varname' = 1 if `var'!=.
        }

	****** DATASET FOR POR_variables, old build_work ******
	compress
	preserve
        #delimit ;
	collapse 
		(mean) male black hisp age gt65 lt18 college dropout incw lnrent lnwage lnwage2 lnwage2_low lnwage2_hi lnwkwage lnwkwage2 lnwkwage2_low lnwkwage2_hi    lnincw2 employed employed_low employed_hi unemployed lfp samehouse commutelt25 poverty employed_sh unemployed_sh poverty_sh lnwage_sh lnwage2_sh        lnwkwage2_sh lnincw2_sh employed_nsh unemployed_nsh poverty_nsh lnwage_nsh  lnwage2_nsh lnwkwage2_nsh lnincw2_nsh employed_male unemployed_male poverty_male male_lnwage male_lnwage2 male_lnwkwage2 male_lnincw2 dropout_lnwage dropout_lnwage2 dropout_lnwkwage2 dropout_lnincw2 employed_fem  unemployed_fem  poverty_fem   female_lnwage female_lnwage2 female_lnwkwage2 female_lnincw2 graduate_lnwage graduate_lnwage2 graduate_lnwkwage2 graduate_lnincw2 vacant female_head workhome selfemp 
		(sum) pop totearn=incw totemp=employed 
		(median) commutetime 
		(rawsum) jobs_outside jobs_outside_wage lnwage2_outside lnwage2_outside_placebo lnwage2_outside_placeboclose lnwage2_outside_placebofar male_jobs_outside male_lnwage2_outside male_lnwkwage2_outside female_jobs_outside female_lnwage2_outside female_lnwkwage2_outside dropout_jobs_outside dropout_lnwage2_outside dropout_lnwkwage2_outside graduate_jobs_outside graduate_lnwage2_outside graduate_lnwkwage2_outside lnwkwage2_outside lnwkwage2_outside_placebo lnwkwage2_outside_placeboclose lnwkwage2_outside_placebofar lnincw2_outside lnincw2_outside_placebo lnincw2_outside_placeboclose lnincw2_outside_placebofar jobs_outside_placebo jobs_outside_placeboclose jobs_outside_placebofar earn_outside earn_outside_placebo 
		N_* 
		[iw=pwgt2], by(`geo'id90 assigned_tract county90) fast;
        #delimit cr
	recode *ln*wage2_* (0=.)
	recode lnwkwage2_* (0=.)
	recode lnincw2_* (0=.)
	recode earn_outside* (0=.)
	gen lnearn=ln(incw)
	tempfile demo
	save `demo', replace
	restore

        preserve
	cap drop value
	replace pern=0 if pern<0
        if `year'<2000 gen incssi = .
                       gen incssif = 0
	collapse (mean) buildingage* rooms* lnrent lnrent2 lnvalue lnvalue2 vacant female_head samehouse (sum) incw incp incssi incwf incpf incssif, by(hid2 `geo'id90 assigned_tract hwgt2 county90) fast
	gen N_hh=1
	gen N_hh_lnrent =1 if lnrent!=.
	gen N_hh_lnrent2=1 if lnrent2!=.
	gen N_hh_lnvalue  =1 if lnvalue!=.
	gen N_hh_lnvalue2 =1 if lnvalue2!=.

	gen N_hh_sh=1 if samehouse==1
	gen N_hh_lnrent_sh=1 if lnrent!=.&samehouse==1
	gen N_hh_lnrent2_sh=1 if lnrent2!=.&samehouse==1
	gen N_hh_lnvalue_sh=1 if lnvalue!=.&samehouse==1
	gen N_hh_lnvalue2_sh=1 if lnvalue2!=.&samehouse==1

	gen N_hh_nsh=1 if samehouse==0
	gen N_hh_lnrent_nsh=1 if lnrent!=.&samehouse==0
	gen N_hh_lnrent2_nsh=1 if lnrent2!=.&samehouse==0
	gen N_hh_lnvalue_nsh=1 if lnvalue!=.&samehouse==0
	gen N_hh_lnvalue2_nsh=1 if lnvalue2!=.&samehouse==0

	gen welfare=incp>0 if incp!=.
	replace welfare=1 if incssi>0 & incssi!=.
	replace female_head=1 if female_head>0 & female_head!=.

	gen lnrent_sh=lnrent if samehouse==1
	gen lnvalue_sh=lnvalue if samehouse==1

	gen lnrent_nsh=lnrent if samehouse==0
	gen lnvalue_nsh=lnvalue if samehouse==0

	gen lnrent2_sh=lnrent2 if samehouse==1
	gen lnvalue2_sh=lnvalue2 if samehouse==1

	gen lnrent2_nsh=lnrent2 if samehouse==0
	gen lnvalue2_nsh=lnvalue2 if samehouse==0

	gen rent2=exp(lnrent2)
	gen value2=exp(lnvalue2)

	replace incp = 0 if incp==.
	replace incp = incp+incssi if incssi<.

	gen lnhhincw = ln(incw)
	gen lnhhincp = ln(incp)

	gen lnhhincw2 = ln(incw) if incwf==0
	gen lnhhincp2 = ln(incp) if incpf==0
	gen DI=incw-rent2 if incwf==0
	#delimit ;
	collapse 
		(mean) buildingage* rooms* rent value lnrent lnrent2 lnvalue lnvalue2 lnrent_sh lnvalue_sh lnrent_nsh lnvalue_nsh lnrent2_sh lnvalue2_sh lnrent2_nsh lnvalue2_nsh vacant female_head  welfare lnhhincw lnhhincp lnhhincw2 lnhhincp2 DI 
		(p10) lnvalue_p10=lnvalue lnrent_p10=lnrent 
		(p25) lnvalue_p25=lnvalue lnrent_p25=lnrent 
		(p50) lnvalue_p50=lnvalue lnrent_p50=lnrent 
		(p75) lnvalue_p75=lnvalue lnrent_p75=lnrent 
		(p90) lnvalue_p90=lnvalue lnrent_p90=lnrent 
		(sum) hh_value=N_hh_lnvalue hh_rent=N_hh_lnrent hh=N_hh (rawsum) N_hh* 
		[iw=hwgt2], by(`geo'id90 assigned_tract county90) fast;
        #delimit cr
	joinby `geo'id90 using `demo', unmatched(both)
	tab _merge
	drop _merge
	
	if "`weight'"=="noweight" {
	   foreach var of varlist * {
	      cap ren `var' `var'_nwt
	      if _rc!=0 drop `var'
	      }
	   foreach var in `geo'id90 assigned_tract county90 {
	      ren `var'_nwt `var'
	      }
	   }

        gen year=`year'
	tempfile demo_`c'
	save `demo_`c'', replace
	restore

        **** Datasets for estimation of build-cells FE
        if "`geo'"=="tract" & "`weight'"!="noweight" {
   	   ****** DATASET FOR POR_variables, old build_cells ******
	   preserve
	   collapse (mean) hwgt2 samehouse lnrent lnrent2 lnvalue lnvalue2 buildingage2 buildingage3 buildingage4 rooms2 rooms3 rooms4 bedrooms2 bedrooms3 bedrooms4, by(hid progid_power tractid90 assigned_tract county90) fast
           gen year = `year'
	   compress
    	   tempfile HH_`s'
	   save `HH_`s'', replace
	   restore

   	   keep pwgt2 samehouse poverty employed unemployed lfp lnwage2 lnwkwage2 lnincw2 age  agesq age3 age4 hs coll student black other male progid_power tractid90 assigned_tract county90
           gen year = `year'
	   compress
    	   tempfile PP_`s'
	   save `PP_`s'', replace
        }
        local c = `c'+1
 }
}



*** APPEND DATASET P.O.R. collapsed
local c = `c'-1
use `demo_1', clear
  forvalues s = 2(1)`c'{
    append using `demo_`s''
   }
**** Fix ids
cap drop progid_power
cap drop countyid
gen     progid_power = county90+"0"
replace progid_power = county90+"1" if assigned_tract==1
replace progid_power = county90+"2" if assigned_tract==0
egen countyid=group(progid_power)
compress
if "`weight'"!="noweight" {
save "$intermediate/por`year'_`geo'.dta", replace
}
if "`weight'"=="noweight" {
save "$intermediate/por`year'_`geo'_noweight.dta", replace
}

*** APPEND DATASET for build cells
if "`geo'"=="tract" & "`weight'"!="noweight" {
  *** APPEND DATASET HH micro
   foreach st of local allstates{
     local c = 1
     use "$data/samplelists.dta" if st=="`st'", clear
     levelsof county90, local(allcounties)
       foreach s of local allcounties{
          if `c'==1 use `HH_`s'', clear
          if `c'> 1 cap noisily append using `HH_`s''
          local c = `c'+1
          }
        **** Fix ids
        cap drop progid_power
        cap drop countyid
        gen     progid_power = county90+"0"
        replace progid_power = county90+"1" if assigned_tract==1
        replace progid_power = county90+"2" if assigned_tract==0
        egen countyid=group(progid_power)
        save "$intermediate/CELLS/tempcenhousing_`st'_`year'", replace
        }

  *** APPEND DATASET PP micro
   foreach st of local allstates{
     local c = 1
     use "$data/samplelists.dta" if st=="`st'", clear
     levelsof county90, local(allcounties)
       foreach s of local allcounties{
          if `c'==1 use `PP_`s'', clear
          if `c'> 1 cap noisily append using `PP_`s''
          local c = `c'+1
          }
        **** Fix ids
        cap drop progid_power
        cap drop countyid
        gen     progid_power = county90+"0"
        replace progid_power = county90+"1" if assigned_tract==1
        replace progid_power = county90+"2" if assigned_tract==0
        egen countyid=group(progid_power)
        save "$intermediate/CELLS/tempcenperson_`st'_`year'", replace
        }
}

timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close
