
args unitofprediction debug

clear mata
clear matrix
clear
version 10.1
set more off
set mem 3g
set matsize 5000

global codes  = "/rdcprojects/mc1/mc00535/programs_organize/2.data/4.BuildWork/"
run "$codes/library.ado"

cap log close
log using "$codes/logs/5.build_cells_`unitofprediction'.log", replace
timer clear
timer on 1

***********************************************************************************
*** This is used to record diagnostics from the variable-adjustment regressions ***
***********************************************************************************
tempname memhold
tempfile results
postfile `memhold' str20(state area) str20(outcome) double(N df_m) using "`results'"

***********************
**** HOUSES
**********************
if "`unitofprediction'"=="houses"{
qui{
 *** obtain all values of state for serializing
 use "$data/samplelists.dta", clear
 levelsof st, local(allstates)

 ** if "`debug'"=="debug" local allstates="$DEBUG"
 if "`debug'"=="debug" local allstates="13"

 local c = 1
 foreach s of local allstates{
   noi di "currently processing state `s' in `year'"
   ****************************************
   ***** Generate housing predictions *****
   ****************************************
   ** Append 3 years
   use "$intermediate/CELLS/tempcenhousing_`s'_1980", clear
   append using "$intermediate/CELLS/tempcenhousing_`s'_1990"
   append using "$intermediate/CELLS/tempcenhousing_`s'_2000"
   save "$intermediate/CELLS/tempcenhousing_`s'.dta", replace

   ** Obtain values of countyid
   use "$intermediate/CELLS/tempcenhousing_`s'.dta", clear
   levelsof countyid, local(incounties)

   ***** Estimate the model separately by city and save the cell predictions in predicted
   tempfile predicted
   foreach ii of local incounties{
      use "$intermediate/CELLS/tempcenhousing_`s'.dta", clear
      keep if countyid==`ii'

      egen bedrooms_rooms=group(bedrooms2 bedrooms3 bedrooms4 rooms2 rooms3 rooms4)
      egen buildingage_bedrooms=group(buildingage2 buildingage3 buildingage4 bedrooms2 bedrooms3 bedrooms4)

      qui tab bedrooms_rooms, gen(DUMbedrooms_rooms)
      qui tab buildingage_bedrooms, gen(DUMbuildingage_bedrooms)

      ***Demean for areg
      foreach var of varlist buildingage2 buildingage3 buildingage4 rooms2 rooms3 rooms4 bedrooms2 bedrooms3 bedrooms4 DUMbedrooms_rooms* DUMbuildingage_bedrooms* {
	egen aux1 = sum(`var'*hwgt2) if year==1990, by(countyid)
	egen aux2 = sum((`var'!=.)*hwgt2)       if year==1990, by(countyid)
	gen `var'_mean=aux1/aux2
	egen `var'_mean2=mean(`var'_mean), by(countyid) //fillin for other decades
	gen dev_`var'=`var'-`var'_mean2
	drop `var' `var'_mean `var'_mean2 aux1 aux2 
      }

    egen tract_year = group(tractid90 year)

    foreach var in lnvalue lnrent lnvalue2 lnrent2 {
      cap drop `var'_hat
      cap drop `var'_comp
      noi di "running adjustment model for countyid==`ii' for variable `var'"
      cap noi areg `var' dev_* [aw=hwgt2], abs(tract_year)
      if _rc==0 {
            predict `var'_hat, d
            predict `var'_comp, xb
            post `memhold' ("`s'") ("`ii'") ("`var'") (e(N)) (e(df_m))
       }
      if _rc!=0 {
           gen `var'_hat = .
           gen `var'_comp = .
           noi di "No adjusted information in countyid==`ii' for variable `var'"
       }
	replace `var'_hat=`var'_hat + _b[_cons]  //recenter prenoi diction around mean


      cap drop samehouse_`var'_hat
      cap drop samehouse_`var'_comp
      noi di "running adjustment model for countyid==`ii' for variable `var' (samehouse==1)"
      cap noi areg `var' dev_* [aw=hwgt2] if samehouse==1, abs(tract_year)
      if _rc==0 {
            predict samehouse_`var'_hat, d
            predict samehouse_`var'_comp, xb
            post `memhold' ("`s'") ("`ii'") ("samehouse_`var'") (e(N)) (e(df_m))
       }
      if _rc!=0 {
           gen samehouse_`var'_hat = .
           gen samehouse_`var'_comp = .
           noi di "No adjusted information in countyid==`ii' for variable `var' (samehouse==1)"
       }
	replace samehouse_`var'_hat=samehouse_`var'_hat + _b[_cons]  //recenter prediction around mean


      cap drop newhouse_`var'_hat
      cap drop newhouse_`var'_comp
      noi di "running adjustment model for countyid==`ii' for variable `var' (samehouse==0)"
      cap noi areg `var' dev_* [aw=hwgt2] if samehouse==0, abs(tract_year)
      if _rc==0 {
            predict newhouse_`var'_hat, d
            predict newhouse_`var'_comp, xb
            post `memhold' ("`s'") ("`ii'") ("newhouse_`var'") (e(N)) (e(df_m))
       }
      if _rc!=0 {
           gen newhouse_`var'_hat = .
           gen newhouse_`var'_comp = .
           noi di "No adjusted information in countyid==`ii' for variable `var' (samehouse==0)"
       }
	replace newhouse_`var'_hat=newhouse_`var'_hat + _b[_cons]  //recenter prediction around mean
    }

    collapse lnvalue_hat lnrent_hat samehouse_lnvalue_hat samehouse_lnrent_hat    newhouse_lnvalue_hat newhouse_lnrent_hat    lnvalue2_hat lnrent2_hat samehouse_lnvalue2_hat samehouse_lnrent2_hat newhouse_lnvalue2_hat newhouse_lnrent2_hat *_comp [iw=hwgt2], by(tractid90 year) fast


      if "`ii'"!= word("`incounties'",1)  append using `predicted'
      save `predicted', replace

      if "`ii'"==word("`incounties'", wordcount("`incounties'")) save "$intermediate/FITTED/fitted_housing_stata_90geo_full_`c'.dta", replace
   } 
   local c = `c'+1
}
}

*** APPEND HOUSING PREDICTIONS
local c = `c'-1
use "$intermediate/FITTED/fitted_housing_stata_90geo_full_1.dta", clear
  forvalues s = 2(1)`c'{
    append using "$intermediate/FITTED/fitted_housing_stata_90geo_full_`s'.dta"
  }
  save "$intermediate/housing_fe_90_fullcounties.dta", replace
}



***********************
**** PERSONS
**********************
if "`unitofprediction'"=="persons"{
qui{
 *** obtain all values of state for serializing
 use "$data/samplelists.dta", clear
 levelsof st, local(allstates)
 
 ** if "`debug'"=="debug" local allstates="$DEBUG"
 if "`debug'"=="debug" local allstates="13"
 
 local c = 1
 foreach s of local allstates{
   noi di "currently processing state `s' in `year'"
    ***************************************
    ***** Generate person predictions *****
    ***************************************
    use "$intermediate/CELLS/tempcenperson_`s'_1980", clear
    append using "$intermediate/CELLS/tempcenperson_`s'_1990"
    append using "$intermediate/CELLS/tempcenperson_`s'_2000"
    save "$intermediate/CELLS/tempcenperson_`s'.dta", replace

    ** Obtain values of countyid
    use "$intermediate/CELLS/tempcenperson_`s'.dta", clear
    levelsof countyid, local(incounties)

    ***** Estimate the model separately by city and save the cell predictions in predicted
    tempfile predicted
    foreach ii of local incounties{
      use "$intermediate/CELLS/tempcenperson_`s'", clear
      keep if countyid==`ii'

      ***Demean for areg
      foreach var of varlist age agesq age3 age4 hs coll student black other male {
	egen aux1 = sum(`var'*pwgt2) if year==1990, by(countyid)
	egen aux2 = sum((`var'!=.)*pwgt2)       if year==1990, by(countyid)
	gen double `var'_mean=aux1/aux2
	egen double `var'_mean2=mean(`var'_mean), by(countyid) //fillin for other decades
	gen double dev_`var'=`var'-`var'_mean2
	drop aux1 aux2

	egen aux1 = sum(`var'*pwgt2) if year==1990 & samehouse==1, by(countyid)
	egen aux2 = sum((`var'!=.)*pwgt2)       if year==1990 & samehouse==1, by(countyid)
	gen samehouse`var'_mean=aux1/aux2 if year==1990 & samehouse==1
	egen samehouse`var'_mean2=mean(samehouse`var'_mean) if samehouse==1, by(countyid) //fillin for other decades
	gen samehouse_dev_`var'=`var'-samehouse`var'_mean2 if samehouse==1
	drop `var' `var'_mean `var'_mean2 samehouse`var'_mean samehouse`var'_mean2 aux1 aux2
      }

    egen tract_year = group(tractid90 year)

    foreach var in lnwage2 lnwkwage2 lnincw2 poverty samehouse employed unemployed lfp {
      cap drop `var'_hat
      cap drop `var'_comp
      noi di "running adjustment model for countyid==`ii' for variable `var'"
      cap noi areg `var' dev_* [aw=pwgt2], abs(tract_year)
      if _rc==0 {
           predict `var'_hat, d
           predict `var'_comp, xb
           post `memhold' ("`s'") ("`ii'") ("`var'") (e(N)) (e(df_m))
       }
      if _rc!=0 {
           gen `var'_hat = .
           gen `var'_comp = .
           noi di "No adjusted information in countyid==`ii' for variable `var'"
       }
	replace `var'_hat=`var'_hat + _b[_cons]  //recenter prediction around mean
    } 

    foreach var in lnwage2 lnwkwage2 lnincw2 poverty samehouse employed unemployed lfp {
      cap drop samehouse_`var'_hat
      cap drop samehouse_`var'_comp
      noi di "running adjustment model for countyid==`ii' for variable `var'"
      cap noi areg `var' samehouse_dev_* if samehouse==1 [aw=pwgt2], abs(tract_year)
      if _rc==0 {
           predict samehouse_`var'_hat, d
           predict samehouse_`var'_comp, xb
           post `memhold' ("`s'") ("`ii'") ("samehouse_`var'") (e(N)) (e(df_m))
       }
      if _rc!=0 {
           gen samehouse_`var'_hat = .
           gen samehouse_`var'_comp = .
           noi di "No adjusted information in countyid==`ii' for variable `var'"
       }
	replace samehouse_`var'_hat=samehouse_`var'_hat + _b[_cons]  //recenter prediction around mean
    } 

    collapse lnwage2_hat lnwkwage2_hat lnincw2_hat poverty_hat samehouse_hat employed_hat unemployed_hat lfp_hat samehouse_lnwage2_hat samehouse_lnwkwage2_hat samehouse_lnincw2_hat samehouse_poverty_hat samehouse_samehouse_hat samehouse_employed_hat samehouse_unemployed_hat samehouse_lfp_hat *_comp [iw=pwgt2], by(tractid90 year) fast

      local variables = "poverty samehouse employed unemployed lfp"
      foreach var of local variables{
          replace `var'_hat = 1 if `var'_hat>1 & `var'_hat<.
          replace `var'_hat = 0 if `var'_hat<0 
          replace samehouse_`var'_hat = 1 if samehouse_`var'_hat>1 & `var'_hat<.
          replace samehouse_`var'_hat = 0 if samehouse_`var'_hat<0 
       }

      if "`ii'"!= word("`incounties'",1)  append using `predicted'
      save `predicted', replace

      if "`ii'"==word("`incounties'",wordcount("`incounties'")) save "$intermediate/FITTED/fitted_person_stata_90geo_full_`c'.dta", replace
  }
  local c = `c'+1
}
}

  *** APPEND PERSON PREDICTIONS
  local c = `c'-1
  use "$intermediate/FITTED/fitted_person_stata_90geo_full_1.dta", clear
  forvalues s = 2(1)`c'{
    append using "$intermediate/FITTED/fitted_person_stata_90geo_full_`s'.dta"
  }
  save "$intermediate/person_fe_90_fullcounties.dta", replace
}


*********************************
*** export diagnostic results ***
*********************************
postclose `memhold'
use `results', clear
save "$intermediate/CELLS/`unitofprediction'_cell_prediction_model_Ns.dta", replace


timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close