*! version 3.1.4 17dec2008 E. Leuven, B. Sianesi
cap program drop psmatch2
program define psmatch2, sortpreserve
	version 9.0
	#delimit ;
	syntax varlist(min=1) [if] [in] [,
	OUTcome(varlist)
	Pscore(varname)
	Neighbor(integer 1)
	TIES
	RADIUS
	CALiper(real 0)
	PCALiper(real 0)
	MAHALanobis(varlist)
	ADD
	KERNEL
	LLR
	Kerneltype(string)
	BWidth(string)
	COMmon
	TRIM(real 100)
	ODDS
	LOGIT
	INDEX
	QUIetly
	NOREPLacement
	DESCending
	NOWARNings
	ATE
	W(string)
	SPLINE
	NKnots(integer 0)
	];
	#delimit cr

	/* record sort order */
	tempvar order
	g long `order' = _n

	/* clean up data */
	foreach v in _treated _support _weight _pscore _pdif _mdif _id _n1 _nn {
		cap drop `v'
	}

	global OUTVAR `outcome'
	if ("`outcome'"!="") {
		foreach v of varlist `outcome' {
			cap drop _`v'
			local moutvar `moutvar' _`v'
		}
	}

	/* determine subset we work on */
	marksample touse
	capture markout `touse' `outcome' `control' `mahalanobis'

	/* separate treatment indicator from varlist */
	tokenize `varlist'
	local treat `1'
	macro shift
	local varlist "`*'"
	local k : word count `varlist'

	/* set caliper to missing (infinity) if not requested */
	if (`caliper'==0) {
		local caliper = .
	}
	if (`pcaliper'==0) {
		local pcaliper = .
	}

	/* determine matching metric */
	local nmvars : word count `mahalanobis'
	if (`nmvars'>0) {
		local metric = "mahalanobis"
	}
	else local metric = "pscore"

	if (`k'==0 & "`pscore'"=="" & "`metric'"=="pscore") {
		di as error "You should either specify a " as input "varlist" as error " or " as input "propensity score"
		exit 198
	}
	if (`k'>0 & "`pscore'"!="") {
		di as error "You cannot specify both a " as input "varlist" as error " AND a " as input "propensity score"
		exit 198
	}
	if (`k'==0 & "`pscore'"=="" & "`add'"!="") {
		di as error "Since you used option " as input "add" as error " you must provide the propensity score"
		exit 198
	}
	if ("`metric'"=="mahalanobis" & "`add'"=="" & (`k'>0 | "`pscore'"!="")) {
		local add "add"
		di as text "Propensity score is added to the Mahalanobis variable list"
	}

	/* check matching method */
	local method "neighbor"
	if ("`kernel'"!="") {
		local method "`kernel'"
	}
	if ("`llr'"!="") {
		local method "`llr'"
	}

	if ("`llr'"!="" & "`kernel'"!="") {
		di as error "You cannot do kernel and llr matching at the same time"
		exit 198
	}

	if ("`noreplacement'"!="" & ("`method'"!="neighbor" | "`metric'"!="pscore" | `neighbor'>1 )) {
		di as error "Matching without replacement is only implemented with 1-to-1 propensity score matching"
		exit 198
	}
	if ("`descending'"!="" & "`noreplacement'"=="") {
		di as error "Option " as input "descending" as error " makes only sense when matching without replacement"
		exit 198
	}

	/* check kerneltype */
	if ("`method'"=="kernel" & "`kerneltype'"=="") {
		local kerneltype "epan"
	}
	if ("`method'"=="llr" & "`kerneltype'"=="") {
		local kerneltype "tricube"
	}
	if !("`kerneltype'"=="" | "`kerneltype'"=="normal" | "`kerneltype'"=="epan" | "`kerneltype'"=="biweight" | "`kerneltype'"=="uniform" | "`kerneltype'"=="tricube") {
		di as error "Kerneltype `kerneltype' not recognized"
		exit 198
	}

	/* radius matching is like kernel matching with uniform kernel */
	if ("`radius'"!="") {
		local method "kernel"
		local kerneltype "uniform"
		local bwidth = `caliper'
	}

	if ("`bwidth'"=="") {
		local bwidth "0.06"
	}

	/* estimate propensity score */
	if ("`varlist'"!="") {
		if ("`logit'"=="") {
			local logit "probit"
		}
		`quietly' `logit' `treat' `varlist' if `touse', nolog
		tempvar pscore
		qui predict double `pscore', `index'
		qui g double _pscore = `pscore'
		label var _pscore "psmatch2: Propensity Score"
	}
	else if ("`metric'"=="pscore" | ("`metric'"=="mahalanobis" & "`add'"!="")) {
		qui g double _pscore = `pscore'
		label var _pscore "psmatch2: Propensity Score"
	}
	capture markout `touse' _pscore

	/* match on log odds ratio if requested, only with logit? */
	if ("`odds'"!="") {
		qui replace _pscore = ln(_pscore/(1 - _pscore))
	}

	/* create treatment indicator variable */
	qui g byte _treated = `treat' if `touse'
	label variable _treated "psmatch2: Treatment assignment"
	cap label drop _treated
	label define _treated 0 "Untreated" 1 "Treated"
	label value _treated _treated

	/* common support if requested */
	if (("`common'"!="" | `trim'<100) & ("`varlist'"=="" & "`pscore'"=="")) {
		di as error "With option 'common' a propensity score is needed. Provide one"
		di as error "with option 'pscore()' or estimate one. See the help file for more details."
		exit 198
	}
	qui g byte _support = 1 if `touse'
	label variable _support "psmatch2: Common support"
	cap label drop _support
	label define _support 0 "Off support" 1 "On support"
	label value _support _support
	if (("`common'"!="" | `trim'<100) & ("`varlist'"!="" | "`pscore'"!="")) {
		if !inrange(`trim',0,100) {
			di as error "Trim level out of range"
			exit 198
		}
		qui _Support_ `pscore', level(`trim') `ate'
	}

	/* nobs for convenience */
	qui count if _treated==0 & _support==1
	global N_control = r(N)
	qui count if _treated<=1 & _support==1
	global N_total = r(N)

	/* do nearest neighbor if llr with tricube */
	if ("`method'"=="llr" & "`kerneltype'"=="tricube" & "`metric'"=="pscore") {
		local method "neighbor"
		if ("`bwidth'"=="") {
			local bwidth "0.8"
		}
		global OUTVAR ""
		foreach v of varlist `outcome' {
			cap drop _s_`v'
			qui ksm `v' _pscore if _treated==0 & _support==1, lowess nograph gen(_s_`v') bw(`bwidth')
			if ("`ate'"!="") {
				tempvar s`v'
				qui ksm `v' _pscore if _treated==1 & _support==1, lowess nograph gen(`s`v'') bw(`bwidth')
				qui replace _s_`v' = `s`v'' if _treated==1 & _support==1
			}
			global OUTVAR $OUTVAR _s_`v'
			label var _s_`v' "psmatch2: smoothed outcome variable"
		}
	}

	/* spline */
	if ("`spline'"!="") {
		cap which spline
		if (_rc) {
			di as error "You need to install package -spline-, for option spline"
			exit  198
		}
		local method "neighbor"
		if ("`nknots'"=="0") {
			local nknots = int($N_control^0.25)
		}
		global OUTVAR ""
		foreach v of varlist `outcome' {
			cap drop _s_`v'
			qui spline `v' _pscore if _treated==0 & _support==1, gen(_s_`v') nknots(`nknots') nograph
			if ("`ate'"!="") {
				if ("`nknots'"=="0") {
					local nknots = int($N_treated^0.25)
				}
				tempvar s`v'
				qui spline `v' _pscore if _treated==1 & _support==1, gen(`s`v'') nknots(`nknots') nograph
				qui replace _s_`v' = `s`v'' if _treated==1 & _support==1
			}
			global OUTVAR $OUTVAR _s_`v'
			label var _s_`v' "psmatch2: smoothed outcome variable using -spline-"
		}
	}


	/* create vars we will need */
	qui g double _weight = _treated if _support==1
	if "`ate'"!="" {
		qui replace _weight = 0 if _treated==1 & _support==1
	}

	if ("`method'"=="neighbor") {
		qui g _n1 = .
		label var _n1 "psmatch2: ID of nearest neighbor"
		qui g _nn = 0 if _support==1
		label var _nn "psmatch2: # matched neighbors"
	}
	label var _weight "psmatch2: weight of matched controls"

	/* outcome of matches */
	if ("`outcome'"!="") {
		foreach v of varlist `outcome'	 {
			if ("`ate'"=="") {
				qui g double _`v' = 0 if _support==1 & _treated==1
			}
			else qui g double _`v' = 0 if _support==1
			label var _`v' "psmatch2: value of `v' of match(es)"
		}
	}

	/* check for duplicate pscores */
	if ("`nowarnings'"=="" & "`metric'"=="pscore") {
		sort _treated _pscore
		cap by _treated _pscore: assert _N==1 if _treated==0 & _support==1
		if (!_rc & "`ate'"!="") {
			cap by _treated _pscore: assert _N==1 if _treated==1 & _support==1
		}
		if (_rc & "`method'"=="neighbor") {
			di as res "There are observations with identical propensity score values."
			di as res "The sort order of the data could affect your results."
			di as res "Make sure that the sort order is random before calling psmatch2."
		}
	}

	/* sort data on treatment status and pscore and create id */
	tempvar msup
	g byte `msup' = - _support
	if ("`metric'"=="pscore" & "`method'"=="neighbor") {
		if ("`descending'"=="") {
			sort `msup' _treated _pscore `order'
		}
		else {
			tempvar mps
			g double `mps' = - _pscore
			sort `msup' _treated `mps' `order'
		}
	}
	else sort `msup' _treated `order'

	if ("`method'"=="neighbor") {
		g _id = _n
		label var _id "psmatch2: Identifier (ID)"
	}

	/* calculate within sample covariance matrix if necessary */
	if ("`metric'"=="mahalanobis") {
		if "`add'"!="" {
			local mahalanobis _pscore `mahalanobis'
		}
		if ("`w'"=="") {
			tempname XX0 XX1 w
			qui mat accum `XX0' = `mahalanobis' if _treated==0, dev noc
			qui mat accum `XX1' = `mahalanobis' if _treated==1, dev noc
			mat `w' = syminv((`XX0' + `XX1')/($N_total - 2))
		}
		local matchon `mahalanobis'
	}
	else local matchon `pscore'

	if ("`method'"=="neighbor" & "`metric'"=="pscore") {

		if ("`ties'"!="") local ties 1
		else local ties 0

		if ("`noreplacement'"!="") local noreplace 1
		else local noreplace 0

                tempvar idlist ismatch
                qui g `ismatch' = 0
		qui g `idlist' = .
		
		if ("`ties'"!="") char _weight[Type] "aweight"
		else char _weight[Type] "fweight"
		
		if ("`ate'"!="") {
			local j0 = $N_control + 1
			mata : match_nn(`j0', $N_total, 1, $N_control, `neighbor', `caliper', `noreplace', `ties', "$OUTVAR", "`moutvar'")
			qui replace _support = 0 if _n1>=. & _treated==0
		}
		local i = $N_control + 1
		mata : match_nn(1, $N_control, `i', $N_total, `neighbor', `caliper', `noreplace', `ties', "$OUTVAR", "`moutvar'")
		qui replace _support = 0 if _n1>=. & _treated==1
		/* difference pscore between treat obs and nearest match */
		qui g double _pdif = abs(_pscore - _pscore[_n1])
		label var _pdif "psmatch2: abs(pscore - pscore[nearest neighbor])"
	}
	if ("`method'"=="neighbor" & "`metric'"=="mahalanobis") {
		char _weight[Type] "fweight"
		qui _Match_mahalanobis `mahalanobis', out(`outcome') caliper(`caliper') pcaliper(`pcaliper') w(`w') `ate'
	}
	if ("`method'"=="kernel") {
		char _weight[Type] "aweight"
		qui _Match_kernel `matchon', out(`outcome') metric(`metric') kerneltype(`kerneltype') bw(`bwidth') w(`w') `ate'
	}
	if ("`method'"=="llr") {
		char _weight[Type] "iweight"
		qui _Match_llr `matchon', out(`outcome') metric(`metric') kerneltype(`kerneltype') bw(`bwidth') w(`w') `ate'
	}

	/* controls off support */
	qui replace _weight = . if _weight==0 | _support==0

	// generate output
	if ("`outcome'"!="") _mktab `outcome', `ate' `spline' `llr' kerneltype(`kerneltype')

	/* get rid of evil globals */
	macro drop N_control N_total NN OUTVAR
end

/****************************************/
/*         FORMAT OUTPUT TABLE          */
/****************************************/
cap program drop _mktab
program define _mktab, rclass
syntax varlist [, ate spline llr kerneltype(string)]

/* create header output table */
di as text "{hline 28}{c TT}{hline 59}"
di as text "        Variable     Sample {c |}    Treated     Controls   Difference         S.E.   T-stat"
di as text "{hline 28}{c +}{hline 59}"

/* create body and return results */
qui foreach v of varlist `varlist' {
	/* no matched outcome for obs off support */
	replace _`v' = . if _support==0

	tempname m1t m0t u0u u1u att dif0
	sum `v' if _treated==1, mean
	scalar `u1u' = r(mean)
	sum `v' if _treated==0, mean
	scalar `u0u' = r(mean)

	sum `v' if _treated==1 & _support==1, mean
	scalar `m1t' = r(mean)
	local n1 = r(N)
	sum _`v' if _treated==1 & _support==1, mean
	scalar `m0t' = r(mean)

	scalar `att' = `m1t' - `m0t'
	scalar `dif0' = `u1u' - `u0u'

	return scalar att = `att'
	return scalar att_`v' = `att'

	if "`ate'"!="" {
		tempname m0u m1u atu ate
		sum _`v' if _treated==0 & _support==1, mean
		scalar `m1u' = r(mean)
		sum `v' if _treated==0 & _support==1, mean
		scalar `m0u' = r(mean)
		local n0 = r(N)

		scalar `atu' = `m1u' - `m0u'
		scalar `ate' = `att'*`n1'/(`n0'+`n1') + `atu'*`n0'/(`n0'+`n1')

		return scalar atu = `atu'
		return scalar atu_`v' = `atu'
		return scalar ate = `ate'
		return scalar ate_`v' = `ate'
	}

	// calculate approx s.e.'s
	tempname wtot var1 var0 stderr number ols seols	 
	tempvar w2
	
	qui sum `v' if _treated==1 & _support==1  
	scalar `number' = r(N)
	scalar `var1'   = r(Var)
	
	qui sum `v' if _treated==0 & _weight<.
	scalar `var0'   = r(Var)

	qui gen `w2' = _weight^2 if _treated==0
	qui sum `w2'
	scalar `wtot' = r(sum)

	if ("`spline'"!="") | ("`llr'"!="" & "`kerneltype'"=="tricube")   {
		scalar `stderr' = .
		local warning no
	}
	else scalar `stderr' = sqrt( (`var1')/`number' + (`wtot'/(`number'^2))*`var0' )

	return scalar seatt = `stderr'
	return scalar seatt_`v' = `stderr'

	qui regress `v' _treated
	scalar `ols' = _b[_treated]
	scalar `seols' = _se[_treated]

	noi di as text %16s abbrev("`v'",16) "  Unmatched {c |}" as result %11.0g `u1u' "  " %11.0g `u0u' "  " %11.0g `ols' "  " %11.0g `seols' "  " %7.2f `ols'/`seols'
	noi di as text              _col(17) "        ATT {c |}" as result %11.0g `m1t' "  " %11.0g `m0t' "  " %11.0g `att'	"  " %11.0g `stderr' "  " %7.2f `att'/`stderr'

	if ("`ate'"!="") {
		noi di as text _col(17) "        ATU {c |}" as result %11.0g `m0u' "  " %11.0g `m1u' "  " %11.0g `atu'
		noi di as text _col(17) "        ATE {c |}" _col(56) as result %11.0g `ate'
	}
	noi di as text "{hline 28}{c +}{hline 59}"
}
if ("`warning'"=="") di in w "Note: S.E. for ATT does not take into account that the propensity score is estimated."

tab _treated _support

end


/* MAHALANOBIS NEAREST NEIGHBOR MATCHING */
cap program drop _Match_mahalanobis
program define _Match_mahalanobis
	syntax varlist(min=1) [, OUTcome(varlist) PCALiper(string) CALiper(string) Neighbor(real 1) W(string) ATE]
	tempname dif pdif base

	_Dif_mbase `varlist', base(`base') w(`w')

	g _mdif = .
	label var _mdif "psmatch2: Difference with match on Mahalanobis metric"

	if ("`ate'"!="") {
		local start 1
	}
	else local start = $N_control + 1

	forvalues obs = `start'/$N_total {
		/* generate difference variable if we match within pscore caliper, otherwise cap */
		if ("`pcaliper'"!=".") {
			_Dif_pscore _pscore if _support==1 & _treated==(`obs'<=$N_control), obs(`obs') dif(`pdif')
			_Dif_mahalanobis `varlist' if _support==1 & _treated==(`obs'<=$N_control) & abs(`pdif')<`pcaliper', obs(`obs') dif(`dif') base(`base') w(`w')
		}
		else _Dif_mahalanobis `varlist' if _support==1 & _treated==(`obs'<=$N_control), obs(`obs') dif(`dif') base(`base') w(`w')

		/* find nearest neighbor */
		sum `dif', mean
		if (r(min)<`caliper') {
			replace _mdif = r(min) in `obs'
			sum _id if `dif'==r(min), mean
			replace _weight = _weight + 1 in `r(min)'
			replace _n1 = r(min) in `obs'
		}
		else replace _support = 0 in `obs'

		drop `dif'
		cap drop `pdif'
	}

	if ("`outcome'"!="") {
		foreach v of varlist `outcome' {
			qui replace _`v' = `v'[_n1]
		}
	}
end

/* KERNEL MATCHING */

cap program drop _Match_kernel
program define _Match_kernel
	syntax varlist(min=1) [, OUTcome(varlist) Kerneltype(string) BWidth(real 0.06) CALiper(string) METric(string) W(string) ATE]
	tempname weight dif base
	tempvar out

	if ("`metric'"=="mahalanobis") {
		_Dif_mbase `varlist', base(`base') w(`w') 
	}

	if ("`ate'"!="") {
		local start 1
	}
	else local start = $N_control + 1

	forvalues obs = `start'/$N_total {
		_Dif_`metric' `varlist' if _support==1 & _treated==(`obs'<=$N_control), obs(`obs') dif(`dif') base(`base') w(`w')
		_Kernel_ `kerneltype' `weight' `dif' `bwidth'
		replace _weight = _weight + `weight' if `weight'!=.
	
		if ("`outcome'"!="") {
			foreach v of varlist `outcome' {
				sum `v' [aw=`weight'] if _support==1 & _treated==(`obs'<=$N_control), mean
				if r(mean)!=. {
					replace _`v' = r(mean) in `obs'
				}
			}
		}
		cap assert `weight'==.
		if (_rc==0) {
			 replace _support = 0 in `obs'
		}

		drop `weight' `dif'
	}
end

/* LLR MATCHING */

cap program drop _Match_llr
program define _Match_llr
	syntax varlist(min=1) [, OUTcome(varlist) Kerneltype(string) BWidth(real 0.06) CALiper(string) METric(string) W(string) ATE]

	tempname weight dif V base
	tempvar out

	if ("`metric'"=="mahalanobis") {
		_Dif_mbase `varlist', base(`base') w(`w')
	}

	if ("`ate'"!="") {
		local start 1
	}
	else local start = $N_control + 1

	forvalues obs = `start'/$N_total {
		_Dif_`metric' `varlist' if _support==1 & _treated==(`obs'<=$N_control), obs(`obs') dif(`dif') base(`base') w(`w')
		_Kernel_ `kerneltype' `weight' `dif' `bwidth'
		sum `dif' [aw=`weight']
		scalar `V' = r(Var)*(r(N)-1)/r(N)
		replace _weight = _weight + `weight'*(`V' + r(sum)^2 - r(sum)*`dif')/`V' if `weight'!=.
		if ("`outcome'"!="") {
			foreach v of varlist `outcome' {
				cap reg `v' `dif' [aw=`weight'] if _support==1 & _treated==(`obs'<=$N_control)
				if (!_rc) {
					replace _`v' = _b[_cons] in `obs'
				}
				else replace _support = 0 in `obs'
			}
		}
		drop `weight' `dif'
	}
end


/* COMMON SUPPORT FUNCTIONS */
cap program drop _Support_
program define _Support_
	syntax varname [, level(real 100) untreated ate]
	if (`level'==100) {
		sum `varlist' if _treated==0, mean
		replace _support = 0 if (`varlist'<r(min) | `varlist'>r(max)) & _treated==1
		if ("`ate'"!="") {
			sum `varlist' if _treated==1, mean
			replace _support = 0 if (`varlist'<r(min) | `varlist'>r(max)) & _treated==0
		}
	}
	else {
		_Support_trim `varlist', level(`level')
		if ("`ate'"!="") {
			_Support_trim `varlist', level(`level') treated(0)
		}
	}
end


cap program drop  _Support_trim
program define _Support_trim
	syntax varname [, level(real 100) treated(integer 1)]
	tempvar x0 y0
	kdensity `varlist' if _treated==(1-`treated'), nograph at(`varlist') gen(`x0' `y0')
	replace _support = 0 if `y0'==0 & _treated==`treated'
	if (`level'>0) {
		_pctile `y0' if _treated==`treated', p(`level')
		replace _support = 0 if `y0'<r(r1) & _treated==`treated'
	}
end


/* DIFFERENCING FUNCTIONS */
cap program drop _Dif_pscore
program define _Dif_pscore
	syntax varname [if], obs(int) dif(string) [base(string) W(string)]
	qui g double `dif' = (`varlist' - `varlist'[`obs']) `if'
end

cap program drop _Dif_mahalanobis
program define _Dif_mahalanobis
	syntax varlist [if], obs(int) dif(string) base(string) W(string)
	tokenize `varlist'
	tempname b
	local k : word count `varlist'
	/* extract data row vector x[i] into b */
	mat `b' = J(1,`k',`1'[`obs'])
	mat colname `b' = `varlist'
	forvalues i = 2/`k' {
		mat `b'[1,`i'] = ``i''[`obs']
	}
	/* calculate W*x[i] */
	mat `b' = `b'*`w'
	/* scoring gives x'Wx[i] */
	mat score double `dif' = `b' `if'
	/* the following then gives (x-x[i])*W(x-x[i]) */
	replace `dif' = `base' - 2*`dif' + `base'[`obs'] `if'
end


/* calculates x'Wx used by mahalanobis metric, needs to be done only once */
cap program drop _Dif_mbase
program define _Dif_mbase
	syntax varlist , base(string) W(string)
	tokenize `varlist'
	g double `base' = 0
	local k = rowsof(`w')
	forvalues i = 1/`k' {
		forvalues j = `i'/`k' {
			replace `base' = `base' + (1 + (`i'!=`j'))*`w'[`i',`j']*(``i'')*(``j'')
		}
	}
end


/* VARIOUS KERNELS */
cap program drop _Kernel_
program define _Kernel_
	args kernel weight dif bwidth
	
	if ("`kernel'"=="epan") {
		qui g double `weight' = 1 - (`dif'/`bwidth')^2 if abs(`dif')<=`bwidth'
	}
	else if ("`kernel'"=="normal") {
		qui g double `weight' = normden(`dif'/`bwidth')
	}
	else if ("`kernel'"=="biweight") {
		qui g double `weight' = (1 - (`dif'/`bwidth')^2)^2 if abs(`dif')<=`bwidth'
	}
	else if ("`kernel'"=="uniform") {
		qui g double `weight' = 1 if abs(`dif')<=`bwidth'
	}
	else if ("`kernel'"=="tricube") {
		qui g double `weight' = (1-abs(`dif'/`bwidth')^3)^3 if abs(`dif')<=`bwidth'
	}
	/* normalize sum of weights to 1 */
	sum `weight', mean
	replace `weight' = `weight'/r(sum)
end


version 9.0
mata:


void match_nn(real scalar j0, real scalar j1, real scalar i0, real scalar i1, real scalar neighbors, real scalar caliper, real scalar noreplace, real scalar ties, string outvar, string moutvar)
{
	real scalar dif0, dif1, obs, c, tmp, i, jmatch, j, k, v, nmatch, nout, forward, idx_idlist, idx_ismatch

	idx_idlist = st_addvar("float", st_tempname())
	idx_ismatch = st_addvar("byte", st_tempname())
	st_view(PSCORE,.,"_pscore")
	st_view(WEIGHT,.,"_weight")
	st_view(TREATED,.,"_treated")
	st_view(SUPPORT,.,"_support")
	st_view(N1,.,"_n1")
	st_view(NN,.,"_nn")
	st_view(ID,.,"_id")
	st_view(IDLIST,.,idx_idlist)
	st_view(ISMATCH,.,idx_ismatch)

	for(i=1; i<=rows(ISMATCH); i++) ISMATCH[i] = 0

	nout = rows(tokens(outvar))
	if (nout>0) {
		st_view(OUTVAR,.,tokens(outvar)) 
		st_view(MOUTVAR,.,tokens(moutvar))
	}

	nmatch = 0
	jmatch = j0
	forward = 1
	i = i0
	while (i<=i1 && jmatch>=j0 && jmatch<=j1) {
		j = jmatch
		dif1 = abs(PSCORE[i]-PSCORE[j])
		while (j>=j0 && j<j1) {
			j = next_unmatched(j,forward,noreplace,idx_ismatch)
			if (j<j0 || j>j1) break
			dif0 = dif1
			dif1 = abs(PSCORE[i]-PSCORE[j])
			if (dif1>dif0) j = j1
			if (dif1<dif0) jmatch = j
		}
		/* update match and match-ID variables */
		if (abs(PSCORE[i]-PSCORE[jmatch])<caliper) {
			N1[i] = jmatch
			ISMATCH[jmatch] = 1
			++nmatch
			IDLIST[nmatch] = ID[jmatch]
			/* match remaining ties */
			if (ties>0) {
				nmatch = match_ties(i,jmatch,j0,j1,nmatch,forward,noreplace,idx_idlist,idx_ismatch)
			}
			/* match remaining neighbors (1-to-many) */
			if (neighbors>1) {
				nmatch = match2(i,jmatch,j0,j1,neighbors,caliper,nmatch,idx_idlist)
			}
			for(k=1; k<=nmatch; k++) {
				obs = IDLIST[k]
				WEIGHT[obs] = WEIGHT[obs] + 1/nmatch
				if (nout>0) MOUTVAR[i,.] = MOUTVAR[i,.] + OUTVAR[obs,.]:/nmatch
			}
			NN[i] = nmatch
		} else SUPPORT[i] = 0
		if (jmatch==j1 && i<i1) forward=0
		if (noreplace==1 && nmatch>0) {
			jmatch = next_unmatched(jmatch,forward,noreplace,idx_ismatch)
		}
		nmatch = 0
		++i
	}
}


real scalar next_unmatched(real scalar j0, real scalar  forward, real scalar  noreplace, real scalar  idx_ismatch)
{
	real scalar j
	j = j0
	do {
		if (forward==1) ++j
		else --j
		
		if (noreplace==0) return(j)
	} while ( _st_data(j,idx_ismatch)==1 )
	return(j)
}


real scalar match2( real scalar obs, real scalar jm, real scalar j0, real scalar j1, real scalar neighbors, real scalar caliper, real scalar nmatch, real scalar idx_idlist)
{
	real scalar dif0, dif1, k, pos0, pos1, idx_id, jmatch

	st_view(PSCORE,.,"_pscore")
	st_view(ID,.,"_id")
	st_view(IDLIST,.,idx_idlist)

	jmatch = jm
	k = 1
	pos0 = jmatch - 1
	pos1 = jmatch + 1
	while (k<neighbors) {
		if (pos0>=j0) dif0 = abs(PSCORE[obs]-PSCORE[pos0])
		if (pos1<=j1) dif1 = abs(PSCORE[obs]-PSCORE[pos1])
		if ((dif0<=dif1 && pos0>=j0) || (pos0>=j0 && pos1>j1)) {
			jmatch = pos0
			--pos0
		} else if (pos1<=j1) {
			jmatch = pos1
			++pos1
		} else k = neighbors
		/* update match and match-ID variables */
		if (abs(PSCORE[obs]-PSCORE[jmatch])<caliper && k<neighbors) {
			++nmatch
			IDLIST[nmatch] = ID[jmatch]
			++k
		} else k = neighbors
	}
	return(nmatch)
}


real scalar match_ties(real scalar obs, real scalar jmatch, real scalar j0, real scalar j1, real scalar nmatch, real scalar forward, real scalar noreplace, real scalar idx_idlist, real scalar idx_ismatch)
{
	real scalar i, dif0, dif

	st_view(PSCORE,.,"_pscore")
	st_view(ID,.,"_id")
	st_view(IDLIST,.,idx_idlist)
	st_view(ISMATCH,.,idx_ismatch)

	dif0 = abs(PSCORE[obs]-PSCORE[jmatch])

	i = next_unmatched(jmatch, forward, noreplace, idx_ismatch)
	if (i<j0 || i>j1) return(nmatch)
	
	dif = abs(PSCORE[obs]-PSCORE[i])
	while (dif<=dif0) {
		++nmatch
		IDLIST[nmatch] = ID[i]
		if (noreplace==1) ISMATCH[i] = 1

		i = next_unmatched(i, forward, noreplace, idx_ismatch)
		if (i<j0 || i>j1) return(nmatch)
		
		dif = abs(PSCORE[obs]-PSCORE[i])
	}
	return(nmatch)
}


end
