** Setup STATA
global S_REPS = "$REPS"
clear all
version 10.1
set mem 1g
set more off
set linesize 255
set matsize 10000
set seed 12345
macro drop _all
cap log close

** REPS
global REPS = "$S_REPS"
if "$REPS"=="" global REPS=1999
di "$REPS IN THIS MASTER" 

** Setup global macro directory structure
global root     = "/rdcprojects/mc1/mc00535/"
global programs = "programs_organize"
global libdir   = "1.library"
global resultdir= "2.results"
global workfile = "3.workfile"
global dofiles  ="$root/$programs/3.estimation/"
global library  ="$root/$programs/$libdir/"
global censusdir="$dofiles/$workfile/"
global logs     = "$dofiles/1.logs/"

global results           = "$dofiles/$resultdir/"
global winloseresults    = "$dofiles/$resultdir/winlose"
global placeboresults    = "$dofiles/$resultdir/placebo"
global percentileresults = "$dofiles/$resultdir/percentile"
global noNYresults       = "$dofiles/$resultdir/samplenoNY"
global withSEZresults    = "$dofiles/$resultdir/samplewithSEZ"
global rejectedresults   = "$dofiles/$resultdir/samplerejected"

!mkdir $results
!mkdir $winloseresults
!mkdir $placeboresults   
!mkdir $percentileresults
!mkdir $noNYresults    
!mkdir $withSEZresults   
!mkdir $rejectedresults  

** Run auxiliary codes (ados)
run "$library/wild.ado"
run "$library/bo2.ado"
run "$library/wild_bo.ado"
run "$library/wild_bo_ci.ado"
run "$library/wild_ci.ado"

run "$library/spatialma_loo_norm.ado"
run "$library/sphdist.ado"
run "$library/deg2rad.ado"

run "$library/formatable.ado"
run "$library/formatvarnames.ado"
run "$library/logit2.ado"
run "$library/balance.ado"
run "$library/overlap.ado"
run "$library/movestuff.ado"

run "$library/pstest.ado"
run "$library/psmatch2.ado"

run "$library/earthdistance.ado"
run "$library/reweightvar.ado"

** Declare OUTCOMES (defined w/o the prefix d_)
#delimit ;

global cluster = "cg";

global outcomes1 "
       lnpop lnhh black college vacant samehouse
       lnvalue2 lnrent_value lnrent2 
       lnvalue2_hat lnrent2_hat lnrent_value_hat 
       lnvalue2_comp lnrent2_comp lnrent_value_comp samehouse_hat
       lnearnings logearn lntotearn lnjobs
       lnwage2 lnwage2_pow       
       lnwage2_hat lnwage2_pow_hat  lnwage2_comp lnwage2_pow_comp
       lnwkwage2 lnwkwage2_pow       
       lnwkwage2_hat lnwkwage2_pow_hat  lnwkwage2_comp lnwkwage2_pow_comp
       lnemplbd lnavrgwage lnest  
       ";

global outcomes2 "
        lnjobs_local lnjobs_nonlocal lnjobs_outside 
        lnwage2_local lnwage2_nonlocal lnwage2_outside
	lnwage2_local_hat lnwage2_nonlocal_hat lnwage2_outside_hat 
        lnwage2_local_comp lnwage2_nonlocal_comp lnwage2_outside_comp
        lnwkwage2_local lnwkwage2_nonlocal lnwkwage2_outside 
        lnwkwage2_local_hat lnwkwage2_nonlocal_hat lnwkwage2_outside_hat
        lnwkwage2_local_comp lnwkwage2_nonlocal_comp lnwkwage2_outside_comp
        qd qd_hat 
	lnincw2 lnincw2_pow lnincw2_local lnincw2_nonlocal lnincw2_outside
	lnincw2_hat lnincw2_pow_hat lnincw2_local_hat lnincw2_nonlocal_hat lnincw2_outside_hat
	lnincw2_comp lnincw2_pow_comp lnincw2_local_comp lnincw2_nonlocal_comp lnincw2_outside_comp
	lnwage3_local lnwage3_local_hat lnwage3_local_comp
	lnwkwage3_local lnwkwage3_local_hat lnwkwage3_local_comp
	lnincw3_local lnincw3_local_hat lnincw3_local_comp
	"; 	  

global outcomes3 "
       employed unemployed poverty 
       employed_hat unemployed_hat poverty_hat
       employed_comp poverty_comp unemployed_comp  
       lnest_less5 lnest_more5 lnest_92univ lnemp_less5 lnemp_more5 lnemp_92univ lnavrgwage_less5 
       lnavrgwage_more5 lnavrgwage_92univ lnwagebill_less5 lnwagebill_more5 lnwagebill_92univ beta_all occshare
       lnest_less5now lnest_more5now lnemp_less5now lnemp_more5now lnavrgwage_less5now
       lnavrgwage_more5now lnwagebill_less5now lnwagebill_more5now
       sh_employed sh_unemployed sh_poverty sh_lnvalue2 sh_lnrent2 sh_lnwage2
       sh_employed_hat sh_unemployed_hat sh_poverty_hat sh_lnwage2_hat 
       sh_lnvalue2_hat sh_lnrent2_hat nsh_lnvalue2_hat nsh_lnrent2_hat nsh_lnrent2 nsh_lnvalue2
       sh_lnvalue2_comp sh_lnrent2_comp nsh_lnvalue2_comp nsh_lnrent2_comp  
       crimerate_city crime_violent crime_property crime_total pupil_teacher_ratio lndiploma_recipients
       lnfemale_jobs lnmale_jobs lnfemale_jobs_local lnmale_jobs_local lnfemale_jobs_nonlocal lnmale_jobs_nonlocal
       lnfemale_jobs_outside lnmale_jobs_outside
       female_lnwage2 male_lnwage2 male_lnwage2_pow female_lnwage2_pow male_lnwage2_local female_lnwage2_local
       male_lnwage2_nonlocal female_lnwage2_nonlocal male_lnwage2_outside female_lnwage2_outside 
       female_lnwkwage2 male_lnwkwage2 male_lnwkwage2_pow female_lnwkwage2_pow male_lnwkwage2_local female_lnwkwage2_local
       male_lnwkwage2_nonlocal female_lnwkwage2_nonlocal male_lnwkwage2_outside female_lnwkwage2_outside
       lnhhincw2 lnhhincp2
	";

global outcomes "$outcomes1 $outcomes2 $outcomes3";

** Declare COVARIATES;
global X_city "l_d_lnpop_city l_d_epop_city cbd90 l_black_city l_crime_city l_manufacture_city  l_pctgov_city ";
global X_sma  "pov25_sma pov35_sma l_black_sma l_dropout_sma l_female_head_sma l_gt65_sma l_hisp_sma l_lt18_sma  
               l2_black_sma l2_dropout_sma l2_female_head_sma l2_gt65_sma l2_hisp_sma l2_lt18_sma       
               l_buildingage_sma l_vacant_sma l2_vacant_sma 
               l_d_commutelt25_sma l_d_lnpop_sma l_d_lnhh_sma l_d_lnrent2_sma l_d_lnvalue2_sma 
               l_d_lnavrgwage_sma l_d_lnemplbd_sma l_d_lnjobs_sma 
               l_d_college_pow_sma l_d_lnwkwage2_pow_sma l_d_lnwkwage2_sma";
global X_1 "l_beta_all_sma l_unemployed_sma l_employed_sma l_d_lnest_sma l_d_lnincw2_sma l_d_lnincw2_pow_sma";

** Declare other necessary variables;
global Z_1  "lnwage2_local lnincw2_local lnwkwage2_local male_lnwage2_local female_lnwage2_local
	     lnwage2_nonlocal lnincw2_nonlocal lnwkwage2_nonlocal male_lnwage2_nonlocal female_lnwage2_nonlocal
	     lnwage2_outside lnincw2_outside lnwkwage2_outside male_lnwage2_outside female_lnwage2_outside l_d_college_sma
	     l2_unemployed_sma l_d_employed_sma l_employed_sma l_lnwkwage2_pow_sma  l_lnavrgwage_sma  l_d_lnincw2_sma 
             l_d_lnincw2_pow_sma l_d_college_sma l_college_sma l_samehouse_sma"; 

** Declare covariates on which assess balance;
global X_BAL1 "
	   l_econindex1 l_employed l_unemployed l_poverty
	   l_econindex2 l_lnjobs l_lnwkwage2_pow l_lnwkwage2 
	   l_econindex3 l_lnemplbd l_lnest l_lnavrgwage
           l_demoindex l_female_head l_college l_dropout l_black l_hisp     
	   l_popindex l_lnpop l_lnhh l_samehouse
           l_housingindex l_lnrent2 l_lnvalue2  l_vacant 
           l_crime_city l_black_city l_manufacture_city l_pctgov_city l_lnpop_city
           treatedcity";

global X_BAL2 "
	   l_d_econindex1 l_d_employed l_d_unemployed l_d_poverty 
	   l_d_econindex2 l_d_lnjobs  l_d_lnwkwage2_pow l_d_lnwkwage2 
	   l_d_econindex3 l_d_lnemplbd l_d_lnest l_d_lnavrgwage 
           l_d_demoindex l_d_female_head l_d_college l_d_dropout l_d_black l_d_hisp     
	   l_d_popindex l_d_lnpop l_d_lnhh l_d_samehouse
           l_d_housingindex l_d_lnrent2 l_d_lnvalue2  l_d_vacant
           l_d_crime_city l_d_black_city l_d_manufacture_city l_d_pctgov_city l_d_lnpop_city
	";
           
global X_BAL3 "
           l_d_lnjobs_local l_d_lnjobs_nonlocal l_d_lnjobs_outside 
           l_d_lnwkwage2_local l_d_lnwkwage2_nonlocal l_d_lnwkwage2_outside   
           ";
              
global X_BAL "$X_BAL1 $X_BAL2 $X_BAL3";

global PLOT1 "
          lnpop employed lnjobs lnjobs_local lnjobs_nonlocal lnjobs_outside lnwkwage2 lnwkwage2_local 
          lnwkwage2_nonlocal lnwkwage2_outside lnrent2 lnvalue2  popindex demoindex econindex3 econindex2 econindex1 housingindex";

** Declare covariates used in the construction of the placebo tracts.;
    global PCBO_interactions "poverty unemployed lnpop lnjobs";
    global PCBO_1 "pov25 pov35 l_black l_dropout l_female_head l_gt65 l_hisp l_lt18";
    global PCBO_2 "l2_black l2_dropout l2_female_head l2_gt65 l2_hisp l2_lt18";
    global PCBO_3 "l_buildingage l_vacant l2_vacant l_d_commutelt25 l_d_lnpop l_d_lnhh l_d_lnrent2 l_d_lnvalue2";
    global PCBO_4 "l_d_lnavrgwage l_d_lnemplbd l_d_lnjobs l_d_college_pow l_d_lnwage2_pow l_d_lnwage2";
    global PCBO_5 "l_beta_all l_employed l_lnjobs l_employed cbd90 l_lnrent2 l_beta_all l_unemployed l_employed";
#delimit cr

