args SPECIFICATION ESTIMATOR TrimLO TrimHI TYPE flag
**** setup
if "`TYPE'"=="winlose_gt10"          local results = "$winloseresults"
if "`TYPE'"=="placebo_gt10"          local results = "$placeboresults"
if "`TYPE'"=="percentile_gt10"       local results = "$percentileresults"
if "`TYPE'"=="noNY_gt10"             local results = "$noNYresults"
if "`TYPE'"=="withSEZ_gt10"          local results = "$withSEZresults"
if "`TYPE'"=="rejected_gt10"         local results = "$rejectedresults"
local NAME= "SPEC`SPECIFICATION'_`TrimLO'_`TrimHI'_`TYPE'_`ESTIMATOR'_`flag'"

cap run "/rdcprojects/mc1/mc00535/programs_organize/3.estimation/1.setup.do"
if _rc!=0 di in red "run 1.setup.do"
cap log close

************************************
***   Data and Sample Restriction***
************************************
log using "`results'/results_`NAME'.log", replace text
if "`TYPE'"=="winlose_gt10"{
   use "$censusdir/workfile_90_winlose.dta", clear

   drop if (city=="Cleveland city" | city=="Los Angeles city") & assigned_tract==1
   drop if city=="Washington city"

   gen mark = population_city>100000 if year==1990
   gen mark2 = mark*population_city 
   egen mark3 = max(mark2), by(progid_power)
   drop if mark3==. //city with population missing (Charleston, WV)
   gen aux = (progid_power!=. & mark3>100000)
   egen aux2 = sum(yr==4), by(progid_power)
   replace aux2 = aux2>10
   egen marksample = max(aux*aux2),by(id)
   replace marksample=1 if city=="Corpus Christi city"
   drop mark2 mark3
}

if "`TYPE'"=="placebo_gt10"{
   use "$censusdir/workfile_90_placebo.dta", clear
   gen assigned_tract_holder = assigned_tract
   drop assigned_tract
   gen assigned_tract = assigned_placebofar

   drop if (city=="Cleveland city" | city=="Los Angeles city") & (assigned_tract==1 | assigned_tract_holder==1)
   drop if city=="Washington city"

   gen mark = population_city>100000 if year==1990
   gen mark2 = mark*population_city 
   egen mark3 = max(mark2), by(progid_placebo)
   gen aux = (progid_placebo!=. & mark3>100000)
   egen aux2 = sum(yr==4), by(progid_placebo)
   replace aux2 = (aux2>10 | assigned_tract==1)
   egen marksample = max(aux*aux2),by(id)
   replace marksample=1 if city=="Corpus Christi city"
   drop mark2 mark3
   replace progid_power=progid_placebo
   tsset id yr
}

if "`TYPE'"=="percentile_gt10" {
   use "$censusdir/workfile_90_percentile.dta" if assigned_tract!=., clear
   drop if (city=="Cleveland city" | city=="Los Angeles city")&assigned_tract==1
   drop if city=="Washington city"
   gen mark = population_city>100000 if year==1990
   gen mark2 = mark*population_city 
   egen mark3 = max(mark2), by(progid_power)
   drop if mark3==. //city with population missing (Charleston, WV)
   gen aux = (progid_power!=. & mark3>100000)
   egen aux2 = sum(yr==4), by(progid_power)
   replace aux2 = aux2>10
   egen marksample = max(aux*aux2),by(id)
   replace marksample=1 if city=="Corpus Christi city"
   drop mark2 mark3
}

if "`TYPE'"=="rejected_gt10" {
   use "$censusdir/workfile_90_winlose.dta", clear
   drop if (city=="Cleveland city" | city=="Los Angeles city")
   drop if city=="Washington city"
   gen aux = (application_tract ==1 | assigned_tract==1)
   egen aux2 = sum(yr==4), by(progid_power)
   replace aux2 = aux2>10
   egen marksample = max(aux*aux2),by(id)
}

if "`TYPE'"=="withSEZ_gt10" {
   use "$censusdir/workfile_90_winlose.dta", clear
   drop if city=="Washington city"
   gen mark = population_city>100000 if year==1990
   gen mark2 = mark*population_city 
   egen mark3 = max(mark2), by(progid_power)
   drop if mark3==. //city with population missing (Charleston, WV)
   gen aux = (progid_power!=. & mark3>100000)
   egen aux2 = sum(yr==4), by(progid_power)
   replace aux2 = aux2>10
   egen marksample = max(aux*aux2),by(id)
   replace marksample=1 if city=="Corpus Christi city"
   drop mark2 mark3
}

if "`TYPE'"=="noNY_gt10" {
   use "$censusdir/workfile_90_winlose.dta", clear
   drop if (city=="Cleveland city" | city=="Los Angeles city") & assigned_tract==1
   drop if city=="Washington city"
   drop if city=="New York city"

   gen mark = population_city>100000 if year==1990
   gen mark2 = mark*population_city 
   egen mark3 = max(mark2), by(progid_power)
   drop if mark3==. //city with population missing (Charleston, WV)
   gen aux = (progid_power!=. & mark3>100000)
   egen aux2 = sum(yr==4), by(progid_power)
   replace aux2 = aux2>10
   egen marksample = max(aux*aux2),by(id)
   replace marksample=1 if city=="Corpus Christi city"
   drop mark2 mark3
}

******************************************
*** SAMPLE CONSTRAINTS                 ***
******************************************
keep if marksample==1

*** Drop according to EZ application requirements
    foreach var of varlist unemployed poverty pop hh jobs jobs_local lnemplbd{
      cap drop `var'_90
      gen `var'_90=`var' if year==1990
      cap drop big_`var'
      egen big_`var'=mean(`var'_90), by(tractid90)
      egen min_`var'=min(`var'), by(tractid90)
    }

*** Gen zone-level covariates 
    egen zonesize=sum(area) if yr==3, by(progid_power)
    gen l_lnzonesize=ln(l.zonesize) if yr==4

*** poverty, pop, hh and pop restrictions
    drop if (big_poverty<0.2 | big_unemployed<0.063)
    drop if big_hh<200|big_pop<500

*************************************
**** Propensity Score Estimation ****
*************************************
log on
if "`SPECIFICATION'"=="1" {
    logit2 assigned_tract $X_city $X_sma $X_1 l_lnzonesize lnhpi1991 lnhpi1992, spec(1) cluster($cluster) trimpointU(`TrimHI') trimpointL(`TrimLO')
    log off
}

*************************************
**** Generate indices            ****
*************************************
keep if touse==1
if "`TYPE'"=="winlose_gt10" save "$censusdir/4indexmerge.dta", replace 
run "$dofiles/2d.workfile_indices.do"

*************************************
**** Decision about pscore       ****
*************************************
*** pscore
    gen phat = phat`SPECIFICATION'
    cap drop aux
    egen aux = mean(phat), by(tractid90)
    replace phat = aux
    drop aux

*** Weights
    cap drop wTOT
    bo2 area_city $X if yr==4 & phat!=., t(assigned_tract) gen(wTOT)
    egen wTOT2=mean(wTOT), by(tractid90)
    replace wTOT=wTOT2 if assigned_tract==0 & e(sample)
    replace wTOT=1 if assigned_tract==1 & e(sample)
    egen aux = mean(wTOT), by(tractid90)
    replace wTOT = aux
    drop aux

cap log on


**********************************************
*****            OVERLAP                  ****
**********************************************

*** Weights properties
    sum wTOT if yr==3 & assigned_tract==1 & touse==1 , de
    di "SUM=" r(sum)
    sum wTOT if yr==3 & assigned_tract==0 & touse==1 , de
    di "SUM=" r(sum)
    codebook city if yr==4 & wTOT!=.
    overlap phat if year==1990, treatment(assigned_tract)
cap log off

**********************************************
*****            BALANCE                  ****
**********************************************
cap log on
di "covariates = $X"

if "`flag'"!="nobalance"{
    if "$REPS"=="" global REPS = 2
    di "REPS=$REPS"
	*** TABLES
	if "`flag'"=="wild_off"{
               balance $X_BAL1 if yr==4 & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(off) dir("`results'/BAL1_`NAME'.dta")
	       balance $X_BAL2 if yr==4 & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(off) dir("`results'/BAL2_`NAME'.dta")
	       balance $X_BAL3 if yr==4  & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(off) dir("`results'/BAL3_`NAME'.dta")
        }
	if "`flag'"=="wild_on"{
               balance $X_BAL1 if yr==4 & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(on) reps($REPS) dir("`results'/BAL1_`NAME'.dta")
	       balance $X_BAL2 if yr==4 & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(on) reps($REPS) dir("`results'/BAL2_`NAME'.dta")
	       balance $X_BAL3  if yr==4 & phat!=., by(assigned_tract) controls($X) cluster($cluster) wild(on) reps($REPS) dir("`results'/BAL3_`NAME'.dta")
        }

*** COMPILE BALANCE TABLES
        preserve
        use "`results'/BAL1_`NAME'.dta", clear
        gen table = 1
        append using "`results'/BAL2_`NAME'.dta"
        replace table = 2 if table==.
        append using "`results'/BAL3_`NAME'.dta"
        replace table = 3 if table==.
        order table covariate 
        save "`results'/balance_table_`NAME'.dta", replace
        erase "`results'/BAL1_`NAME'.dta"
        erase "`results'/BAL2_`NAME'.dta"
        erase "`results'/BAL3_`NAME'.dta"
        restore
*** PLOTS 
	do "$dofiles/4.balance.do" `SPECIFICATION' `TrimLO' `TrimHI' `TYPE'
}
cap log close
keep if touse==1
di "$REPS"

