args  SPECIFICATION ESTIMATOR TrimLO TrimHI TYPE flag

**** setup
if "`TYPE'"=="winlose_gt10"          local results = "$winloseresults"
if "`TYPE'"=="placebo_gt10"          local results = "$placeboresults"
if "`TYPE'"=="percentile_gt10"       local results = "$percentileresults"
if "`TYPE'"=="noNY_gt10"             local results = "$noNYresults"
if "`TYPE'"=="withSEZ_gt10"          local results = "$withSEZresults"
if "`TYPE'"=="rejected_gt10"         local results = "$rejectedresults"
local NAME= "SPEC`SPECIFICATION'_`TrimLO'_`TrimHI'_`TYPE'_`ESTIMATOR'_`flag'"

*** organize dataset of results
    use "`results'/results_`NAME'.dta", clear
    foreach var of global outcomes{
       replace outcome = "`var'" if outcome=="d_`var'"
    }
    compress

*** pvalues
qui{
    gen tstat = abs(coeff/se)
    gen star     = "*"   if tstat>invnorm(0.95)  & tstat<.
    replace star = "**"  if tstat>invnorm(0.975) & tstat<.
    replace star = "***" if tstat>invnorm(0.995) & tstat<.
    foreach estimator in 2.wild 2.wildbo {
       replace star = ""    if estimator=="`estimator'"
       replace star = "*"   if pvalue<.1 & estimator=="`estimator'"
       replace star = "**"  if pvalue<.05 & estimator=="`estimator'"
       replace star = "***" if pvalue<.01 & estimator=="`estimator'"
    }
    replace star = ""    if              estimator=="1.naive" & ("`ESTIMATOR '"=="wild" | "`ESTIMATOR '"=="wildbo")
    replace star = "*"   if pvalue<.1  & estimator=="1.naive" & ("`ESTIMATOR '"=="wild" | "`ESTIMATOR '"=="wildbo")
    replace star = "**"  if pvalue<.05 & estimator=="1.naive" & ("`ESTIMATOR '"=="wild" | "`ESTIMATOR '"=="wildbo")
    replace star = "***" if pvalue<.01 & estimator=="1.naive" & ("`ESTIMATOR '"=="wild" | "`ESTIMATOR '"=="wildbo")
    drop tstat

*** Format coefficient and se
   foreach var in coeff se{
      format `var' %9.3f
   }

*** Identify adjusted/composition, samehouse/newarrivals, migration-logits, lbd effects
   gen adjusted = 0
   replace adjusted = 1 if regexm(outcome,"_hat")==1
   replace adjusted = 2 if regexm(outcome,"_comp")==1
   gen samehouse = 0
   replace samehouse = 1 if regexm(outcome,"_sh")==1 | regexm(outcome,"sh_")==1
   replace samehouse = 2 if regexm(outcome,"_nsh")==1 | regexm(outcome,"nsh_")==1
   gen mig_logit = regexm(outcome,"beta")==1
   gen lbd = regexm(outcome,"lnemp")==1 | regexm(outcome,"lnest")==1 | regexm(outcome,"lnavrgwage")==1 | regexm(outcome,"lnwagebill") 
   gen gender = 0
   replace gender = 1 if regexm(outcome,"male")==1 
   replace gender = 2 if regexm(outcome,"female")==1

   foreach var of global outcomes{
     replace outcome = regexr(outcome,"_hat","")
     replace outcome = regexr(outcome,"_comp","")
     replace outcome = regexr(outcome,"_nsh","")
     replace outcome = regexr(outcome,"nsh_","")
     replace outcome = regexr(outcome,"_sh","")
     replace outcome = regexr(outcome,"sh_","")
     replace outcome = regexr(outcome,"female_","")
     replace outcome = regexr(outcome,"male_","")
   }

tempfile data
save `data', replace
}

cap log close
log using "`results'/results_`NAME'.log", append text
log off
*************************************************
***                  TABLES                   ***
*************************************************
**** TABLE 4      ---------------------------------------------------------------------------------------------
use `data', clear
gen order = .
replace order = 1 if regexm(outcome,"lnemp")==1
replace order = 2 if regexm(outcome,"lnest")==1
replace order = 3 if regexm(outcome,"lnavrgwage")==1
replace order = 4 if regexm(outcome,"lnwagebill")==1
gen panel = .
replace panel = 1 if regexm(outcome,"_92univ")==0 &  regexm(outcome,"_less5")==0&   regexm(outcome,"_more")==0
replace panel = 2 if regexm(outcome,"_92univ")==1 &  regexm(outcome,"_less5")==0&   regexm(outcome,"_more")==0
replace panel = 3 if regexm(outcome,"_92univ")==0 &  regexm(outcome,"_less5")==1 &   regexm(outcome,"_more")==0
replace panel = 4 if regexm(outcome,"_92univ")==0 &  regexm(outcome,"_less5")==0 &   regexm(outcome,"_more")==1
replace panel = 5 if regexm(outcome,"_92univ")==0 &  regexm(outcome,"_less5now")==1 &   regexm(outcome,"_more5now")==0
replace panel = 6 if regexm(outcome,"_92univ")==0 &  regexm(outcome,"_less5now")==0 &   regexm(outcome,"_more5now")==1
replace panel = 7 if order==4
keep if lbd==1 & panel<=6
egen ord = group(panel order)
replace ord = ord+5
formatable coeff se star N,  depvars(outcome) select(estimator) ord(ord) stars
log on
di "$REPS REPS USED IN THESE s.e."
di ""
***** TABLE 4: WAGE AND JOB IMPACTS, LBD 2000***********
list, clean noheader noobs
log off
gen order = _n
gen table = 4
save "`results'/formatresults_`NAME'.dta", replace

**** TABLE 5-------------------------------------------------------------------------------
use `data', clear
drop if samehouse>0 | lbd==1 | mig_logit ==1 | adjusted>0 | gender>0 | dropout>0
keep if outcome=="lnjobs" | outcome=="lnjobs_nonlocal" | outcome=="lnjobs_local"| outcome=="lnjobs_outside"
gen ord = 1 if outcome=="lnjobs"
replace ord = 2 if outcome=="lnjobs_local"
replace ord = 3 if outcome=="lnjobs_nonlocal"
replace ord = 4 if outcome=="lnjobs_outside"
replace ord = ord+5
formatable coeff se star N,  depvars(outcome) select(estimator) ord(ord) stars
log on
***** TABLE 5: EMPLOYMENT IMPACTS, JTW***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 5
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


**** TABLE 6-------------------------------------------------------------------------------
use `data', clear
drop if samehouse>0 | lbd==1 | mig_logit ==1 | gender>0 | dropout>0
keep if outcome=="lnwage2" | outcome=="lnwage2_pow" | outcome=="lnwage2_local" | outcome=="lnwage2_nonlocal" | outcome=="lnwage2_outside" 
gen ord = 1 if outcome=="lnwage2"
replace ord = 2 if outcome=="lnwage2_pow"
replace ord = 3 if outcome=="lnwage2_local"
replace ord = 4 if outcome=="lnwage2_nonlocal"
replace ord = 5 if outcome=="lnwage2_outside"

replace ord = ord+5
formatable coeff se star N,  depvars(outcome) select(estimator adjusted) ord(ord) stars
log on
***** TABLE 6: WAGE IMPACTS, JTW ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 6
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


**** TABLE 7 -----------------------------------------------------------------------------------------------------------
use `data', clear
drop if samehouse>0 | lbd==1 | mig_logit ==1 | gender>0 | dropout>0
keep if outcome =="lnvalue2" | outcome =="lnrent2" | outcome=="lnhh" | outcome=="lnpop" | outcome=="vacant" | outcome=="samehouse"
replace outcome = outcome+"_unadjusted" if adjusted==0 & (outcome =="lnvalue2" | outcome =="lnrent2")
replace outcome = outcome+"_adjusted"   if adjusted==1 & (outcome =="lnvalue2" | outcome =="lnrent2")
replace outcome = outcome+"_comp"       if adjusted==2 & (outcome =="lnvalue2" | outcome =="lnrent2")
drop if adjusted>0 & (outcome=="lnhh" | outcome=="lnpop" | outcome=="vacant" | outcome=="samehouse")
gen ord = 1     if outcome=="lnrent2_unadjusted"
replace ord = 2 if outcome=="lnrent2_adjusted"
replace ord = 3 if outcome=="lnrent2_comp"
replace ord = 4 if outcome=="lnvalue2_unadjusted"
replace ord = 5 if outcome=="lnvalue2_adjusted"
replace ord = 6 if outcome=="lnvalue2_comp"
replace ord = 7 if outcome=="lnhh"
replace ord = 8 if outcome=="lnpop"
replace ord = 9 if outcome=="samehouse"
replace ord = 10 if outcome=="vacant"
replace ord = ord+5
formatable coeff se star N,  depvars(outcome) select(estimator) ord(ord) stars
log on
***** TABLE 7: IMPACT ON HOUSING MARKET AND POPULATION***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 7
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace

**** Appendix TABLE 1: Gender ------------------------------------------------------------------------------------------------------------
use `data', clear
keep if gender>0
drop if outcome=="male"
drop if outcome=="pow"
gen ord     = 1 if outcome=="lnjobs"
replace ord = 2 if outcome=="lnjobs_local"
replace ord = 3 if outcome=="lnjobs_nonlocal"
replace ord = 4 if outcome=="lnjobs_outside"
replace ord = 5 if outcome=="lnwage2"
replace ord = 6 if outcome=="lnwage2_pow"
replace ord = 7 if outcome=="lnwage2_local"
replace ord = 8 if outcome=="lnwage2_nonlocal"
replace ord = 9 if outcome=="lnwage2_outside"
replace ord = 10 if outcome=="lnwkwage2"
replace ord = 11 if outcome=="lnwkwage2_pow"
replace ord = 12 if outcome=="lnwkwage2_local"
replace ord = 13 if outcome=="lnwkwage2_nonlocal"
replace ord = 14 if outcome=="lnwkwage2_outside"

replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator gender) ord(ord) stars
log on

***** APPENDIX TABLE 1: GENDER ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 21
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


**** Appendix TABLE Z: Dropout ------------------------------------------------------------------------------------------------------------
use `data', clear
keep if dropout>0
drop if outcome=="dropout"
drop if outcome=="pow"
gen ord     = 1 if outcome=="lnjobs"
replace ord = 2 if outcome=="lnjobs_local"
replace ord = 3 if outcome=="lnjobs_nonlocal"
replace ord = 4 if outcome=="lnjobs_outside"
replace ord = 5 if outcome=="lnwage2"
replace ord = 6 if outcome=="lnwage2_pow"
replace ord = 7 if outcome=="lnwage2_local"
replace ord = 8 if outcome=="lnwage2_nonlocal"
replace ord = 9 if outcome=="lnwage2_outside"
replace ord = 10 if outcome=="lnwkwage2"
replace ord = 11 if outcome=="lnwkwage2_pow"
replace ord = 12 if outcome=="lnwkwage2_local"
replace ord = 13 if outcome=="lnwkwage2_nonlocal"
replace ord = 14 if outcome=="lnwkwage2_outside"

replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator dropout) ord(ord) stars
log on

***** APPENDIX TABLE Z: Dropout ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 21
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace







**** Appendix TABLE 2: OTHER DEMOGRAPHICS --------------------------------------------------------------------------------------------------
use `data', clear
keep if outcome=="beta_all" |  outcome=="black" | outcome=="college" | outcome=="male" | outcome=="pow"
gen ord = 1 if outcome=="beta_all"
replace ord = 2 if outcome=="black"
replace ord = 3 if outcome=="college"
replace ord = 4 if outcome=="male"
replace ord = 5 if outcome=="pow"
replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator) ord(ord) stars
log on
***** APPENDIX TABLE 2: OTHER DEMOGRAPHICS ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 22
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


***** APPENDIX TABLE 3: SAMEHOUSE VS NEW ARRIVALS ***********
use `data', clear
keep if samehouse>0
*drop if adjusted>0

replace outcome = outcome+"_unadjusted" if adjusted==0 & (outcome =="lnvalue2" | outcome =="lnrent2")
replace outcome = outcome+"_adjusted"   if adjusted==1 & (outcome =="lnvalue2" | outcome =="lnrent2")
replace outcome = outcome+"_comp"       if adjusted==2 & (outcome =="lnvalue2" | outcome =="lnrent2")
drop if adjusted>0 & (outcome=="lnwage2" | outcome=="employed" | outcome=="unemployed" | outcome=="poverty")

gen ord = 1     if outcome=="lnrent2_unadjusted"
replace ord = 2 if outcome=="lnrent2_adjusted"
replace ord = 3 if outcome=="lnrent2_comp"
replace ord = 4 if outcome=="lnvalue2_unadjusted"
replace ord = 5 if outcome=="lnvalue2_adjusted"
replace ord = 6 if outcome=="lnvalue2_comp"

replace ord = 7 if outcome=="lnwage2"
replace ord = 8 if outcome=="employed"
replace ord = 9 if outcome=="unemployed"
replace ord = 10 if outcome=="poverty"
replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator samehouse) ord(ord) stars
log on
***** APPENDIX TABLE 3: SAMEHOUSE VS NEW ARRIVALS ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs

log off
gen order = _n
gen table = 23
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


***** APPENDIX TABLE 4: AMENITIES -CRIME AND EDUC- ***********
use `data', clear
keep if outcome=="crimerate_city"|outcome=="crime_violent"|outcome=="crime_property"|outcome=="crime_total"|outcome=="pupil_teacher_ratio"|outcome=="lndiploma_recipients"
gen     ord = 1 if outcome=="crimerate_city"
replace ord = 2 if outcome=="crime_violent" 
replace ord = 3 if outcome=="crime_property"
replace ord = 4 if outcome=="crime_total"
replace ord = 5 if outcome=="pupil_teacher_ratio"
replace ord = 6 if outcome=="lndiploma_recipients"
replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator) ord(ord) stars
log on
***** APPENDIX TABLE 4: AMENITIES -CRIME AND EDUC- ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 24
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace


***** APPENDIX TABLE 5: Earnings ***********
use `data', clear

drop if samehouse>0 | lbd==1 | mig_logit ==1 | gender>0 | dropout>0
keep if outcome=="qd" | outcome=="lnwkwage2" | outcome=="lnwkwage2_pow" | outcome=="lnwkwage2_local" | outcome=="lnwkwage2_nonlocal" | outcome=="lnwkwage2_outside"| outcome=="lnincw2" | outcome=="lnincw2_pow" | outcome=="lnincw2_local" | outcome=="lnincw2_nonlocal" | outcome=="lnincw2_outside"| outcome=="lnhhincw2" | outcome=="lnhhincp2"
 
gen ord = 1 if outcome=="lnwkwage2"
replace ord = 2 if outcome=="lnwkwage2_pow"
replace ord = 3 if outcome=="lnwkwage2_local"
replace ord = 4 if outcome=="lnwkwage2_nonlocal"
replace ord = 5 if outcome=="lnwkwage2_outside"
replace ord = 6 if outcome=="lnincw2"
replace ord = 7 if outcome=="lnincw2_pow"
replace ord = 8 if outcome=="lnincw2_local"
replace ord = 9 if outcome=="lnincw2_nonlocal"
replace ord = 10 if outcome=="lnincw2_outside"
replace ord = 11 if outcome=="lnhhincw2"
replace ord = 12 if outcome=="lnhhincp2"
replace ord = 13 if outcome=="qd"
replace ord= ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator adjusted) ord(ord) stars
log on
***** APPENDIX TABLE 5: Earnings ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 25
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace



***** APPENDIX TABLE 6: Unimputed Local Wages ***********
use `data', clear
drop if samehouse>0 | lbd==1 | mig_logit ==1 | gender>0 | dropout>0
keep if outcome=="lnwage3_local" | outcome=="lnwkwage3_local" | outcome=="lnincw3_local" 
gen ord = 1 if outcome=="lnwage3_local"
replace ord = 2 if outcome=="lnwkwage3_local"
replace ord = 3 if outcome=="lnincw3_local"
replace ord = ord+5
cap noisily formatable coeff se star N,  depvars(outcome) select(estimator adjusted) ord(ord) stars
log on
***** APPENDIX TABLE 6: Unimputed Local Wages ***********
di "$REPS REPS USED IN THESE s.e."
list, clean noheader noobs
log off
gen order = _n
gen table = 26
append using  "`results'/formatresults_`NAME'.dta"
save "`results'/formatresults_`NAME'.dta", replace




log close
