clear
clear matrix
set more off

** 1. Setup and open main file ------------------------------------------------------------------------------------------------------
	cap run "/rdcprojects/mc1/mc00535/programs_organize/3.estimation/1.setup.do"
	if _rc!=0 di in red "run 1.setup.do"
	global ssllbd = "/rdcprojects/mc1/mc00535/data/ssllbd/"
	!mkdir /rdcprojects/mc1/mc00535/programs_organize/3.estimation/2.results/winlose/annual_lbd_plots/

*** Data Prep
   ** Load data
   use "$ssllbd/LBD_simple_annual_panel.dta", replace
   gen lnestab  = ln(establishments)
   gen lnestab_less5now = ln(establishments_less5now)
   gen lnestab_more5now = ln(establishments_more5now)
   gen lnemplbd = ln(employment)
   drop lnavrgwage2*

   gen avrgwage=wagebill/employment
   gen avrgwage_less5now=wagebill_less5now/employment_less5now
   gen avrgwage_more5now=wagebill_more5now/employment_more5now
   gen avrgwage_less5=wagebill_less5/employment_less5
   gen avrgwage_more5=wagebill_more5/employment_more5

   **winsorize
   forvalues i=1987/2002{
	centile avrgwage if year==`i', c(1 99)
	local ll=r(c_1)
	local ul=r(c_2)
	foreach var of varlist avrgwage*{
		replace `var'=`ll' if `var'<`ll'&year==`i'
		replace `var'=`ul' if `var'>`ul'&`var'!=.&year==`i'
		sum `var' if year==`i'
	}
   }

   *take logs
   replace lnavrgwage=ln(avrgwage)
   replace lnavrgwage_less5now=ln(avrgwage_less5now)
   replace lnavrgwage_more5now=ln(avrgwage_more5now)
   replace lnavrgwage_less5=ln(avrgwage_less5)
   replace lnavrgwage_more5=ln(avrgwage_more5)

   drop avrgwage*
   drop _W
   reshape wide establishments* wagebill* employment* lnestab* lnemplbd lnavrgwage*, i(tractid90) j(year)
   aorder
   order tractid90

   ** create the variable yr for merge with workfile
   gen yr=4
   tempfile templbd
   save `templbd'
   clear

   **** merge on bo weights
   run "$dofiles/3.pscore.do" 1 ols 0 1 winlose_gt10 wild_off
   ren employment emplbd2000
   ren d_lnemplbd dlnemplbd2000
   keep yr tractid90 assigned_tract progid_power wTOT $X city emplbd2000 dlnemplbd2000 cg
   joinby tractid90 yr using `templbd', unmatched(none)
   foreach var in lnestab lnestab_less5now lnestab_more5now lnemplbd lnavrgwage lnavrgwage_less5now lnavrgwage_more5now{
      forval year=1987/2004 {
        gen ld_`var'`year' = `var'`year' - `var'1992
	}
    }
   compare emplbd2000 employment2000 if yr==4
   compare dlnemplbd2000 ld_lnemplbd2000

*** Plots
        global annualplots = "/rdcprojects/mc1/mc00535/programs_organize/3.estimation/2.results/winlose/annual_lbd_plots/"
	foreach var in lnestab lnestab_less5now lnestab_more5now lnemplbd lnavrgwage lnavrgwage_less5now lnavrgwage_more5now{
	   forval year=1987/2004 {
	      reg ld_`var'`year' assigned_tract if yr==4, cluster(cg)
	      gen     Tld_`var'`year' = 0
	      replace Tld_`var'`year'=_b[assigned_tract] if _rc==0
	      gen     SEld_`var'`year' = 0
	      replace SEld_`var'`year'=e(se) if _rc==0
	   }
	}

	foreach var in lnestab lnestab_less5now lnestab_more5now lnemplbd lnavrgwage lnavrgwage_less5now lnavrgwage_more5now{
	   forval year=1987/2004 {
	      cap bo2 ld_`var'`year' $X if yr==4, t(assigned_tract) cluster(cg)
	      gen     Tld_rw_`var'`year' = 0
	      replace Tld_rw_`var'`year'=e(delt) if _rc==0
	      gen     SEld_rw_`var'`year' = 0
	      replace SEld_rw_`var'`year'=e(se) if _rc==0
	   }
	}

	reshape long establishments employment lnestab lnestab_less5now lnestab_more5now lnemplbd lnavrgwage lnavrgwage_less5now lnavrgwage_more5now Tld_lnestab Tld_lnestab_more5now Tld_lnestab_less5now Tld_lnemplbd Tld_lnavrgwage  Tld_lnavrgwage_less5now Tld_lnavrgwage_more5now SEld_lnestab SEld_lnestab_more5now SEld_lnestab_less5now SEld_lnemplbd SEld_lnavrgwage SEld_lnavrgwage_less5now SEld_lnavrgwage_more5now Tld_rw_lnestab Tld_rw_lnestab_more5now Tld_rw_lnestab_less5now Tld_rw_lnemplbd Tld_rw_lnavrgwage Tld_rw_lnavrgwage_less5now Tld_rw_lnavrgwage_more5now SEld_rw_lnestab SEld_rw_lnestab_more5now SEld_rw_lnestab_less5now SEld_rw_lnemplbd SEld_rw_lnavrgwage SEld_rw_lnavrgwage_less5now SEld_rw_lnavrgwage_more5now, i(tractid90) j(year)

	preserve
	collapse (mean) lnestab lnestab_less5now lnestab_more5now lnemplbd lnavrgwage lnavrgwage_less5now lnavrgwage_more5now, by(assigned_tract year)
	tempfile rawmeans
	save `rawmeans'
	restore

	preserve
	collapse (mean) rw_lnestab=lnestab rw_lnestab_less5now=lnestab_less5now rw_lnestab_more5now=lnestab_more5now rw_lnemplbd=lnemplbd rw_lnavrgwage=lnavrgwage rw_lnavrgwage_less5now=lnavrgwage_less5now rw_lnavrgwage_more5now=lnavrgwage_more5now [iw=wTOT], by(assigned_tract year)
	joinby assigned_tract year using `rawmeans', unmatched(both)
	tab _m
	drop _m

	foreach var of varlist *lnestab* *lnemplbd *lnavrgwage* {
	gen ez_`var' = `var' if assigned_tract==1
	gen nonez_`var' = `var' if assigned_tract==0
	}
	drop ez_rw*

	collapse ez* nonez*, by(year)

	reshape long ez nonez nonez_rw, i(year) j(outcome) string

	drop if year==1988
	replace outcome = "Log (Average Earnings per Worker)" if outcome=="_lnavrgwage"  
	replace outcome = "Log (Jobs) -LBD" if outcome=="_lnemplbd"  
	replace outcome = "Log (Establishments)" if outcome=="_lnestab"
	label var ez "EZ"
	label var nonez "non-EZ"
	label var nonez_rw  "non-EZ Reweighted"
	twoway line ez nonez nonez_rw year, by(outcome, style(rescale)) lpattern(solid dot dash) xlabel(1987(5)2002) scheme(s2mono)
	graph export "$annualplots/outcome_trends.eps", as(eps) preview(off) replace
	!epstopdf     $annualplots/outcome_trends.eps
	save "$annualplots/data_annual_lbd_plot.dta", replace
	restore


	preserve
	collapse (mean) T* SE*, by(year)
	drop if year==1988
	foreach outcome in lnestab lnestab_more5now lnestab_less5now lnemplbd lnavrgwage lnavrgwage_more5now lnavrgwage_less5now rw_lnestab rw_lnestab_more5now rw_lnestab_less5now rw_lnemplbd rw_lnavrgwage rw_lnavrgwage_less5now rw_lnavrgwage_more5now{
	gen Tld_`outcome'_low  = Tld_`outcome' - 1.96*SEld_`outcome'
	gen Tld_`outcome'_high = Tld_`outcome' + 1.96*SEld_`outcome'
	twoway (rarea Tld_`outcome'_low Tld_`outcome'_high year, xlabel(1987(3)2002)) (line Tld_`outcome' year, xlabel(1987(3)2002) scheme(s2mono) legend(order(2 "long difference" 1 "95% CI")) xtitle() ytitle("`outcome'"))
	graph export "$annualplots/`outcome'.eps", as(eps) preview(off) replace
	!epstopdf $annualplots/`outcome'.eps
	}
	restore
	

